# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: radiensserver.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import datasource_pb2 as datasource__pb2
from . import biointerface_pb2 as biointerface__pb2
from . import spikesorter_pb2 as spikesorter__pb2
from . import radiens_dev_pb2 as radiens__dev__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='radiensserver.proto',
  package='allego',
  syntax='proto2',
  serialized_options=b'Z\023internal/radix/grpc',
  serialized_pb=b'\n\x13radiensserver.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\x1a\x10\x64\x61tasource.proto\x1a\x12\x62iointerface.proto\x1a\x11spikesorter.proto\x1a\x11radiens_dev.proto\"K\n\x19RadiensHealthcheckRequest\x12\x1a\n\x12isIncludeWarehouse\x18\x01 \x01(\x08\x12\x12\n\nisDetailed\x18\x02 \x01(\x08\"]\n\x16RadiensHealthcheckSpec\x12\x0e\n\x06\x65rrMsg\x18\x01 \x01(\t\x12\x33\n\toutfitter\x18\x02 \x01(\x0b\x32 .allego.WarehouseHealthcheckSpec2\xca/\n\x0bRadiensCore\x12R\n\x0bHealthcheck\x12!.allego.RadiensHealthcheckRequest\x1a\x1e.allego.RadiensHealthcheckSpec\"\x00\x12>\n\nInitialize\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12\x39\n\x05\x43lose\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12L\n\x10WorkspaceControl\x12\x1f.allego.WorkspaceControlRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x11GetRadiensServers\x12 .allego.GetRadiensServersRequest\x1a\x1b.allego.RadiensServersReply\"\x00\x12H\n\x0cGetWorkspace\x12\x1b.allego.GetWorkspaceRequest\x1a\x19.allego.GetWorkspaceReply\"\x00\x12J\n\x13GetRadixEnvironment\x12\x17.allego.StandardRequest\x1a\x18.allego.RadixEnvironment\"\x00\x12H\n\rListDirectory\x12\x1e.allego.ListDataSourcesRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12V\n\x12\x43opyDataSourceFile\x12\'.allego.CopyRemoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12X\n\x14RemoveDataSourceFile\x12\'.allego.CopyRemoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12P\n\x12MoveDataSourceFile\x12!.allego.MoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12N\n\x13SpikesListDirectory\x12\x1e.allego.ListDataSourcesRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12R\n\x0eSpikesCopyFile\x12\'.allego.CopyRemoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12T\n\x10SpikesRemoveFile\x12\'.allego.CopyRemoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12L\n\x0eSpikesMoveFile\x12!.allego.MoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12T\n\x16ManageNodeOrganization\x12\x1c.allego.ManageNodeOrgRequest\x1a\x1a.allego.ManageNodeOrgReply\"\x00\x12K\n\rManageNodeLab\x12\x1c.allego.ManageNodeLabRequest\x1a\x1a.allego.ManageNodeLabReply\"\x00\x12N\n\x0eManageNodeUser\x12\x1d.allego.ManageNodeUserRequest\x1a\x1b.allego.ManageNodeUserReply\"\x00\x12\x45\n\x0fManageNodeProbe\x12\x18.allego.ProbeNodeRequest\x1a\x16.allego.ProbeNodeReply\"\x00\x12\x41\n\x0bManageEdges\x12\x18.allego.WorldEdgeRequest\x1a\x16.allego.WorldEdgeReply\"\x00\x12\x42\n\nQueryWorld\x12\x19.allego.QueryWorldRequest\x1a\x17.allego.QueryWorldReply\"\x00\x12V\n\x1bGetWarehouseSensorComponent\x12\x19.allego.SensorCompRequest\x1a\x1a.allego.GetSensorCompReply\"\x00\x12O\n\x0fListSensorSpecs\x12\x1c.allego.SignalGroupIDRequest\x1a\x1c.allego.ListSensorSpecsReply\"\x00\x12>\n\tSetSensor\x12\x18.allego.SetSensorRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x14SetSensorPositionTcs\x12#.allego.SetSensorPositionTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12R\n\x13SetSitePositionsTcs\x12\".allego.SetSitePositionsTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11UpdateSignalGroup\x12 .allego.UpdateSignalGroupRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11GetSignalGroupIDs\x12\x17.allego.StandardRequest\x1a\x1e.allego.GetSignalGroupIDsReply\"\x00\x12N\n\x11GetSpikeSorterIDs\x12\x17.allego.StandardRequest\x1a\x1e.allego.GetSpikeSorterIDsReply\"\x00\x12\x45\n\x0eGetSignalGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x13.allego.SignalGroup\"\x00\x12O\n\x13GetDataSourceParams\x12\x1c.allego.SignalGroupIDRequest\x1a\x18.allego.DataSourceParams\"\x00\x12=\n\nGetSignals\x12\x19.allego.GetSignalsRequest\x1a\x12.allego.RawSignals\"\x00\x12\x41\n\x0cSetDACStream\x12\x18.allego.DACStreamRequest\x1a\x15.allego.StandardReply\"\x00\x12;\n\tSetDACOff\x12\x15.allego.DACOffRequest\x1a\x15.allego.StandardReply\"\x00\x12@\n\rGetHDSnapshot\x12\x19.allego.HDSnapshotRequest\x1a\x12.allego.HDSnapshot\"\x00\x12\x42\n\x0bSetDSPGroup\x12\x1a.allego.SetDSPGroupRequest\x1a\x15.allego.StandardReply\"\x00\x12?\n\x0bGetDSPGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x10.allego.DSPGroup\"\x00\x12J\n\x0eListDataSource\x12\x19.allego.DataSourceRequest\x1a\x1b.allego.DataSourceStatusMap\"\x00\x12K\n\x11ListDataSourceIDs\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12[\n\x15SetDataSourceFromFile\x12 .allego.DataSourceSetSaveRequest\x1a\x1e.allego.DataSourceSetSaveReply\"\x00\x12I\n\x0f\x43learDataSource\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12J\n\x10RenameDataSource\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12>\n\x08KpiClear\x12\x19.allego.KpiControlRequest\x1a\x15.allego.StandardReply\"\x00\x12\x42\n\x0cKpiCalculate\x12\x19.allego.KpiControlRequest\x1a\x15.allego.StandardReply\"\x00\x12\x45\n\x0cGetKpiStatus\x12\x1b.allego.GetKpiStatusRequest\x1a\x16.allego.KpiStatusReply\"\x00\x12H\n\rKpiGetMetrics\x12\x15.allego.KpiMetricsReq\x1a\x1e.allego.KpiBundlePacketMetrics\"\x00\x12P\n\x12SetKpiUpdatePeriod\x12!.allego.SetKpiUpdatePeriodRequest\x1a\x15.allego.StandardReply\"\x00\x12J\n\x0fSetKpiThreshold\x12\x1e.allego.SetKpiThresholdRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11SetKpiEventDetect\x12 .allego.SetKpiEventDetectRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11SetKpiEventShadow\x12 .allego.SetKpiEventShadowRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11SetKpiEventWindow\x12 .allego.SetKpiEventWindowRequest\x1a\x15.allego.StandardReply\"\x00\x12U\n\x10SpikesSaveToFile\x12 .allego.DataSourceSetSaveRequest\x1a\x1d.allego.DataSourceFileSetStat\"\x00\x12W\n\x11SpikesSetFromFile\x12 .allego.DataSourceSetSaveRequest\x1a\x1e.allego.DataSourceSetSaveReply\"\x00\x12\x46\n\x0cSpikesGetIDs\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12H\n\x0eSpikesRenameID\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12S\n\x17SpikesGetAllSummaryInfo\x12\x19.allego.DataSourceRequest\x1a\x1b.allego.DataSourceStatusMap\"\x00\x12\x45\n\rSpikesGetSpec\x12\x19.allego.DataSourceRequest\x1a\x17.allego.SpikesSpecReply\"\x00\x12\x64\n\x13SpikesGetRasterData\x12\'.allego.SpikeSorterGetRasterDataRequest\x1a\".allego.SpikeSorterRasterDataReply\"\x00\x12g\n\x14SpikesGetSpikesDense\x12$.allego.BiointerfaceGetSpikesRequest\x1a\'.allego.BiointerfaceSpikeDataDenseReply\"\x00\x12I\n\x0fSpikesDeleteIDs\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12\x66\n\x16\x42iointerfaceGetNeurons\x12%.allego.BiointerfaceGetNeuronsRequest\x1a#.allego.BiointerfaceGetNeuronsReply\"\x00\x12p\n\"BiointerfaceSeekEndSpikeTimestamps\x12\x31.allego.BiointerfaceSeekEndSpikeTimestampsRequest\x1a\x15.allego.StandardReply\"\x00\x12Q\n\x0f\x42iointerfaceViz\x12\x1e.allego.BiointerfaceVizRequest\x1a\x1c.allego.BiointerfaceVizReply\"\x00\x12[\n\x1b\x42iointerfaceListSensorSpecs\x12\x1c.allego.SignalGroupIDRequest\x1a\x1c.allego.ListSensorSpecsReply\"\x00\x12J\n\x15\x42iointerfaceSetSensor\x12\x18.allego.SetSensorRequest\x1a\x15.allego.StandardReply\"\x00\x12`\n BiointerfaceSetSensorPositionTcs\x12#.allego.SetSensorPositionTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12^\n\x1f\x42iointerfaceSetSitePositionsTcs\x12\".allego.SetSitePositionsTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12H\n\x0c\x46\x65\x61tureStart\x12\x1f.allego.FeatureStartStopRequest\x1a\x15.allego.StandardReply\"\x00\x12G\n\x0b\x46\x65\x61tureStop\x12\x1f.allego.FeatureStartStopRequest\x1a\x15.allego.StandardReply\"\x00\x12=\n\nGetPrivacy\x12\x17.allego.StandardRequest\x1a\x14.allego.PrivacyReply\"\x00\x12@\n\nSetPrivacy\x12\x19.allego.SetPrivacyRequest\x1a\x15.allego.StandardReply\"\x00\x12J\n\x11\x44\x65leteSignalGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x15.allego.StandardReply\"\x00\x12K\n\x14SpikesGetSignalGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x13.allego.SignalGroup\"\x00\x12\x33\n\x0bSetProtocol\x12\x10.allego.Protocol\x1a\x10.allego.Protocol\"\x00\x12:\n\x0bGetProtocol\x12\x17.allego.ProtocolRequest\x1a\x10.allego.Protocol\"\x00\x12\x43\n\x0eRenameProtocol\x12\x1d.allego.RenameProtocolRequest\x1a\x10.allego.Protocol\"\x00\x12J\n\x0fGetAllProtocols\x12\x17.allego.StandardRequest\x1a\x1c.allego.GetAllProtocolsReply\"\x00\x12K\n\rApplyProtocol\x12\x17.allego.ProtocolRequest\x1a\x1d.allego.ApplyProtocolProgress\"\x00\x30\x01\x32\xf9\x06\n\x13RadiensSpikeSorter1\x12R\n\x0bHealthcheck\x12!.allego.RadiensHealthcheckRequest\x1a\x1e.allego.RadiensHealthcheckSpec\"\x00\x12P\n\x12SpikeSorterCommand\x12!.allego.SpikeSorterCommandRequest\x1a\x15.allego.StandardReply\"\x00\x12R\n\x13SpikeSorterSetParam\x12\".allego.SpikeSorterSetParamRequest\x1a\x15.allego.StandardReply\"\x00\x12\x64\n\x13SpikeSorterGetParam\x12\".allego.SpikeSorterStandardRequest\x1a\'.allego.GetSpikeSorterParamCommandReply\"\x00\x12U\n\x13SpikeSorterGetState\x12\".allego.SpikeSorterStandardRequest\x1a\x18.allego.SpikeSorterState\"\x00\x12\x65\n\x17SpikeSorterGetDashboard\x12\".allego.SpikeSorterStandardRequest\x1a$.allego.SpikeSorterGetDashboardReply\"\x00\x12I\n\x16SpikeSorterWrangleData\x12\x16.allego.WrangleRequest\x1a\x15.allego.StandardReply\"\x00\x12W\n\x11SpikeSorterLaunch\x12 .allego.SpikeSorterLaunchRequest\x1a\x1e.allego.SpikeSorterLaunchReply\"\x00\x12P\n\x11SpikeSorterDelete\x12\".allego.SpikeSorterStandardRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\rSpikesGetSpec\x12\".allego.SpikeSorterStandardRequest\x1a\x17.allego.SpikesSpecReply\"\x00\x32\xb7\x04\n\x0bRadiensDev1\x12R\n\x0bHealthcheck\x12!.allego.RadiensHealthcheckRequest\x1a\x1e.allego.RadiensHealthcheckSpec\"\x00\x12S\n\x1aSpkSortTrainerMakeNewModel\x12\x1c.allego.SpkSortTrainerNewReq\x1a\x15.allego.StandardReply\"\x00\x12W\n#SpkSortTrainerMakeDefaultProdModels\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12\x64\n$SpkSortTrainerListLocalNetworkModels\x12\x17.allego.StandardRequest\x1a!.allego.SpkSortTrainerStatusReply\"\x00\x12g\n&SpkSortTrainerDeleteLocalNetworkModels\x12$.allego.SpkSortTrainerDeleteModelReq\x1a\x15.allego.StandardReply\"\x00\x12W\n\x17SpkSortTrainerGetStatus\x12\x17.allego.StandardRequest\x1a!.allego.SpkSortTrainerStatusReply\"\x00\x42\x15Z\x13internal/radix/grpc'
  ,
  dependencies=[common__pb2.DESCRIPTOR,datasource__pb2.DESCRIPTOR,biointerface__pb2.DESCRIPTOR,spikesorter__pb2.DESCRIPTOR,radiens__dev__pb2.DESCRIPTOR,])




_RADIENSHEALTHCHECKREQUEST = _descriptor.Descriptor(
  name='RadiensHealthcheckRequest',
  full_name='allego.RadiensHealthcheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isIncludeWarehouse', full_name='allego.RadiensHealthcheckRequest.isIncludeWarehouse', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isDetailed', full_name='allego.RadiensHealthcheckRequest.isDetailed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=196,
)


_RADIENSHEALTHCHECKSPEC = _descriptor.Descriptor(
  name='RadiensHealthcheckSpec',
  full_name='allego.RadiensHealthcheckSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errMsg', full_name='allego.RadiensHealthcheckSpec.errMsg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outfitter', full_name='allego.RadiensHealthcheckSpec.outfitter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=291,
)

_RADIENSHEALTHCHECKSPEC.fields_by_name['outfitter'].message_type = common__pb2._WAREHOUSEHEALTHCHECKSPEC
DESCRIPTOR.message_types_by_name['RadiensHealthcheckRequest'] = _RADIENSHEALTHCHECKREQUEST
DESCRIPTOR.message_types_by_name['RadiensHealthcheckSpec'] = _RADIENSHEALTHCHECKSPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RadiensHealthcheckRequest = _reflection.GeneratedProtocolMessageType('RadiensHealthcheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _RADIENSHEALTHCHECKREQUEST,
  '__module__' : 'radiensserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.RadiensHealthcheckRequest)
  })
_sym_db.RegisterMessage(RadiensHealthcheckRequest)

RadiensHealthcheckSpec = _reflection.GeneratedProtocolMessageType('RadiensHealthcheckSpec', (_message.Message,), {
  'DESCRIPTOR' : _RADIENSHEALTHCHECKSPEC,
  '__module__' : 'radiensserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.RadiensHealthcheckSpec)
  })
_sym_db.RegisterMessage(RadiensHealthcheckSpec)


DESCRIPTOR._options = None

_RADIENSCORE = _descriptor.ServiceDescriptor(
  name='RadiensCore',
  full_name='allego.RadiensCore',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=294,
  serialized_end=6384,
  methods=[
  _descriptor.MethodDescriptor(
    name='Healthcheck',
    full_name='allego.RadiensCore.Healthcheck',
    index=0,
    containing_service=None,
    input_type=_RADIENSHEALTHCHECKREQUEST,
    output_type=_RADIENSHEALTHCHECKSPEC,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Initialize',
    full_name='allego.RadiensCore.Initialize',
    index=1,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Close',
    full_name='allego.RadiensCore.Close',
    index=2,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WorkspaceControl',
    full_name='allego.RadiensCore.WorkspaceControl',
    index=3,
    containing_service=None,
    input_type=common__pb2._WORKSPACECONTROLREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetRadiensServers',
    full_name='allego.RadiensCore.GetRadiensServers',
    index=4,
    containing_service=None,
    input_type=common__pb2._GETRADIENSSERVERSREQUEST,
    output_type=common__pb2._RADIENSSERVERSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetWorkspace',
    full_name='allego.RadiensCore.GetWorkspace',
    index=5,
    containing_service=None,
    input_type=common__pb2._GETWORKSPACEREQUEST,
    output_type=common__pb2._GETWORKSPACEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetRadixEnvironment',
    full_name='allego.RadiensCore.GetRadixEnvironment',
    index=6,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._RADIXENVIRONMENT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListDirectory',
    full_name='allego.RadiensCore.ListDirectory',
    index=7,
    containing_service=None,
    input_type=common__pb2._LISTDATASOURCESREQUEST,
    output_type=datasource__pb2._CPRMMVLSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CopyDataSourceFile',
    full_name='allego.RadiensCore.CopyDataSourceFile',
    index=8,
    containing_service=None,
    input_type=datasource__pb2._COPYREMOVEDATASOURCEFILEREQUEST,
    output_type=datasource__pb2._CPRMMVLSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveDataSourceFile',
    full_name='allego.RadiensCore.RemoveDataSourceFile',
    index=9,
    containing_service=None,
    input_type=datasource__pb2._COPYREMOVEDATASOURCEFILEREQUEST,
    output_type=datasource__pb2._CPRMMVLSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='MoveDataSourceFile',
    full_name='allego.RadiensCore.MoveDataSourceFile',
    index=10,
    containing_service=None,
    input_type=datasource__pb2._MOVEDATASOURCEFILEREQUEST,
    output_type=datasource__pb2._CPRMMVLSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesListDirectory',
    full_name='allego.RadiensCore.SpikesListDirectory',
    index=11,
    containing_service=None,
    input_type=common__pb2._LISTDATASOURCESREQUEST,
    output_type=datasource__pb2._CPRMMVLSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesCopyFile',
    full_name='allego.RadiensCore.SpikesCopyFile',
    index=12,
    containing_service=None,
    input_type=datasource__pb2._COPYREMOVEDATASOURCEFILEREQUEST,
    output_type=datasource__pb2._CPRMMVLSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesRemoveFile',
    full_name='allego.RadiensCore.SpikesRemoveFile',
    index=13,
    containing_service=None,
    input_type=datasource__pb2._COPYREMOVEDATASOURCEFILEREQUEST,
    output_type=datasource__pb2._CPRMMVLSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesMoveFile',
    full_name='allego.RadiensCore.SpikesMoveFile',
    index=14,
    containing_service=None,
    input_type=datasource__pb2._MOVEDATASOURCEFILEREQUEST,
    output_type=datasource__pb2._CPRMMVLSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ManageNodeOrganization',
    full_name='allego.RadiensCore.ManageNodeOrganization',
    index=15,
    containing_service=None,
    input_type=common__pb2._MANAGENODEORGREQUEST,
    output_type=common__pb2._MANAGENODEORGREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ManageNodeLab',
    full_name='allego.RadiensCore.ManageNodeLab',
    index=16,
    containing_service=None,
    input_type=common__pb2._MANAGENODELABREQUEST,
    output_type=common__pb2._MANAGENODELABREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ManageNodeUser',
    full_name='allego.RadiensCore.ManageNodeUser',
    index=17,
    containing_service=None,
    input_type=common__pb2._MANAGENODEUSERREQUEST,
    output_type=common__pb2._MANAGENODEUSERREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ManageNodeProbe',
    full_name='allego.RadiensCore.ManageNodeProbe',
    index=18,
    containing_service=None,
    input_type=common__pb2._PROBENODEREQUEST,
    output_type=common__pb2._PROBENODEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ManageEdges',
    full_name='allego.RadiensCore.ManageEdges',
    index=19,
    containing_service=None,
    input_type=common__pb2._WORLDEDGEREQUEST,
    output_type=common__pb2._WORLDEDGEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='QueryWorld',
    full_name='allego.RadiensCore.QueryWorld',
    index=20,
    containing_service=None,
    input_type=common__pb2._QUERYWORLDREQUEST,
    output_type=common__pb2._QUERYWORLDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetWarehouseSensorComponent',
    full_name='allego.RadiensCore.GetWarehouseSensorComponent',
    index=21,
    containing_service=None,
    input_type=common__pb2._SENSORCOMPREQUEST,
    output_type=common__pb2._GETSENSORCOMPREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListSensorSpecs',
    full_name='allego.RadiensCore.ListSensorSpecs',
    index=22,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=common__pb2._LISTSENSORSPECSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSensor',
    full_name='allego.RadiensCore.SetSensor',
    index=23,
    containing_service=None,
    input_type=common__pb2._SETSENSORREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSensorPositionTcs',
    full_name='allego.RadiensCore.SetSensorPositionTcs',
    index=24,
    containing_service=None,
    input_type=common__pb2._SETSENSORPOSITIONTCSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSitePositionsTcs',
    full_name='allego.RadiensCore.SetSitePositionsTcs',
    index=25,
    containing_service=None,
    input_type=common__pb2._SETSITEPOSITIONSTCSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSignalGroup',
    full_name='allego.RadiensCore.UpdateSignalGroup',
    index=26,
    containing_service=None,
    input_type=common__pb2._UPDATESIGNALGROUPREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignalGroupIDs',
    full_name='allego.RadiensCore.GetSignalGroupIDs',
    index=27,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._GETSIGNALGROUPIDSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSpikeSorterIDs',
    full_name='allego.RadiensCore.GetSpikeSorterIDs',
    index=28,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=spikesorter__pb2._GETSPIKESORTERIDSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignalGroup',
    full_name='allego.RadiensCore.GetSignalGroup',
    index=29,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=common__pb2._SIGNALGROUP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataSourceParams',
    full_name='allego.RadiensCore.GetDataSourceParams',
    index=30,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=datasource__pb2._DATASOURCEPARAMS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSignals',
    full_name='allego.RadiensCore.GetSignals',
    index=31,
    containing_service=None,
    input_type=common__pb2._GETSIGNALSREQUEST,
    output_type=common__pb2._RAWSIGNALS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDACStream',
    full_name='allego.RadiensCore.SetDACStream',
    index=32,
    containing_service=None,
    input_type=common__pb2._DACSTREAMREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDACOff',
    full_name='allego.RadiensCore.SetDACOff',
    index=33,
    containing_service=None,
    input_type=common__pb2._DACOFFREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetHDSnapshot',
    full_name='allego.RadiensCore.GetHDSnapshot',
    index=34,
    containing_service=None,
    input_type=common__pb2._HDSNAPSHOTREQUEST,
    output_type=common__pb2._HDSNAPSHOT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDSPGroup',
    full_name='allego.RadiensCore.SetDSPGroup',
    index=35,
    containing_service=None,
    input_type=common__pb2._SETDSPGROUPREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDSPGroup',
    full_name='allego.RadiensCore.GetDSPGroup',
    index=36,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=common__pb2._DSPGROUP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListDataSource',
    full_name='allego.RadiensCore.ListDataSource',
    index=37,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCEREQUEST,
    output_type=datasource__pb2._DATASOURCESTATUSMAP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListDataSourceIDs',
    full_name='allego.RadiensCore.ListDataSourceIDs',
    index=38,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCEREQUEST,
    output_type=datasource__pb2._DATASOURCEIDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDataSourceFromFile',
    full_name='allego.RadiensCore.SetDataSourceFromFile',
    index=39,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCESETSAVEREQUEST,
    output_type=datasource__pb2._DATASOURCESETSAVEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ClearDataSource',
    full_name='allego.RadiensCore.ClearDataSource',
    index=40,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCEREQUEST,
    output_type=datasource__pb2._DATASOURCEIDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RenameDataSource',
    full_name='allego.RadiensCore.RenameDataSource',
    index=41,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCEREQUEST,
    output_type=datasource__pb2._DATASOURCEIDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='KpiClear',
    full_name='allego.RadiensCore.KpiClear',
    index=42,
    containing_service=None,
    input_type=common__pb2._KPICONTROLREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='KpiCalculate',
    full_name='allego.RadiensCore.KpiCalculate',
    index=43,
    containing_service=None,
    input_type=common__pb2._KPICONTROLREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetKpiStatus',
    full_name='allego.RadiensCore.GetKpiStatus',
    index=44,
    containing_service=None,
    input_type=common__pb2._GETKPISTATUSREQUEST,
    output_type=common__pb2._KPISTATUSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='KpiGetMetrics',
    full_name='allego.RadiensCore.KpiGetMetrics',
    index=45,
    containing_service=None,
    input_type=common__pb2._KPIMETRICSREQ,
    output_type=common__pb2._KPIBUNDLEPACKETMETRICS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetKpiUpdatePeriod',
    full_name='allego.RadiensCore.SetKpiUpdatePeriod',
    index=46,
    containing_service=None,
    input_type=common__pb2._SETKPIUPDATEPERIODREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetKpiThreshold',
    full_name='allego.RadiensCore.SetKpiThreshold',
    index=47,
    containing_service=None,
    input_type=common__pb2._SETKPITHRESHOLDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetKpiEventDetect',
    full_name='allego.RadiensCore.SetKpiEventDetect',
    index=48,
    containing_service=None,
    input_type=common__pb2._SETKPIEVENTDETECTREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetKpiEventShadow',
    full_name='allego.RadiensCore.SetKpiEventShadow',
    index=49,
    containing_service=None,
    input_type=common__pb2._SETKPIEVENTSHADOWREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetKpiEventWindow',
    full_name='allego.RadiensCore.SetKpiEventWindow',
    index=50,
    containing_service=None,
    input_type=common__pb2._SETKPIEVENTWINDOWREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesSaveToFile',
    full_name='allego.RadiensCore.SpikesSaveToFile',
    index=51,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCESETSAVEREQUEST,
    output_type=datasource__pb2._DATASOURCEFILESETSTAT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesSetFromFile',
    full_name='allego.RadiensCore.SpikesSetFromFile',
    index=52,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCESETSAVEREQUEST,
    output_type=datasource__pb2._DATASOURCESETSAVEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesGetIDs',
    full_name='allego.RadiensCore.SpikesGetIDs',
    index=53,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCEREQUEST,
    output_type=datasource__pb2._DATASOURCEIDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesRenameID',
    full_name='allego.RadiensCore.SpikesRenameID',
    index=54,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCEREQUEST,
    output_type=datasource__pb2._DATASOURCEIDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesGetAllSummaryInfo',
    full_name='allego.RadiensCore.SpikesGetAllSummaryInfo',
    index=55,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCEREQUEST,
    output_type=datasource__pb2._DATASOURCESTATUSMAP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesGetSpec',
    full_name='allego.RadiensCore.SpikesGetSpec',
    index=56,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCEREQUEST,
    output_type=biointerface__pb2._SPIKESSPECREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesGetRasterData',
    full_name='allego.RadiensCore.SpikesGetRasterData',
    index=57,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERGETRASTERDATAREQUEST,
    output_type=spikesorter__pb2._SPIKESORTERRASTERDATAREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesGetSpikesDense',
    full_name='allego.RadiensCore.SpikesGetSpikesDense',
    index=58,
    containing_service=None,
    input_type=biointerface__pb2._BIOINTERFACEGETSPIKESREQUEST,
    output_type=biointerface__pb2._BIOINTERFACESPIKEDATADENSEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesDeleteIDs',
    full_name='allego.RadiensCore.SpikesDeleteIDs',
    index=59,
    containing_service=None,
    input_type=datasource__pb2._DATASOURCEREQUEST,
    output_type=datasource__pb2._DATASOURCEIDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceGetNeurons',
    full_name='allego.RadiensCore.BiointerfaceGetNeurons',
    index=60,
    containing_service=None,
    input_type=biointerface__pb2._BIOINTERFACEGETNEURONSREQUEST,
    output_type=biointerface__pb2._BIOINTERFACEGETNEURONSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceSeekEndSpikeTimestamps',
    full_name='allego.RadiensCore.BiointerfaceSeekEndSpikeTimestamps',
    index=61,
    containing_service=None,
    input_type=biointerface__pb2._BIOINTERFACESEEKENDSPIKETIMESTAMPSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceViz',
    full_name='allego.RadiensCore.BiointerfaceViz',
    index=62,
    containing_service=None,
    input_type=biointerface__pb2._BIOINTERFACEVIZREQUEST,
    output_type=biointerface__pb2._BIOINTERFACEVIZREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceListSensorSpecs',
    full_name='allego.RadiensCore.BiointerfaceListSensorSpecs',
    index=63,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=common__pb2._LISTSENSORSPECSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceSetSensor',
    full_name='allego.RadiensCore.BiointerfaceSetSensor',
    index=64,
    containing_service=None,
    input_type=common__pb2._SETSENSORREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceSetSensorPositionTcs',
    full_name='allego.RadiensCore.BiointerfaceSetSensorPositionTcs',
    index=65,
    containing_service=None,
    input_type=common__pb2._SETSENSORPOSITIONTCSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BiointerfaceSetSitePositionsTcs',
    full_name='allego.RadiensCore.BiointerfaceSetSitePositionsTcs',
    index=66,
    containing_service=None,
    input_type=common__pb2._SETSITEPOSITIONSTCSREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FeatureStart',
    full_name='allego.RadiensCore.FeatureStart',
    index=67,
    containing_service=None,
    input_type=common__pb2._FEATURESTARTSTOPREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FeatureStop',
    full_name='allego.RadiensCore.FeatureStop',
    index=68,
    containing_service=None,
    input_type=common__pb2._FEATURESTARTSTOPREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPrivacy',
    full_name='allego.RadiensCore.GetPrivacy',
    index=69,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._PRIVACYREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetPrivacy',
    full_name='allego.RadiensCore.SetPrivacy',
    index=70,
    containing_service=None,
    input_type=common__pb2._SETPRIVACYREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSignalGroup',
    full_name='allego.RadiensCore.DeleteSignalGroup',
    index=71,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesGetSignalGroup',
    full_name='allego.RadiensCore.SpikesGetSignalGroup',
    index=72,
    containing_service=None,
    input_type=common__pb2._SIGNALGROUPIDREQUEST,
    output_type=common__pb2._SIGNALGROUP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetProtocol',
    full_name='allego.RadiensCore.SetProtocol',
    index=73,
    containing_service=None,
    input_type=common__pb2._PROTOCOL,
    output_type=common__pb2._PROTOCOL,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetProtocol',
    full_name='allego.RadiensCore.GetProtocol',
    index=74,
    containing_service=None,
    input_type=common__pb2._PROTOCOLREQUEST,
    output_type=common__pb2._PROTOCOL,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RenameProtocol',
    full_name='allego.RadiensCore.RenameProtocol',
    index=75,
    containing_service=None,
    input_type=common__pb2._RENAMEPROTOCOLREQUEST,
    output_type=common__pb2._PROTOCOL,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllProtocols',
    full_name='allego.RadiensCore.GetAllProtocols',
    index=76,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._GETALLPROTOCOLSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ApplyProtocol',
    full_name='allego.RadiensCore.ApplyProtocol',
    index=77,
    containing_service=None,
    input_type=common__pb2._PROTOCOLREQUEST,
    output_type=common__pb2._APPLYPROTOCOLPROGRESS,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RADIENSCORE)

DESCRIPTOR.services_by_name['RadiensCore'] = _RADIENSCORE


_RADIENSSPIKESORTER1 = _descriptor.ServiceDescriptor(
  name='RadiensSpikeSorter1',
  full_name='allego.RadiensSpikeSorter1',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=6387,
  serialized_end=7276,
  methods=[
  _descriptor.MethodDescriptor(
    name='Healthcheck',
    full_name='allego.RadiensSpikeSorter1.Healthcheck',
    index=0,
    containing_service=None,
    input_type=_RADIENSHEALTHCHECKREQUEST,
    output_type=_RADIENSHEALTHCHECKSPEC,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterCommand',
    full_name='allego.RadiensSpikeSorter1.SpikeSorterCommand',
    index=1,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERCOMMANDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterSetParam',
    full_name='allego.RadiensSpikeSorter1.SpikeSorterSetParam',
    index=2,
    containing_service=None,
    input_type=common__pb2._SPIKESORTERSETPARAMREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterGetParam',
    full_name='allego.RadiensSpikeSorter1.SpikeSorterGetParam',
    index=3,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERSTANDARDREQUEST,
    output_type=spikesorter__pb2._GETSPIKESORTERPARAMCOMMANDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterGetState',
    full_name='allego.RadiensSpikeSorter1.SpikeSorterGetState',
    index=4,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERSTANDARDREQUEST,
    output_type=spikesorter__pb2._SPIKESORTERSTATE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterGetDashboard',
    full_name='allego.RadiensSpikeSorter1.SpikeSorterGetDashboard',
    index=5,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERSTANDARDREQUEST,
    output_type=spikesorter__pb2._SPIKESORTERGETDASHBOARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterWrangleData',
    full_name='allego.RadiensSpikeSorter1.SpikeSorterWrangleData',
    index=6,
    containing_service=None,
    input_type=common__pb2._WRANGLEREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterLaunch',
    full_name='allego.RadiensSpikeSorter1.SpikeSorterLaunch',
    index=7,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERLAUNCHREQUEST,
    output_type=spikesorter__pb2._SPIKESORTERLAUNCHREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikeSorterDelete',
    full_name='allego.RadiensSpikeSorter1.SpikeSorterDelete',
    index=8,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERSTANDARDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpikesGetSpec',
    full_name='allego.RadiensSpikeSorter1.SpikesGetSpec',
    index=9,
    containing_service=None,
    input_type=spikesorter__pb2._SPIKESORTERSTANDARDREQUEST,
    output_type=biointerface__pb2._SPIKESSPECREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RADIENSSPIKESORTER1)

DESCRIPTOR.services_by_name['RadiensSpikeSorter1'] = _RADIENSSPIKESORTER1


_RADIENSDEV1 = _descriptor.ServiceDescriptor(
  name='RadiensDev1',
  full_name='allego.RadiensDev1',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  serialized_start=7279,
  serialized_end=7846,
  methods=[
  _descriptor.MethodDescriptor(
    name='Healthcheck',
    full_name='allego.RadiensDev1.Healthcheck',
    index=0,
    containing_service=None,
    input_type=_RADIENSHEALTHCHECKREQUEST,
    output_type=_RADIENSHEALTHCHECKSPEC,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpkSortTrainerMakeNewModel',
    full_name='allego.RadiensDev1.SpkSortTrainerMakeNewModel',
    index=1,
    containing_service=None,
    input_type=radiens__dev__pb2._SPKSORTTRAINERNEWREQ,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpkSortTrainerMakeDefaultProdModels',
    full_name='allego.RadiensDev1.SpkSortTrainerMakeDefaultProdModels',
    index=2,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpkSortTrainerListLocalNetworkModels',
    full_name='allego.RadiensDev1.SpkSortTrainerListLocalNetworkModels',
    index=3,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=radiens__dev__pb2._SPKSORTTRAINERSTATUSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpkSortTrainerDeleteLocalNetworkModels',
    full_name='allego.RadiensDev1.SpkSortTrainerDeleteLocalNetworkModels',
    index=4,
    containing_service=None,
    input_type=radiens__dev__pb2._SPKSORTTRAINERDELETEMODELREQ,
    output_type=common__pb2._STANDARDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SpkSortTrainerGetStatus',
    full_name='allego.RadiensDev1.SpkSortTrainerGetStatus',
    index=5,
    containing_service=None,
    input_type=common__pb2._STANDARDREQUEST,
    output_type=radiens__dev__pb2._SPKSORTTRAINERSTATUSREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RADIENSDEV1)

DESCRIPTOR.services_by_name['RadiensDev1'] = _RADIENSDEV1

# @@protoc_insertion_point(module_scope)
