# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: datasource.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='datasource.proto',
  package='allego',
  syntax='proto2',
  serialized_options=b'Z\023internal/radix/grpc',
  serialized_pb=b'\n\x10\x64\x61tasource.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"<\n\x11\x44\x61taSourceRequest\x12\x11\n\tdsourceID\x18\x01 \x03(\t\x12\x14\n\x0crenameDsrcID\x18\x02 \x01(\t\"\xae\x01\n\x18\x44\x61taSourceSetSaveRequest\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x02 \x02(\t\x12\x11\n\tdsourceID\x18\x03 \x01(\t\x12\x0b\n\x03uID\x18\x04 \x01(\t\x12(\n\x08\x66ileType\x18\x05 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x0f\n\x07isForce\x18\x06 \x01(\x08\x12\x17\n\x0fisBackgroundKPI\x18\x07 \x01(\x08\"%\n\x11\x44\x61taSourceIDReply\x12\x10\n\x08sortedID\x18\x01 \x03(\t\"\x95\x01\n\x16\x44\x61taSourceSetSaveReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12(\n\x06status\x18\x02 \x01(\x0b\x32\x18.allego.DataSourceStatus\x12\r\n\x05niIDs\x18\x03 \x03(\t\x12/\n\x0f\x61ssociatedDsrcs\x18\x04 \x03(\x0b\x32\x16.allego.FileDescriptor\"\xae\x01\n\x13\x44\x61taSourceStatusMap\x12\x39\n\x07\x64source\x18\x01 \x03(\x0b\x32(.allego.DataSourceStatusMap.DsourceEntry\x12\x12\n\norderedIDs\x18\x02 \x03(\t\x1aH\n\x0c\x44sourceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.allego.DataSourceStatus:\x02\x38\x01\"\xa1\x03\n\x1f\x43opyRemoveDataSourceFileRequest\x12\x45\n\x04many\x18\x01 \x01(\x0b\x32\x35.allego.CopyRemoveDataSourceFileRequest.MultipleFilesH\x00\x12>\n\x03one\x18\x02 \x01(\x0b\x32/.allego.CopyRemoveDataSourceFileRequest.OneFileH\x00\x12\x0f\n\x07isForce\x18\x03 \x01(\x08\x12\x12\n\nisValidate\x18\x04 \x01(\x08\x1at\n\rMultipleFiles\x12#\n\x03src\x18\x01 \x03(\x0b\x32\x16.allego.FileDescriptor\x12\x10\n\x08\x64\x65stPath\x18\x02 \x01(\t\x12,\n\x0c\x64\x65stFileType\x18\x03 \x01(\x0e\x32\x16.allego.RadixFileTypes\x1aT\n\x07OneFile\x12#\n\x03src\x18\x01 \x02(\x0b\x32\x16.allego.FileDescriptor\x12$\n\x04\x64\x65st\x18\x02 \x01(\x0b\x32\x16.allego.FileDescriptorB\x06\n\x04\x64\x65sc\"\xf8\x02\n\x15\x44\x61taSourceFileSetStat\x12\x10\n\x08numFiles\x18\x01 \x02(\x05\x12\x1b\n\x13numBytesPrimaryData\x18\x02 \x02(\x03\x12\x18\n\x10numBytesMetaData\x18\x03 \x02(\x03\x12\x10\n\x08numBytes\x18\x04 \x02(\x03\x12\x16\n\x0eisMetadataFile\x18\x05 \x02(\x08\x12-\n\ttimeStamp\x18\x06 \x02(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bnumChannels\x18\x07 \x02(\x05\x12\x13\n\x0b\x64urationSec\x18\x08 \x02(\x01\x12\x12\n\ndatasetUID\x18\t \x02(\t\x12\x17\n\x0f\x64\x61tasetChecksum\x18\n \x01(\t\x12\x19\n\x11\x64\x61tasetProvenance\x18\x0b \x03(\t\x12\x12\n\nsampleRate\x18\x0c \x02(\x05\x12\x37\n\x0e\x62\x61\x63kgroundProc\x18\r \x01(\x0b\x32\x1f.allego.BackgroundProcessStatus\"\x82\x02\n\rCpRmMvLsReply\x12\x10\n\x08numFiles\x18\x01 \x02(\x05\x12\x12\n\nnumDsource\x18\x02 \x02(\x05\x12\x10\n\x08numBytes\x18\x03 \x02(\x03\x12\x10\n\x08\x64\x65stPath\x18\x04 \x02(\t\x12\x35\n\x07\x64source\x18\x05 \x03(\x0b\x32$.allego.CpRmMvLsReply.DataSourceInfo\x12\x0b\n\x03msg\x18\x06 \x01(\t\x1a\x63\n\x0e\x44\x61taSourceInfo\x12$\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x16.allego.FileDescriptor\x12+\n\x04stat\x18\x02 \x02(\x0b\x32\x1d.allego.DataSourceFileSetStat\"y\n\x17\x42\x61\x63kgroundProcessStatus\x12\x0b\n\x03uID\x18\x01 \x02(\t\x12\x14\n\x0c\x66racComplete\x18\x02 \x01(\x01\x12\x16\n\x0e\x65lapsedTimeSec\x18\x03 \x01(\x01\x12#\n\x1b\x65stimatedCompletionWallTime\x18\x04 \x01(\t\"\x8b\x01\n\x19MoveDataSourceFileRequest\x12#\n\x03src\x18\x01 \x02(\x0b\x32\x16.allego.FileDescriptor\x12$\n\x04\x64\x65st\x18\x02 \x02(\x0b\x32\x16.allego.FileDescriptor\x12\x0f\n\x07isForce\x18\x03 \x01(\x08\x12\x12\n\nisValidate\x18\x04 \x01(\x08\"\xc5\x02\n\x10\x44\x61taSourceStatus\x12%\n\x04type\x18\x01 \x02(\x0e\x32\x17.allego.SignalGroupType\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\x12\x10\n\x08\x64uration\x18\x04 \x02(\x01\x12(\n\x0bsignalGroup\x18\x06 \x02(\x0b\x32\x13.allego.SignalGroup\x12\x17\n\x0fnumTotalSamples\x18\x07 \x02(\x03\x12\x12\n\nsampleFreq\x18\t \x02(\x01\x12\x0b\n\x03uid\x18\n \x02(\t\x12\x16\n\x0e\x64\x61taSourceType\x18\x0b \x02(\t\x12\x10\n\x08\x66ileType\x18\x0c \x02(\t\x12\x0c\n\x04mode\x18\r \x02(\t\x12\r\n\x05label\x18\x0e \x02(\t\x12\x0c\n\x04path\x18\x0f \x02(\t\x12\x14\n\x0c\x62\x61seFileName\x18\x10 \x02(\t\"\xbf\x01\n\x10\x44\x61taSourceParams\x12\x12\n\nsampleFreq\x18\x01 \x02(\x01\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x10\n\x08\x64uration\x18\x03 \x02(\x01\x12%\n\x04type\x18\x05 \x02(\x0e\x32\x17.allego.SignalGroupType\x12\x35\n\x0e\x64\x61tasourceType\x18\x06 \x01(\x0e\x32\x1d.allego.RadiensDatasourceType\x12\x14\n\x0c\x64\x61tasourceID\x18\x07 \x01(\t\".\n\x10ImpedanceRequest\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\"\x85\x01\n\tImpedance\x12\x34\n\nimpedances\x18\x01 \x03(\x0b\x32 .allego.Impedance.ImpedanceValue\x1a\x42\n\x0eImpedanceValue\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\x0c\n\x04zMag\x18\x02 \x02(\x01\x12\x0e\n\x06zPhase\x18\x03 \x02(\x01*0\n\x15RadiensDatasourceType\x12\x07\n\x03\x41NY\x10\x00\x12\x0e\n\nTIMESERIES\x10\x01\x42\x15Z\x13internal/radix/grpc'
  ,
  dependencies=[common__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_RADIENSDATASOURCETYPE = _descriptor.EnumDescriptor(
  name='RadiensDatasourceType',
  full_name='allego.RadiensDatasourceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ANY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMESERIES', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2713,
  serialized_end=2761,
)
_sym_db.RegisterEnumDescriptor(_RADIENSDATASOURCETYPE)

RadiensDatasourceType = enum_type_wrapper.EnumTypeWrapper(_RADIENSDATASOURCETYPE)
ANY = 0
TIMESERIES = 1



_DATASOURCEREQUEST = _descriptor.Descriptor(
  name='DataSourceRequest',
  full_name='allego.DataSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.DataSourceRequest.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='renameDsrcID', full_name='allego.DataSourceRequest.renameDsrcID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=135,
)


_DATASOURCESETSAVEREQUEST = _descriptor.Descriptor(
  name='DataSourceSetSaveRequest',
  full_name='allego.DataSourceSetSaveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='allego.DataSourceSetSaveRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseName', full_name='allego.DataSourceSetSaveRequest.baseName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.DataSourceSetSaveRequest.dsourceID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uID', full_name='allego.DataSourceSetSaveRequest.uID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileType', full_name='allego.DataSourceSetSaveRequest.fileType', index=4,
      number=5, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isForce', full_name='allego.DataSourceSetSaveRequest.isForce', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isBackgroundKPI', full_name='allego.DataSourceSetSaveRequest.isBackgroundKPI', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=312,
)


_DATASOURCEIDREPLY = _descriptor.Descriptor(
  name='DataSourceIDReply',
  full_name='allego.DataSourceIDReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sortedID', full_name='allego.DataSourceIDReply.sortedID', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=351,
)


_DATASOURCESETSAVEREPLY = _descriptor.Descriptor(
  name='DataSourceSetSaveReply',
  full_name='allego.DataSourceSetSaveReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.DataSourceSetSaveReply.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='allego.DataSourceSetSaveReply.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='niIDs', full_name='allego.DataSourceSetSaveReply.niIDs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='associatedDsrcs', full_name='allego.DataSourceSetSaveReply.associatedDsrcs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=503,
)


_DATASOURCESTATUSMAP_DSOURCEENTRY = _descriptor.Descriptor(
  name='DsourceEntry',
  full_name='allego.DataSourceStatusMap.DsourceEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.DataSourceStatusMap.DsourceEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.DataSourceStatusMap.DsourceEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=608,
  serialized_end=680,
)

_DATASOURCESTATUSMAP = _descriptor.Descriptor(
  name='DataSourceStatusMap',
  full_name='allego.DataSourceStatusMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsource', full_name='allego.DataSourceStatusMap.dsource', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orderedIDs', full_name='allego.DataSourceStatusMap.orderedIDs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATASOURCESTATUSMAP_DSOURCEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=506,
  serialized_end=680,
)


_COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES = _descriptor.Descriptor(
  name='MultipleFiles',
  full_name='allego.CopyRemoveDataSourceFileRequest.MultipleFiles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='allego.CopyRemoveDataSourceFileRequest.MultipleFiles.src', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destPath', full_name='allego.CopyRemoveDataSourceFileRequest.MultipleFiles.destPath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destFileType', full_name='allego.CopyRemoveDataSourceFileRequest.MultipleFiles.destFileType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=1006,
)

_COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE = _descriptor.Descriptor(
  name='OneFile',
  full_name='allego.CopyRemoveDataSourceFileRequest.OneFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='allego.CopyRemoveDataSourceFileRequest.OneFile.src', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dest', full_name='allego.CopyRemoveDataSourceFileRequest.OneFile.dest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1092,
)

_COPYREMOVEDATASOURCEFILEREQUEST = _descriptor.Descriptor(
  name='CopyRemoveDataSourceFileRequest',
  full_name='allego.CopyRemoveDataSourceFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='many', full_name='allego.CopyRemoveDataSourceFileRequest.many', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one', full_name='allego.CopyRemoveDataSourceFileRequest.one', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isForce', full_name='allego.CopyRemoveDataSourceFileRequest.isForce', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isValidate', full_name='allego.CopyRemoveDataSourceFileRequest.isValidate', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES, _COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='desc', full_name='allego.CopyRemoveDataSourceFileRequest.desc',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=683,
  serialized_end=1100,
)


_DATASOURCEFILESETSTAT = _descriptor.Descriptor(
  name='DataSourceFileSetStat',
  full_name='allego.DataSourceFileSetStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numFiles', full_name='allego.DataSourceFileSetStat.numFiles', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numBytesPrimaryData', full_name='allego.DataSourceFileSetStat.numBytesPrimaryData', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numBytesMetaData', full_name='allego.DataSourceFileSetStat.numBytesMetaData', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numBytes', full_name='allego.DataSourceFileSetStat.numBytes', index=3,
      number=4, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isMetadataFile', full_name='allego.DataSourceFileSetStat.isMetadataFile', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeStamp', full_name='allego.DataSourceFileSetStat.timeStamp', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numChannels', full_name='allego.DataSourceFileSetStat.numChannels', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='durationSec', full_name='allego.DataSourceFileSetStat.durationSec', index=7,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasetUID', full_name='allego.DataSourceFileSetStat.datasetUID', index=8,
      number=9, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasetChecksum', full_name='allego.DataSourceFileSetStat.datasetChecksum', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasetProvenance', full_name='allego.DataSourceFileSetStat.datasetProvenance', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampleRate', full_name='allego.DataSourceFileSetStat.sampleRate', index=11,
      number=12, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backgroundProc', full_name='allego.DataSourceFileSetStat.backgroundProc', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1103,
  serialized_end=1479,
)


_CPRMMVLSREPLY_DATASOURCEINFO = _descriptor.Descriptor(
  name='DataSourceInfo',
  full_name='allego.CpRmMvLsReply.DataSourceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='allego.CpRmMvLsReply.DataSourceInfo.desc', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stat', full_name='allego.CpRmMvLsReply.DataSourceInfo.stat', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1641,
  serialized_end=1740,
)

_CPRMMVLSREPLY = _descriptor.Descriptor(
  name='CpRmMvLsReply',
  full_name='allego.CpRmMvLsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numFiles', full_name='allego.CpRmMvLsReply.numFiles', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numDsource', full_name='allego.CpRmMvLsReply.numDsource', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numBytes', full_name='allego.CpRmMvLsReply.numBytes', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destPath', full_name='allego.CpRmMvLsReply.destPath', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dsource', full_name='allego.CpRmMvLsReply.dsource', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='allego.CpRmMvLsReply.msg', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CPRMMVLSREPLY_DATASOURCEINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1482,
  serialized_end=1740,
)


_BACKGROUNDPROCESSSTATUS = _descriptor.Descriptor(
  name='BackgroundProcessStatus',
  full_name='allego.BackgroundProcessStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uID', full_name='allego.BackgroundProcessStatus.uID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fracComplete', full_name='allego.BackgroundProcessStatus.fracComplete', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elapsedTimeSec', full_name='allego.BackgroundProcessStatus.elapsedTimeSec', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='estimatedCompletionWallTime', full_name='allego.BackgroundProcessStatus.estimatedCompletionWallTime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1742,
  serialized_end=1863,
)


_MOVEDATASOURCEFILEREQUEST = _descriptor.Descriptor(
  name='MoveDataSourceFileRequest',
  full_name='allego.MoveDataSourceFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='allego.MoveDataSourceFileRequest.src', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dest', full_name='allego.MoveDataSourceFileRequest.dest', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isForce', full_name='allego.MoveDataSourceFileRequest.isForce', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isValidate', full_name='allego.MoveDataSourceFileRequest.isValidate', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1866,
  serialized_end=2005,
)


_DATASOURCESTATUS = _descriptor.Descriptor(
  name='DataSourceStatus',
  full_name='allego.DataSourceStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='allego.DataSourceStatus.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.DataSourceStatus.timeRange', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.DataSourceStatus.timestampRange', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='allego.DataSourceStatus.duration', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signalGroup', full_name='allego.DataSourceStatus.signalGroup', index=4,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numTotalSamples', full_name='allego.DataSourceStatus.numTotalSamples', index=5,
      number=7, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampleFreq', full_name='allego.DataSourceStatus.sampleFreq', index=6,
      number=9, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='allego.DataSourceStatus.uid', index=7,
      number=10, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSourceType', full_name='allego.DataSourceStatus.dataSourceType', index=8,
      number=11, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileType', full_name='allego.DataSourceStatus.fileType', index=9,
      number=12, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.DataSourceStatus.mode', index=10,
      number=13, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='allego.DataSourceStatus.label', index=11,
      number=14, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='allego.DataSourceStatus.path', index=12,
      number=15, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseFileName', full_name='allego.DataSourceStatus.baseFileName', index=13,
      number=16, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2008,
  serialized_end=2333,
)


_DATASOURCEPARAMS = _descriptor.Descriptor(
  name='DataSourceParams',
  full_name='allego.DataSourceParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sampleFreq', full_name='allego.DataSourceParams.sampleFreq', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.DataSourceParams.timeRange', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='allego.DataSourceParams.duration', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='allego.DataSourceParams.type', index=3,
      number=5, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasourceType', full_name='allego.DataSourceParams.datasourceType', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasourceID', full_name='allego.DataSourceParams.datasourceID', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2336,
  serialized_end=2527,
)


_IMPEDANCEREQUEST = _descriptor.Descriptor(
  name='ImpedanceRequest',
  full_name='allego.ImpedanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.ImpedanceRequest.port', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2529,
  serialized_end=2575,
)


_IMPEDANCE_IMPEDANCEVALUE = _descriptor.Descriptor(
  name='ImpedanceValue',
  full_name='allego.Impedance.ImpedanceValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.Impedance.ImpedanceValue.ntvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zMag', full_name='allego.Impedance.ImpedanceValue.zMag', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zPhase', full_name='allego.Impedance.ImpedanceValue.zPhase', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2645,
  serialized_end=2711,
)

_IMPEDANCE = _descriptor.Descriptor(
  name='Impedance',
  full_name='allego.Impedance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='impedances', full_name='allego.Impedance.impedances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_IMPEDANCE_IMPEDANCEVALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2578,
  serialized_end=2711,
)

_DATASOURCESETSAVEREQUEST.fields_by_name['fileType'].enum_type = common__pb2._RADIXFILETYPES
_DATASOURCESETSAVEREPLY.fields_by_name['status'].message_type = _DATASOURCESTATUS
_DATASOURCESETSAVEREPLY.fields_by_name['associatedDsrcs'].message_type = common__pb2._FILEDESCRIPTOR
_DATASOURCESTATUSMAP_DSOURCEENTRY.fields_by_name['value'].message_type = _DATASOURCESTATUS
_DATASOURCESTATUSMAP_DSOURCEENTRY.containing_type = _DATASOURCESTATUSMAP
_DATASOURCESTATUSMAP.fields_by_name['dsource'].message_type = _DATASOURCESTATUSMAP_DSOURCEENTRY
_COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES.fields_by_name['src'].message_type = common__pb2._FILEDESCRIPTOR
_COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES.fields_by_name['destFileType'].enum_type = common__pb2._RADIXFILETYPES
_COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES.containing_type = _COPYREMOVEDATASOURCEFILEREQUEST
_COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE.fields_by_name['src'].message_type = common__pb2._FILEDESCRIPTOR
_COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE.fields_by_name['dest'].message_type = common__pb2._FILEDESCRIPTOR
_COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE.containing_type = _COPYREMOVEDATASOURCEFILEREQUEST
_COPYREMOVEDATASOURCEFILEREQUEST.fields_by_name['many'].message_type = _COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES
_COPYREMOVEDATASOURCEFILEREQUEST.fields_by_name['one'].message_type = _COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE
_COPYREMOVEDATASOURCEFILEREQUEST.oneofs_by_name['desc'].fields.append(
  _COPYREMOVEDATASOURCEFILEREQUEST.fields_by_name['many'])
_COPYREMOVEDATASOURCEFILEREQUEST.fields_by_name['many'].containing_oneof = _COPYREMOVEDATASOURCEFILEREQUEST.oneofs_by_name['desc']
_COPYREMOVEDATASOURCEFILEREQUEST.oneofs_by_name['desc'].fields.append(
  _COPYREMOVEDATASOURCEFILEREQUEST.fields_by_name['one'])
_COPYREMOVEDATASOURCEFILEREQUEST.fields_by_name['one'].containing_oneof = _COPYREMOVEDATASOURCEFILEREQUEST.oneofs_by_name['desc']
_DATASOURCEFILESETSTAT.fields_by_name['timeStamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATASOURCEFILESETSTAT.fields_by_name['backgroundProc'].message_type = _BACKGROUNDPROCESSSTATUS
_CPRMMVLSREPLY_DATASOURCEINFO.fields_by_name['desc'].message_type = common__pb2._FILEDESCRIPTOR
_CPRMMVLSREPLY_DATASOURCEINFO.fields_by_name['stat'].message_type = _DATASOURCEFILESETSTAT
_CPRMMVLSREPLY_DATASOURCEINFO.containing_type = _CPRMMVLSREPLY
_CPRMMVLSREPLY.fields_by_name['dsource'].message_type = _CPRMMVLSREPLY_DATASOURCEINFO
_MOVEDATASOURCEFILEREQUEST.fields_by_name['src'].message_type = common__pb2._FILEDESCRIPTOR
_MOVEDATASOURCEFILEREQUEST.fields_by_name['dest'].message_type = common__pb2._FILEDESCRIPTOR
_DATASOURCESTATUS.fields_by_name['type'].enum_type = common__pb2._SIGNALGROUPTYPE
_DATASOURCESTATUS.fields_by_name['signalGroup'].message_type = common__pb2._SIGNALGROUP
_DATASOURCEPARAMS.fields_by_name['type'].enum_type = common__pb2._SIGNALGROUPTYPE
_DATASOURCEPARAMS.fields_by_name['datasourceType'].enum_type = _RADIENSDATASOURCETYPE
_IMPEDANCEREQUEST.fields_by_name['port'].enum_type = common__pb2._PORT
_IMPEDANCE_IMPEDANCEVALUE.containing_type = _IMPEDANCE
_IMPEDANCE.fields_by_name['impedances'].message_type = _IMPEDANCE_IMPEDANCEVALUE
DESCRIPTOR.message_types_by_name['DataSourceRequest'] = _DATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['DataSourceSetSaveRequest'] = _DATASOURCESETSAVEREQUEST
DESCRIPTOR.message_types_by_name['DataSourceIDReply'] = _DATASOURCEIDREPLY
DESCRIPTOR.message_types_by_name['DataSourceSetSaveReply'] = _DATASOURCESETSAVEREPLY
DESCRIPTOR.message_types_by_name['DataSourceStatusMap'] = _DATASOURCESTATUSMAP
DESCRIPTOR.message_types_by_name['CopyRemoveDataSourceFileRequest'] = _COPYREMOVEDATASOURCEFILEREQUEST
DESCRIPTOR.message_types_by_name['DataSourceFileSetStat'] = _DATASOURCEFILESETSTAT
DESCRIPTOR.message_types_by_name['CpRmMvLsReply'] = _CPRMMVLSREPLY
DESCRIPTOR.message_types_by_name['BackgroundProcessStatus'] = _BACKGROUNDPROCESSSTATUS
DESCRIPTOR.message_types_by_name['MoveDataSourceFileRequest'] = _MOVEDATASOURCEFILEREQUEST
DESCRIPTOR.message_types_by_name['DataSourceStatus'] = _DATASOURCESTATUS
DESCRIPTOR.message_types_by_name['DataSourceParams'] = _DATASOURCEPARAMS
DESCRIPTOR.message_types_by_name['ImpedanceRequest'] = _IMPEDANCEREQUEST
DESCRIPTOR.message_types_by_name['Impedance'] = _IMPEDANCE
DESCRIPTOR.enum_types_by_name['RadiensDatasourceType'] = _RADIENSDATASOURCETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataSourceRequest = _reflection.GeneratedProtocolMessageType('DataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceRequest)
  })
_sym_db.RegisterMessage(DataSourceRequest)

DataSourceSetSaveRequest = _reflection.GeneratedProtocolMessageType('DataSourceSetSaveRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESETSAVEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceSetSaveRequest)
  })
_sym_db.RegisterMessage(DataSourceSetSaveRequest)

DataSourceIDReply = _reflection.GeneratedProtocolMessageType('DataSourceIDReply', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEIDREPLY,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceIDReply)
  })
_sym_db.RegisterMessage(DataSourceIDReply)

DataSourceSetSaveReply = _reflection.GeneratedProtocolMessageType('DataSourceSetSaveReply', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESETSAVEREPLY,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceSetSaveReply)
  })
_sym_db.RegisterMessage(DataSourceSetSaveReply)

DataSourceStatusMap = _reflection.GeneratedProtocolMessageType('DataSourceStatusMap', (_message.Message,), {

  'DsourceEntry' : _reflection.GeneratedProtocolMessageType('DsourceEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASOURCESTATUSMAP_DSOURCEENTRY,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.DataSourceStatusMap.DsourceEntry)
    })
  ,
  'DESCRIPTOR' : _DATASOURCESTATUSMAP,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceStatusMap)
  })
_sym_db.RegisterMessage(DataSourceStatusMap)
_sym_db.RegisterMessage(DataSourceStatusMap.DsourceEntry)

CopyRemoveDataSourceFileRequest = _reflection.GeneratedProtocolMessageType('CopyRemoveDataSourceFileRequest', (_message.Message,), {

  'MultipleFiles' : _reflection.GeneratedProtocolMessageType('MultipleFiles', (_message.Message,), {
    'DESCRIPTOR' : _COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.CopyRemoveDataSourceFileRequest.MultipleFiles)
    })
  ,

  'OneFile' : _reflection.GeneratedProtocolMessageType('OneFile', (_message.Message,), {
    'DESCRIPTOR' : _COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.CopyRemoveDataSourceFileRequest.OneFile)
    })
  ,
  'DESCRIPTOR' : _COPYREMOVEDATASOURCEFILEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.CopyRemoveDataSourceFileRequest)
  })
_sym_db.RegisterMessage(CopyRemoveDataSourceFileRequest)
_sym_db.RegisterMessage(CopyRemoveDataSourceFileRequest.MultipleFiles)
_sym_db.RegisterMessage(CopyRemoveDataSourceFileRequest.OneFile)

DataSourceFileSetStat = _reflection.GeneratedProtocolMessageType('DataSourceFileSetStat', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEFILESETSTAT,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceFileSetStat)
  })
_sym_db.RegisterMessage(DataSourceFileSetStat)

CpRmMvLsReply = _reflection.GeneratedProtocolMessageType('CpRmMvLsReply', (_message.Message,), {

  'DataSourceInfo' : _reflection.GeneratedProtocolMessageType('DataSourceInfo', (_message.Message,), {
    'DESCRIPTOR' : _CPRMMVLSREPLY_DATASOURCEINFO,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.CpRmMvLsReply.DataSourceInfo)
    })
  ,
  'DESCRIPTOR' : _CPRMMVLSREPLY,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.CpRmMvLsReply)
  })
_sym_db.RegisterMessage(CpRmMvLsReply)
_sym_db.RegisterMessage(CpRmMvLsReply.DataSourceInfo)

BackgroundProcessStatus = _reflection.GeneratedProtocolMessageType('BackgroundProcessStatus', (_message.Message,), {
  'DESCRIPTOR' : _BACKGROUNDPROCESSSTATUS,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.BackgroundProcessStatus)
  })
_sym_db.RegisterMessage(BackgroundProcessStatus)

MoveDataSourceFileRequest = _reflection.GeneratedProtocolMessageType('MoveDataSourceFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDATASOURCEFILEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.MoveDataSourceFileRequest)
  })
_sym_db.RegisterMessage(MoveDataSourceFileRequest)

DataSourceStatus = _reflection.GeneratedProtocolMessageType('DataSourceStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESTATUS,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceStatus)
  })
_sym_db.RegisterMessage(DataSourceStatus)

DataSourceParams = _reflection.GeneratedProtocolMessageType('DataSourceParams', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEPARAMS,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceParams)
  })
_sym_db.RegisterMessage(DataSourceParams)

ImpedanceRequest = _reflection.GeneratedProtocolMessageType('ImpedanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPEDANCEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.ImpedanceRequest)
  })
_sym_db.RegisterMessage(ImpedanceRequest)

Impedance = _reflection.GeneratedProtocolMessageType('Impedance', (_message.Message,), {

  'ImpedanceValue' : _reflection.GeneratedProtocolMessageType('ImpedanceValue', (_message.Message,), {
    'DESCRIPTOR' : _IMPEDANCE_IMPEDANCEVALUE,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.Impedance.ImpedanceValue)
    })
  ,
  'DESCRIPTOR' : _IMPEDANCE,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.Impedance)
  })
_sym_db.RegisterMessage(Impedance)
_sym_db.RegisterMessage(Impedance.ImpedanceValue)


DESCRIPTOR._options = None
_DATASOURCESTATUSMAP_DSOURCEENTRY._options = None
# @@protoc_insertion_point(module_scope)
