# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='common.proto',
  package='allego',
  syntax='proto2',
  serialized_options=b'Z\023internal/radix/grpc',
  serialized_pb=b'\n\x0c\x63ommon.proto\x12\x06\x61llego\"9\n\x10RadixEnvironment\x12\x0f\n\x07version\x18\x01 \x02(\t\x12\x14\n\x0cuserDataPath\x18\x02 \x02(\t\"\x11\n\x0fStandardRequest\"\x1f\n\rStandardReply\x12\x0e\n\x06\x65rrMsg\x18\x01 \x01(\t\"&\n\rDACOffRequest\x12\x15\n\rstreamGroupId\x18\x01 \x01(\t\"\xba\x01\n\x13WorkspaceDescriptor\x12\n\n\x02iD\x18\x01 \x02(\t\x12!\n\x03\x61pp\x18\x02 \x02(\x0e\x32\x14.allego.WorkspaceApp\x12\x12\n\nisModified\x18\x03 \x02(\x08\x12\x19\n\x11timestampLastUsed\x18\x04 \x02(\t\x12\x19\n\x11timestampModified\x18\x05 \x02(\t\x12*\n\nannotation\x18\x06 \x02(\x0b\x32\x16.allego.AnnotateBundle\"\xb8\x01\n\x17WorkspaceControlRequest\x12&\n\x03\x63md\x18\x01 \x02(\x0e\x32\x19.allego.WorkspaceCommands\x12\x13\n\x0bworkspaceID\x18\x02 \x01(\t\x12*\n\nannotation\x18\x03 \x01(\x0b\x32\x16.allego.AnnotateBundle\x12\x1a\n\x12targetFullFileName\x18\x04 \x01(\t\x12\x18\n\x10isForceOverwrite\x18\x05 \x01(\x08\"\xd3\x01\n\x13GetWorkspaceRequest\x12)\n\x03\x63md\x18\x01 \x02(\x0e\x32\x1c.allego.GetWorkspaceCommands\x12\x13\n\x0bworkspaceID\x18\x02 \x01(\t\x12\x14\n\x0cworkspaceDir\x18\x03 \x01(\t\x12%\n\x07\x61ppMask\x18\x04 \x01(\x0e\x32\x14.allego.WorkspaceApp\x12,\n\x0c\x61nnotateMask\x18\x05 \x01(\x0b\x32\x16.allego.AnnotateBundle\x12\x11\n\tisBrowser\x18\x06 \x01(\x08\"\xab\x01\n\x11GetWorkspaceReply\x12\x43\n\rworkspaceDesc\x18\x01 \x03(\x0b\x32,.allego.GetWorkspaceReply.WorkspaceDescEntry\x1aQ\n\x12WorkspaceDescEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.allego.WorkspaceDescriptor:\x02\x38\x01\"`\n\x18GetRadiensServersRequest\x12\x15\n\rhostIPaddress\x18\x01 \x02(\t\x12-\n\nserverType\x18\x02 \x01(\x0e\x32\x19.allego.RadiensServerType\"\x97\x02\n\nServerSpec\x12\x0c\n\x04host\x18\x01 \x02(\t\x12\x0b\n\x03pid\x18\x02 \x02(\x05\x12\x30\n\x07service\x18\x03 \x03(\x0b\x32\x1f.allego.ServerSpec.ServiceEntry\x12\x30\n\x05spawn\x18\x04 \x01(\x0b\x32!.allego.ServerSpec.SpawnedProcess\x1a\x1b\n\x0bGrpcService\x12\x0c\n\x04port\x18\x01 \x02(\x05\x1a\x1d\n\x0eSpawnedProcess\x12\x0b\n\x03pid\x18\x01 \x03(\x05\x1aN\n\x0cServiceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.allego.ServerSpec.GrpcService:\x02\x38\x01\"j\n\x13RadiensServersReply\x12(\n\x0c\x61llegoserver\x18\x01 \x03(\x0b\x32\x12.allego.ServerSpec\x12)\n\rradiensserver\x18\x02 \x03(\x0b\x32\x12.allego.ServerSpec\"-\n\x14SignalGroupIDRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\"\xc4\x01\n\tSignalMap\x12\x0f\n\x07siteIdx\x18\x01 \x03(\x05\x12\x13\n\x0b\x63ompSiteNum\x18\x02 \x03(\t\x12\x13\n\x0bposProbeUmX\x18\x03 \x03(\x01\x12\x13\n\x0bposProbeUmY\x18\x04 \x03(\x01\x12\x13\n\x0bposProbeUmZ\x18\x05 \x03(\x01\x12\x14\n\x0cposTissueUmX\x18\x06 \x03(\x01\x12\x14\n\x0cposTissueUmY\x18\x07 \x03(\x01\x12\x14\n\x0cposTissueUmZ\x18\x08 \x03(\x01\x12\x10\n\x08sensorID\x18\t \x03(\t\"=\n\x10GPIOChannelCount\x12\x0c\n\x04nAux\x18\x01 \x02(\x05\x12\x0c\n\x04nDin\x18\x02 \x02(\x05\x12\r\n\x05nDout\x18\x03 \x02(\x05\"D\n\x10PortChannelCount\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x14\n\x0c\x63hannelCount\x18\x02 \x02(\x05\"Q\n\x0eSetPortRequest\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x10\n\x08probeUID\x18\x02 \x02(\t\x12\x11\n\thstageUID\x18\x03 \x02(\t\"\xe2\x02\n\x11HDSnapshotRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12=\n\npriSignals\x18\x03 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x12=\n\nauxSignals\x18\x04 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x12=\n\ndinSignals\x18\x05 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x12>\n\x0b\x64outSignals\x18\x06 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x1a&\n\x0fSelectedSignals\x12\x13\n\x0bntvChanIdxs\x18\x01 \x03(\x05\"]\n\x0eHDSnapshotMeta\x12\x11\n\tglobalMin\x18\x04 \x02(\x01\x12\x11\n\tglobalMax\x18\x05 \x02(\x01\x12%\n\x08sigGroup\x18\x06 \x01(\x0b\x32\x13.allego.SignalGroup\"\x9f\x02\n\nHDSnapshot\x12$\n\x04meta\x18\x01 \x02(\x0b\x32\x16.allego.HDSnapshotMeta\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x13\n\x0btimeSamples\x18\x03 \x02(\x0c\x12#\n\x07signals\x18\x04 \x02(\x0b\x32\x12.allego.RawSignals\x12&\n\npriSignals\x18\x05 \x01(\x0b\x32\x12.allego.RawSignals\x12&\n\nauxSignals\x18\x06 \x01(\x0b\x32\x12.allego.RawSignals\x12&\n\ndinSignals\x18\x07 \x01(\x0b\x32\x12.allego.RawSignals\x12\'\n\x0b\x64outSignals\x18\x08 \x01(\x0b\x32\x12.allego.RawSignals\"\xc6\x02\n\x11GetSignalsRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x37\n\x06params\x18\x02 \x02(\x0b\x32\'.allego.GetSignalsRequest.GetSigsParams\x1a\xe0\x01\n\rGetSigsParams\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x12\x12\n\ntimeWindow\x18\x02 \x02(\x01\x12\x0f\n\x07spacing\x18\x03 \x02(\x01\x12\x11\n\tmagnitude\x18\x04 \x02(\x01\x12\x17\n\x0fplotWidthPoints\x18\x05 \x02(\x01\x12\x11\n\tgpioOnTop\x18\x06 \x02(\x08\x12\x14\n\x0c\x61uxMagnitude\x18\x07 \x02(\x01\x12\x13\n\x0b\x63omponentID\x18\x08 \x02(\t\x12-\n\x0cresampleType\x18\t \x02(\x0e\x32\x17.allego.ResampleRoutine\"<\n\nRawSignals\x12\r\n\x05shape\x18\x01 \x03(\x05\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x0c\n\x04\x64\x61ta\x18\x03 \x02(\x0c\"\x85\x02\n\x14ListSensorSpecsReply\x12\x41\n\x06probes\x18\x01 \x03(\x0b\x32\x31.allego.ListSensorSpecsReply.SpecWithChannelCount\x12\x45\n\nheadstages\x18\x02 \x03(\x0b\x32\x31.allego.ListSensorSpecsReply.SpecWithChannelCount\x12\'\n\x05ports\x18\x03 \x03(\x0b\x32\x18.allego.PortChannelCount\x1a:\n\x14SpecWithChannelCount\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x14\n\x0c\x63hannelCount\x18\x02 \x02(\x05\"S\n\x16ListDataSourcesRequest\x12\x11\n\tdirectory\x18\x01 \x02(\t\x12&\n\x06sortBy\x18\x02 \x01(\x0e\x32\x16.allego.DataSourceSort\">\n\x16GetSignalGroupIDsReply\x12\x12\n\ncontinuous\x18\x01 \x03(\t\x12\x10\n\x08\x64iscrete\x18\x02 \x03(\t\"\xaf\x01\n\nDataSource\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x02(\t\x12\x17\n\x0f\x64urationSeconds\x18\x03 \x02(\x01\x12\x17\n\x0f\x64urationMinutes\x18\x04 \x02(\x01\x12\x15\n\rdurationHours\x18\x05 \x02(\x01\x12(\n\x08\x66ileType\x18\x06 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x12\n\nnumSignals\x18\x07 \x02(\x05\"o\n\x0e\x46ileDescriptor\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x02 \x02(\t\x12(\n\x08\x66ileType\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x13\n\x0b\x66ileNameUID\x18\x04 \x01(\t\"\xd0\x01\n\x08TimeSpec\x12\x30\n\ttimeRange\x18\x01 \x01(\x0b\x32\x1b.allego.TimeSpec.TimeRangeLH\x00\x12:\n\x0etimestampRange\x18\x02 \x01(\x0b\x32 .allego.TimeSpec.TimestampRangeLH\x00\x1a\x1f\n\nTimeRangeL\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x1a)\n\x0fTimestampRangeL\x12\x16\n\x0etimestampRange\x18\x01 \x03(\x03\x42\n\n\x08timeDesc\"\xbe\x01\n\nSignalSpec\x12.\n\x07siteNum\x18\x01 \x01(\x0b\x32\x1b.allego.SignalSpec.SiteNumLH\x00\x12\x34\n\nntvChanIdx\x18\x02 \x01(\x0b\x32\x1e.allego.SignalSpec.NtvChanIdxLH\x00\x1a\x1b\n\x08SiteNumL\x12\x0f\n\x07siteNum\x18\x01 \x03(\x05\x1a!\n\x0bNtvChanIdxL\x12\x12\n\nntvChanIdx\x18\x01 \x03(\x05\x42\n\n\x08siteDesc\"\xf9\x05\n\rChannelRecord\x12\x10\n\x08\x63hanName\x18\x01 \x02(\t\x12$\n\x08\x63hanType\x18\x02 \x02(\x0e\x32\x12.allego.SignalType\x12\x12\n\nntvChanIdx\x18\x03 \x02(\x05\x12\x0f\n\x07siteNum\x18\x04 \x02(\x05\x12\x15\n\rcolorGroupIdx\x18\x05 \x02(\x05\x12\x12\n\nisSelected\x18\x06 \x02(\x08\x12\x13\n\x0bisAudioLeft\x18\x07 \x02(\x08\x12\x1a\n\x04port\x18\x08 \x02(\x0e\x32\x0c.allego.Port\x12\x11\n\tsiteShape\x18\t \x02(\t\x12\x10\n\x08siteCtrX\x18\n \x02(\x01\x12\x10\n\x08siteCtrY\x18\x0b \x02(\x01\x12\x10\n\x08siteCtrZ\x18\x0c \x02(\x01\x12\x13\n\x0bsiteLimXMin\x18\r \x02(\x01\x12\x13\n\x0bsiteLimXMax\x18\x0e \x02(\x01\x12\x13\n\x0bsiteLimYMin\x18\x0f \x02(\x01\x12\x13\n\x0bsiteLimYMax\x18\x10 \x02(\x01\x12\x13\n\x0bsiteLimZMin\x18\x11 \x02(\x01\x12\x13\n\x0bsiteLimZMax\x18\x12 \x02(\x01\x12\x13\n\x0bsiteCtrTcsX\x18\x13 \x02(\x01\x12\x13\n\x0bsiteCtrTcsY\x18\x14 \x02(\x01\x12\x13\n\x0bsiteCtrTcsZ\x18\x15 \x02(\x01\x12\x13\n\x0bsensorUnits\x18\x16 \x02(\t\x12\x0e\n\x06\x61\x62sIdx\x18\x17 \x02(\x05\x12\x14\n\x0cisAudioRight\x18\x18 \x02(\x08\x12\x12\n\nsysChanIdx\x18\x19 \x02(\x05\x12\x17\n\x0fsiteAreaMicron2\x18\x1a \x01(\x01\x12\x11\n\tscsToTcsX\x18\x1b \x01(\x01\x12\x11\n\tscsToTcsY\x18\x1c \x01(\x01\x12\x11\n\tscsToTcsZ\x18\x1d \x01(\x01\x12\x10\n\x08sensorID\x18\x1e \x01(\t\x12\x0f\n\x07probeID\x18\x1f \x01(\t\x12\x13\n\x0bheadstageID\x18  \x01(\t\x12\x13\n\x0b\x64\x61tasetRidx\x18! \x01(\x05\x12\x13\n\x0b\x64\x61tasetAidx\x18\" \x01(\x05\x12\x13\n\x0bntvChanName\x18# \x01(\t\x12\x11\n\tsensorUID\x18$ \x01(\t\"\x1f\n\x07XYCoord\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\"+\n\x08XYZCoord\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\t\n\x01z\x18\x03 \x02(\x01\"\xc2\x02\n\x06Sensor\x12\x0f\n\x07probeId\x18\x01 \x02(\t\x12\x13\n\x0bheadstageId\x18\x02 \x02(\t\x12+\n\twireframe\x18\x03 \x02(\x0b\x32\x18.allego.Sensor.WireFrame\x12\x0c\n\x04xMin\x18\x04 \x02(\x01\x12\x0c\n\x04xMax\x18\x05 \x02(\x01\x12\x0c\n\x04yMin\x18\x06 \x02(\x01\x12\x0c\n\x04yMax\x18\x07 \x02(\x01\x12+\n\x08position\x18\x08 \x02(\x0b\x32\x19.allego.SensorPositionTcs\x12\x11\n\tsensorUID\x18\t \x01(\t\x1am\n\tWireFrame\x12\x1c\n\x03vtx\x18\x01 \x03(\x0b\x32\x0f.allego.XYCoord\x12 \n\x07vtxXlim\x18\x02 \x02(\x0b\x32\x0f.allego.XYCoord\x12 \n\x07vtxYlim\x18\x03 \x02(\x0b\x32\x0f.allego.XYCoord\"\x98\x02\n\x0eSensorPortSpec\x12\x1f\n\x07sensorA\x18\x01 \x01(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorB\x18\x02 \x01(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorC\x18\x03 \x01(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorD\x18\x04 \x01(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorE\x18\x05 \x01(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorF\x18\x06 \x01(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorG\x18\x07 \x01(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorH\x18\x08 \x01(\x0b\x32\x0e.allego.Sensor\"t\n\x10SignalGroupUnits\x12\x32\n\x05units\x18\x01 \x03(\x0b\x32#.allego.SignalGroupUnits.UnitsEntry\x1a,\n\nUnitsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x80\x02\n\x0bSignalGroup\x12\'\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x15.allego.ChannelRecord\x12.\n\x0esensorPortSpec\x18\x02 \x02(\x0b\x32\x16.allego.SensorPortSpec\x12\x12\n\ndatasetUID\x18\x03 \x01(\t\x12\x10\n\x08sampFreq\x18\x04 \x01(\x01\x12\x13\n\x0bsourceLabel\x18\x05 \x01(\t\x12\x19\n\x11neighborMaxRadius\x18\x06 \x01(\x01\x12-\n\x0bsignalUnits\x18\x07 \x01(\x0b\x32\x18.allego.SignalGroupUnits\x12\x13\n\x0bhasDiscrete\x18\x08 \x01(\x08\"\x87\x01\n\x18\x43reateSignalGroupRequest\x12\x16\n\x0e\x64\x61taSourceName\x18\x01 \x02(\t\x12\x16\n\x0e\x64\x61taSourcePath\x18\x02 \x02(\t\x12$\n\x04type\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x15\n\rstreamGroupId\x18\x04 \x02(\t\"s\n\tSubOpSort\x12)\n\x04sort\x18\x01 \x03(\x0e\x32\x1b.allego.SubOpSort.SortField\";\n\tSortField\x12\x0e\n\nSITE_CTR_X\x10\x00\x12\x0e\n\nSITE_CTR_Y\x10\x01\x12\x0e\n\nSITE_CTR_Z\x10\x02\"\x92\x03\n\x18UpdateSignalGroupRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12=\n\toperation\x18\x02 \x02(\x0e\x32*.allego.UpdateSignalGroupRequest.Operation\x12\x42\n\taddRemove\x18\x03 \x01(\x0e\x32-.allego.UpdateSignalGroupRequest.SubOperationH\x00\x12#\n\x06sortOp\x18\x04 \x01(\x0b\x32\x11.allego.SubOpSortH\x00\x12\x16\n\nntvChanIdx\x18\x05 \x03(\x05\x42\x02\x10\x01\x12&\n\nsignalType\x18\x06 \x02(\x0e\x32\x12.allego.SignalType\"B\n\tOperation\x12\t\n\x05\x43OLOR\x10\x00\x12\n\n\x06SELECT\x10\x01\x12\x14\n\x10\x44\x45PRECATED_AUDIO\x10\x02\x12\x08\n\x04SORT\x10\x03\"#\n\x0cSubOperation\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\n\n\x06REMOVE\x10\x01\x42\x0e\n\x0csubOperation\"\x0f\n\rLicenseStatus\"u\n\x12SetDSPGroupRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\"\n\x05stage\x18\x02 \x02(\x0e\x32\x13.allego.FilterStage\x12$\n\tdspParams\x18\x03 \x03(\x0b\x32\x11.allego.DSPParams\"\xf2\x02\n\tDSPParams\x12\x1d\n\x04type\x18\x01 \x02(\x0e\x32\x0f.allego.DSPType\x12\"\n\x05stage\x18\x02 \x02(\x0e\x32\x13.allego.FilterStage\x12\x0e\n\x04\x66req\x18\x03 \x01(\x01H\x00\x12\x36\n\x0c\x66reqSpecBand\x18\x04 \x01(\x0b\x32\x1e.allego.DSPParams.FreqSpecBandH\x00\x12\x17\n\rrefNtvChanIdx\x18\x08 \x01(\x05H\x00\x12\x16\n\x0enotchBandwidth\x18\x05 \x01(\x01\x12\x11\n\tuserLabel\x18\x06 \x02(\t\x12\x1a\n\x04port\x18\x07 \x02(\x0e\x32\x0c.allego.Port\x12\x18\n\x10targetNtvChanIdx\x18\t \x01(\x01\x12\r\n\x05isAux\x18\n \x02(\x08\x12\x12\n\nauxChanIdx\x18\x0b \x01(\x05\x1a\x31\n\x0c\x46reqSpecBand\x12\x0f\n\x07lowFreq\x18\x01 \x02(\x01\x12\x10\n\x08highFreq\x18\x02 \x02(\x01\x42\n\n\x08\x66reqSpec\"\x85\x01\n\x08\x44SPGroup\x12#\n\x08hardware\x18\x01 \x03(\x0b\x32\x11.allego.DSPParams\x12)\n\x0esoftwareStage1\x18\x02 \x03(\x0b\x32\x11.allego.DSPParams\x12)\n\x0esoftwareStage2\x18\x03 \x03(\x0b\x32\x11.allego.DSPParams\"k\n\x10SetSensorRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12\x0f\n\x07probeId\x18\x03 \x02(\t\x12\x13\n\x0bheadstageId\x18\x04 \x02(\t\"m\n\x11SensorPositionTcs\x12\t\n\x01X\x18\x02 \x02(\x01\x12\t\n\x01Y\x18\x03 \x02(\x01\x12\t\n\x01Z\x18\x04 \x02(\x01\x12\x11\n\tRingAngle\x18\x05 \x02(\x01\x12\x12\n\nAxialAngle\x18\x06 \x02(\x01\x12\x10\n\x08\x41rcAngle\x18\x07 \x02(\x01\"}\n\x1bSetSensorPositionTcsRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12+\n\x08position\x18\x03 \x02(\x0b\x32\x19.allego.SensorPositionTcs\"F\n\x0fSitePositionTcs\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\t\n\x01X\x18\x02 \x02(\x01\x12\t\n\x01Y\x18\x03 \x02(\x01\x12\t\n\x01Z\x18\x04 \x02(\x01\"\x7f\n\x1aSetSitePositionsTcsRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12.\n\rsitePositions\x18\x03 \x03(\x0b\x32\x17.allego.SitePositionTcs\"Y\n\x17\x46\x65\x61tureStartStopRequest\x12\x0e\n\x06nodeId\x18\x01 \x02(\t\x12.\n\x0e\x66\x65\x61tureLicense\x18\x02 \x02(\x0e\x32\x16.allego.FeatureLicense\"!\n\x0cPrivacyReply\x12\x11\n\tisPrivate\x18\x02 \x02(\x08\"&\n\x11SetPrivacyRequest\x12\x11\n\tisPrivate\x18\x01 \x02(\x08\"7\n\x0b\x44\x65nseMatrix\x12\x0c\n\x04rows\x18\x01 \x02(\x03\x12\x0c\n\x04\x63ols\x18\x02 \x02(\x03\x12\x0c\n\x04\x64\x61ta\x18\x03 \x02(\x0c\"Y\n\x0bKpiMetricID\x12$\n\x04mode\x18\x01 \x02(\x0e\x32\x16.allego.KpiMetricsMode\x12$\n\x04name\x18\x02 \x02(\x0e\x32\x16.allego.KpiMetricsEnum\"W\n\tTimeRange\x12\x14\n\x0ctimeRangeSec\x18\x01 \x03(\x01\x12\x11\n\ttimestamp\x18\x02 \x03(\x03\x12\n\n\x02\x66s\x18\x03 \x02(\x01\x12\x15\n\rwallTimeStart\x18\x04 \x01(\t\"q\n\tBundleReq\x12\x0f\n\x07ntvIdxs\x18\x01 \x03(\x05\x12\x1d\n\x02tR\x18\x02 \x02(\x0b\x32\x11.allego.TimeRange\x12$\n\x07metrics\x18\x04 \x03(\x0b\x32\x13.allego.KpiMetricID\x12\x0e\n\x06isTail\x18\x05 \x02(\x08\"\x94\x01\n\rKpiMetricsReq\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12!\n\x05stype\x18\x02 \x01(\x0e\x32\x12.allego.SignalType\x12\x1e\n\x03\x61rg\x18\x03 \x02(\x0b\x32\x11.allego.BundleReq\x12)\n\nbundleName\x18\x04 \x01(\x0e\x32\x15.allego.KpiBundleName\"\x83\x03\n\x0eKpiMetricsData\x12\x12\n\nnumPackets\x18\x01 \x02(\x03\x12\x0f\n\x07numSigs\x18\x02 \x02(\x03\x12\x12\n\nnumMetrics\x18\x03 \x02(\x03\x12#\n\x06metric\x18\x04 \x03(\x0b\x32\x13.allego.KpiMetricID\x12\x0f\n\x07pktIdxs\x18\x05 \x03(\x03\x12 \n\x03val\x18\x06 \x02(\x0b\x32\x13.allego.DenseMatrix\x12\x35\n\tstatsPkts\x18\x07 \x02(\x0b\x32\".allego.KpiMetricsData.MetricStats\x12\x31\n\x05stats\x18\x08 \x02(\x0b\x32\".allego.KpiMetricsData.MetricStats\x12\x14\n\x0cpacketDurSec\x18\t \x02(\x01\x12\x1d\n\x02tR\x18\n \x02(\x0b\x32\x11.allego.TimeRange\x1a\x41\n\x0bMetricStats\x12\x0c\n\x04mean\x18\x01 \x03(\x01\x12\n\n\x02sD\x18\x02 \x03(\x01\x12\x0b\n\x03max\x18\x03 \x03(\x01\x12\x0b\n\x03min\x18\x04 \x03(\x01\"w\n\x16KpiBundlePacketMetrics\x12\x0f\n\x07ntvIdxs\x18\x01 \x03(\x05\x12#\n\x07sigType\x18\x02 \x02(\x0e\x32\x12.allego.SignalType\x12\'\n\x07metrics\x18\x04 \x02(\x0b\x32\x16.allego.KpiMetricsData\"S\n\nKpiMetrics\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12.\n\x06\x62undle\x18\x02 \x02(\x0b\x32\x1e.allego.KpiBundlePacketMetrics\"\x88\x01\n\x11KpiControlRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12!\n\x05stype\x18\x02 \x01(\x0e\x32\x12.allego.SignalType\x12\x14\n\x0cisAllBundles\x18\x03 \x01(\x08\x12#\n\x04name\x18\x04 \x01(\x0e\x32\x15.allego.KpiBundleName\"\x90\x01\n\x19SetKpiUpdatePeriodRequest\x12!\n\x05stype\x18\x01 \x02(\x0e\x32\x12.allego.SignalType\x12\x15\n\rstreamGroupId\x18\x02 \x01(\t\x12\x14\n\x0cupdatePeriod\x18\x03 \x02(\x01\x12#\n\x04name\x18\x04 \x01(\x0e\x32\x15.allego.KpiBundleName\"\xd2\x02\n\x16SetKpiThresholdRequest\x12!\n\x05stype\x18\x01 \x02(\x0e\x32\x12.allego.SignalType\x12\x15\n\rstreamGroupId\x18\x02 \x01(\t\x12\x13\n\x0bisUpdatePos\x18\x03 \x02(\x08\x12\x12\n\nisClearPos\x18\x04 \x02(\x08\x12\x0f\n\x07isSdPos\x18\x05 \x02(\x08\x12\x10\n\x08levelPos\x18\x06 \x02(\x01\x12\x13\n\x0bisUpdateNeg\x18\x07 \x02(\x08\x12\x12\n\nisClearNeg\x18\x08 \x02(\x08\x12\x0f\n\x07isSdNeg\x18\t \x02(\x08\x12\x10\n\x08levelNeg\x18\n \x02(\x01\x12\x16\n\nntvChanIdx\x18\x0b \x03(\x05\x42\x02\x10\x01\x12)\n\x07thrName\x18\x0c \x01(\x0e\x32\x18.allego.KpiThresholdName\x12#\n\x04name\x18\r \x01(\x0e\x32\x15.allego.KpiBundleName\"\xd2\x01\n\x18SetKpiEventDetectRequest\x12!\n\x05stype\x18\x01 \x02(\x0e\x32\x12.allego.SignalType\x12\x15\n\rstreamGroupId\x18\x02 \x01(\t\x12\x15\n\risEventDetect\x18\x03 \x02(\x08\x12\x16\n\nntvChanIdx\x18\x04 \x03(\x05\x42\x02\x10\x01\x12)\n\x07thrName\x18\x05 \x01(\x0e\x32\x18.allego.KpiThresholdName\x12\x10\n\x08isPosThr\x18\x06 \x01(\x08\x12\x10\n\x08isNegThr\x18\x07 \x01(\x08\"\xa5\x01\n\x18SetKpiEventShadowRequest\x12!\n\x05stype\x18\x01 \x02(\x0e\x32\x12.allego.SignalType\x12\x15\n\rstreamGroupId\x18\x02 \x01(\t\x12\x0e\n\x06shadow\x18\x03 \x02(\x01\x12\x16\n\nntvChanIdx\x18\x04 \x03(\x05\x42\x02\x10\x01\x12\'\n\x07wdwName\x18\x05 \x01(\x0e\x32\x16.allego.KpiWindowdName\"\xb6\x01\n\x18SetKpiEventWindowRequest\x12!\n\x05stype\x18\x01 \x02(\x0e\x32\x12.allego.SignalType\x12\x15\n\rstreamGroupId\x18\x02 \x01(\t\x12\x0e\n\x06preThr\x18\x03 \x02(\x01\x12\x0f\n\x07postThr\x18\x04 \x02(\x01\x12\x16\n\nntvChanIdx\x18\x05 \x03(\x05\x42\x02\x10\x01\x12\'\n\x07wdwName\x18\x06 \x01(\x0e\x32\x16.allego.KpiWindowdName\"Q\n\x13GetKpiStatusRequest\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\x12#\n\x04name\x18\x03 \x01(\x0e\x32\x15.allego.KpiBundleName\"\xa3\x02\n\x0eKpiStatusReply\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x16\n\x0etimestampRange\x18\x04 \x03(\x03\x12\x18\n\x10numPacketsMemory\x18\x05 \x02(\x03\x12\x11\n\tpacketDur\x18\x06 \x02(\x01\x12\x14\n\x0cupdatePeriod\x18\x07 \x02(\x01\x12\x13\n\x0bpersistence\x18\x08 \x02(\x01\x12\x0c\n\x04\x62\x65ta\x18\t \x02(\x01\x12\x1d\n\x15isTrackingSignalCache\x18\x0b \x02(\x08\x12\x12\n\nnumPackets\x18\x0c \x02(\x03\x12\x13\n\x0bmemoryBytes\x18\r \x02(\x01\x12\n\n\x02\x66s\x18\x0e \x02(\x01\x12\x15\n\rwallTimeStart\x18\x0f \x02(\t\"\xe6\x02\n\x11SigKpiParamRecord\x12\x15\n\risEventDetect\x18\x01 \x02(\x08\x12\x12\n\nntvChanIdx\x18\x02 \x02(\x05\x12\x11\n\teventThr0\x18\x03 \x02(\x01\x12\x11\n\teventThr1\x18\x04 \x02(\x01\x12\x13\n\x0b\x65ventThrSd0\x18\x05 \x02(\x01\x12\x13\n\x0b\x65ventThrSd1\x18\x06 \x02(\x01\x12\x11\n\tpreThrPts\x18\x07 \x02(\x05\x12\x12\n\npostThrPts\x18\x08 \x02(\x05\x12\x11\n\tevtDurPts\x18\t \x02(\x05\x12\x11\n\tshadowPts\x18\n \x02(\x05\x12\x0e\n\x06preThr\x18\x0b \x02(\x01\x12\x0f\n\x07postThr\x18\x0c \x02(\x01\x12\x0e\n\x06\x65vtDur\x18\r \x02(\x01\x12\x0e\n\x06shadow\x18\x0e \x02(\x01\x12\x11\n\tisSetThr0\x18\x0f \x02(\x08\x12\x11\n\tisSetThr1\x18\x10 \x02(\x08\x12\x10\n\x08isSDThr0\x18\x11 \x02(\x08\x12\x10\n\x08isSDThr1\x18\x12 \x02(\x08\"J\n\x0e\x41nnotateBundle\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\r\n\x05notes\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x01(\t\"]\n\x0fProjectMetadata\x12\x12\n\nprojectUID\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61seUID\x18\x02 \x01(\t\x12\x10\n\x08trialUID\x18\x03 \x01(\t\x12\x13\n\x0b\x61nnotateUID\x18\x04 \x03(\t\"3\n\x16SensorExtendedMetadata\x12\x19\n\x11sensorInstanceUID\x18\x01 \x01(\t\"%\n\x0fGonumMatrixList\x12\x12\n\nmdataBytes\x18\x01 \x02(\x0c\"6\n\x0fRadixMatrixList\x12#\n\x06matrix\x18\x01 \x03(\x0b\x32\x13.allego.RadixMatrix\"*\n\x0bRadixMatrix\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x02\x12\r\n\x05shape\x18\x02 \x03(\x05\"8\n\x10RadixSignalsList\x12$\n\x06matrix\x18\x01 \x03(\x0b\x32\x14.allego.RadixSignals\"\xa9\x01\n\x0cRadixSignals\x12\x10\n\x08sampFreq\x18\x01 \x02(\x01\x12 \n\x03pri\x18\x02 \x02(\x0b\x32\x13.allego.RadixMatrix\x12 \n\x03\x61ux\x18\x03 \x02(\x0b\x32\x13.allego.RadixMatrix\x12 \n\x03\x64in\x18\x04 \x02(\x0b\x32\x13.allego.RadixMatrix\x12!\n\x04\x64out\x18\x05 \x02(\x0b\x32\x13.allego.RadixMatrix\"\x19\n\x0cVectorString\x12\t\n\x01x\x18\x01 \x03(\t\"\x1a\n\rVectorFloat64\x12\t\n\x01x\x18\x01 \x03(\x01\"G\n\x12VectorSliceFloat64\x12\"\n\x03vec\x18\x01 \x03(\x0b\x32\x15.allego.VectorFloat64\x12\r\n\x05label\x18\x02 \x01(\t\"\xde\x02\n\x14LogsysKpiStatusReply\x12\x1f\n\x05portA\x18\x01 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portB\x18\x02 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portC\x18\x03 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portD\x18\x04 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portE\x18\x05 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portF\x18\x06 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portG\x18\x07 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portH\x18\x08 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1e\n\x04\x61ux0\x18\t \x02(\x0b\x32\x10.allego.KpiCache\x12\x1e\n\x04\x61ux1\x18\n \x02(\x0b\x32\x10.allego.KpiCache\"\xfc\x02\n\x08KpiCache\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x12\n\npersistDur\x18\x03 \x02(\x01\x12\x15\n\rminNumPackets\x18\x04 \x02(\x05\x12\x11\n\tsizeBytes\x18\x05 \x02(\x05\x12\x12\n\nnumPackets\x18\x06 \x02(\x05\x12\x0e\n\x06tRange\x18\x07 \x03(\x01\x12\x0f\n\x07tsRange\x18\x08 \x03(\x03\x12\x15\n\rmeanPacketDur\x18\t \x02(\x01\x12\x19\n\x11meanCalcPacketDur\x18\n \x02(\x01\x12\x11\n\tpacketDur\x18\x0b \x02(\x01\x12\x1d\n\x15totalPacketsProcessed\x18\x0c \x02(\r\x12\x12\n\nsignalType\x18\r \x02(\t\x12\x12\n\nnumPriSigs\x18\x0e \x02(\x05\x12\x12\n\nnumAuxSigs\x18\x0f \x02(\x05\x12\x12\n\nnumDinSigs\x18\x10 \x02(\x05\x12\x13\n\x0bnumDoutSigs\x18\x11 \x02(\x05\x12\x14\n\x0cupdatePeriod\x18\x12 \x02(\x01\"\xfa\x02\n\x12LogsysKpiTailReply\x12\"\n\x05portA\x18\x01 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portB\x18\x02 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portC\x18\x03 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portD\x18\x04 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portE\x18\x05 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portF\x18\x06 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portG\x18\x07 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portH\x18\x08 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12!\n\x04\x61ux0\x18\t \x01(\x0b\x32\x13.allego.KpiPortInfo\x12!\n\x04\x61ux1\x18\n \x01(\x0b\x32\x13.allego.KpiPortInfo\"3\n\x0bKpiPortInfo\x12$\n\x07kpiTail\x18\x01 \x03(\x0b\x32\x13.allego.KpiTailRows\"\xf4\x02\n\x0bKpiTailRows\x12\x10\n\x08wallTime\x18\x01 \x02(\t\x12\x11\n\ttimeRange\x18\x02 \x02(\x01\x12\x14\n\x0clocalSigType\x18\x03 \x02(\t\x12\x12\n\nntvChanIdx\x18\x04 \x02(\x03\x12\x0b\n\x03\x64ur\x18\x05 \x02(\x01\x12\x0e\n\x06stdDev\x18\x06 \x02(\x01\x12\x0f\n\x07\x63StdDev\x18\x07 \x02(\x01\x12\x11\n\tabsEvtAmp\x18\x08 \x02(\x01\x12\x12\n\ncabsEvtAmp\x18\t \x02(\x01\x12\x0b\n\x03SNR\x18\n \x02(\x01\x12\x0c\n\x04\x63SNR\x18\x0b \x02(\x01\x12\x0f\n\x07numEvts\x18\x0c \x02(\x05\x12\x10\n\x08\x63numEvts\x18\r \x02(\x05\x12\x0f\n\x07\x65vtRate\x18\x0e \x02(\x01\x12\x10\n\x08\x63\x45vtRate\x18\x0f \x02(\x01\x12\x0b\n\x03max\x18\x10 \x02(\x01\x12\x0c\n\x04\x63max\x18\x11 \x02(\x01\x12\x0b\n\x03min\x18\x12 \x02(\x01\x12\x0c\n\x04\x63min\x18\x13 \x02(\x01\x12\x14\n\x0cmeanPosPkAmp\x18\x14 \x02(\x01\x12\x14\n\x0cmeanNegPkAmp\x18\x15 \x02(\x01\"*\n\x18WarehouseHealthcheckSpec\x12\x0e\n\x06\x65rrMsg\x18\x01 \x01(\t\"(\n\x19OutfitterGetDeviceRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x9e\x01\n\x11SensorCompRequest\x12 \n\x05probe\x18\x01 \x03(\x0b\x32\x11.allego.ProbeDesc\x12(\n\theadstage\x18\x02 \x03(\x0b\x32\x15.allego.HeadstageDesc\x12\x16\n\x0eisIncludeModel\x18\x03 \x01(\x08\x12\x19\n\x11isIncludeMetadata\x18\x04 \x01(\x08\x12\n\n\x02iD\x18\x05 \x01(\t\"z\n\x19RegisterSensorCompRequest\x12 \n\x05probe\x18\x01 \x03(\x0b\x32\x11.allego.ProbeDesc\x12(\n\theadstage\x18\x02 \x03(\x0b\x32\x15.allego.HeadstageDesc\x12\x11\n\tprofileID\x18\x03 \x02(\t\"\x92\x01\n\x1dSaveSensorCompInstanceRequest\x12 \n\x05probe\x18\x01 \x01(\x0b\x32\x11.allego.ProbeDesc\x12(\n\theadstage\x18\x02 \x01(\x0b\x32\x15.allego.HeadstageDesc\x12\x19\n\x11isIncludeMetadata\x18\x04 \x01(\x08\x12\n\n\x02iD\x18\x05 \x01(\t\"&\n\tProbeDesc\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0b\n\x03uID\x18\x02 \x01(\t\"*\n\rHeadstageDesc\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0b\n\x03uID\x18\x02 \x01(\t\"`\n\x12GetSensorCompReply\x12 \n\x05probe\x18\x01 \x03(\x0b\x32\x11.allego.ProbeSpec\x12(\n\theadstage\x18\x02 \x03(\x0b\x32\x15.allego.HeadstageSpec\"x\n\tProbeSpec\x12\x1f\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x11.allego.ProbeDesc\x12!\n\x05model\x18\x02 \x01(\x0b\x32\x12.allego.ProbeModel\x12\'\n\x08metaData\x18\x03 \x01(\x0b\x32\x15.allego.ProbeMetaData\"\x88\x01\n\rHeadstageSpec\x12#\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x15.allego.HeadstageDesc\x12%\n\x05model\x18\x02 \x01(\x0b\x32\x16.allego.HeadstageModel\x12+\n\x08metaData\x18\x03 \x01(\x0b\x32\x19.allego.HeadstageMetaData\"\xce\x04\n\nProbeModel\x12\n\n\x02iD\x18\x01 \x02(\t\x12.\n\x04site\x18\x02 \x03(\x0b\x32 .allego.ProbeModel.ProbeSiteDesc\x12\x34\n\twireframe\x18\x03 \x02(\x0b\x32!.allego.ProbeModel.ProbeWireFrame\x12\x34\n\x0esiteOverallMin\x18\x05 \x02(\x0b\x32\x1c.allego.ProbeModel.ProbePtXY\x12\x34\n\x0esiteOverallMax\x18\x06 \x02(\x0b\x32\x1c.allego.ProbeModel.ProbePtXY\x1a\xde\x01\n\rProbeSiteDesc\x12\x0c\n\x04\x61rea\x18\x01 \x02(\x01\x12\x0f\n\x07\x63\x65nterX\x18\x02 \x02(\x01\x12\x0f\n\x07\x63\x65nterY\x18\x03 \x02(\x01\x12\x0f\n\x07\x63\x65nterZ\x18\x04 \x02(\x01\x12\x11\n\tlimitXMax\x18\x05 \x02(\x01\x12\x11\n\tlimitXMin\x18\x06 \x02(\x01\x12\x11\n\tlimitYMax\x18\x07 \x02(\x01\x12\x11\n\tlimitYMin\x18\x08 \x02(\x01\x12\x11\n\tlimitZMax\x18\t \x02(\x01\x12\x11\n\tlimitZMin\x18\n \x02(\x01\x12\x0b\n\x03num\x18\x0b \x02(\x03\x12\r\n\x05shape\x18\x0c \x02(\t\x1a^\n\x0eProbeWireFrame\x12,\n\x06vertex\x18\x01 \x03(\x0b\x32\x1c.allego.ProbeModel.ProbePtXY\x12\x0e\n\x06limitX\x18\x02 \x03(\x01\x12\x0e\n\x06limitY\x18\x03 \x03(\x01\x1a!\n\tProbePtXY\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\"_\n\rProbeMetaData\x12\x11\n\tprobeName\x18\x01 \x02(\t\x12\x10\n\x08numSites\x18\x02 \x02(\x05\x12\x13\n\x0b\x63\x61talogTags\x18\x03 \x02(\t\x12\x14\n\x0cinstanceTags\x18\x04 \x02(\t\"\x84\x01\n\x0eHeadstageModel\x12\n\n\x02iD\x18\x01 \x02(\t\x12\x31\n\x04rows\x18\x02 \x03(\x0b\x32#.allego.HeadstageModel.HeadstageRow\x1a\x33\n\x0cHeadstageRow\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x03\x12\x0f\n\x07siteNum\x18\x02 \x02(\x03\"\x13\n\x11HeadstageMetaData\"5\n\x0bUserProfile\x12\x11\n\tprofileID\x18\x01 \x02(\t\x12\x13\n\x0blicenseCode\x18\x02 \x02(\t\"B\n\x16GetCurrentProfileReply\x12(\n\x0buserProfile\x18\x01 \x02(\x0b\x32\x13.allego.UserProfile\"@\n\x13GetAllProfilesReply\x12)\n\x0cuserProfiles\x18\x01 \x03(\x0b\x32\x13.allego.UserProfile\"-\n\x18SetCurrentProfileRequest\x12\x11\n\tprofileID\x18\x01 \x02(\t\"\x88\x01\n\x14ManageNodeOrgPayload\x12\r\n\x05orgID\x18\x01 \x01(\t\x12\x0f\n\x07orgName\x18\x02 \x01(\t\x12\x14\n\x0corgShortName\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x01(\t\"i\n\x14ManageNodeOrgRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12-\n\x07payload\x18\x02 \x03(\x0b\x32\x1c.allego.ManageNodeOrgPayload\"S\n\x12ManageNodeOrgReply\x12-\n\x07payload\x18\x01 \x03(\x0b\x32\x1c.allego.ManageNodeOrgPayload\x12\x0e\n\x06\x65rrMsg\x18\x02 \x01(\t\"\xa2\x01\n\x14ManageNodeLabPayload\x12\r\n\x05labID\x18\x01 \x01(\t\x12\x0f\n\x07labDesc\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65pt\x18\x03 \x01(\t\x12\x14\n\x0corganization\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x64minID\x18\x05 \x01(\t\x12\x11\n\tlabHeadID\x18\x06 \x01(\t\x12\x14\n\x0clabManagerID\x18\x07 \x01(\t\x12\x0c\n\x04tags\x18\x08 \x01(\t\"i\n\x14ManageNodeLabRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12-\n\x07payload\x18\x02 \x03(\x0b\x32\x1c.allego.ManageNodeLabPayload\"S\n\x12ManageNodeLabReply\x12-\n\x07payload\x18\x01 \x03(\x0b\x32\x1c.allego.ManageNodeLabPayload\x12\x0e\n\x06\x65rrMsg\x18\x02 \x01(\t\"\x99\x01\n\x15ManageNodeUserPayload\x12\x0e\n\x06userID\x18\x01 \x01(\t\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\x0c\x12\"\n\x04role\x18\x04 \x01(\x0e\x32\x14.allego.UserRoleType\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\x0f\n\x07labName\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x01(\t\"k\n\x15ManageNodeUserRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12.\n\x07payload\x18\x02 \x03(\x0b\x32\x1d.allego.ManageNodeUserPayload\"U\n\x13ManageNodeUserReply\x12.\n\x07payload\x18\x01 \x03(\x0b\x32\x1d.allego.ManageNodeUserPayload\x12\x0e\n\x06\x65rrMsg\x18\x02 \x01(\t\"6\n\x13\x43\x61talogProbePayload\x12\x1f\n\x04spec\x18\x01 \x02(\x0b\x32\x11.allego.ProbeSpec\"]\n\x10ProbeNodeRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12%\n\x07payload\x18\x02 \x03(\x0b\x32\x14.allego.ProbePayload\"7\n\x0eProbeNodeReply\x12%\n\x07payload\x18\x01 \x03(\x0b\x32\x14.allego.ProbePayload\"/\n\x0cProbePayload\x12\x1f\n\x04spec\x18\x01 \x02(\x0b\x32\x11.allego.ProbeSpec\"\xa5\x02\n\x0b\x45\x64gePayload\x12/\n\x06source\x18\x01 \x02(\x0b\x32\x1f.allego.EdgePayload.GenericNode\x12/\n\x06target\x18\x02 \x02(\x0b\x32\x1f.allego.EdgePayload.GenericNode\x12)\n\tedgeLabel\x18\x03 \x02(\x0e\x32\x16.allego.WorldEdgeLabel\x12-\n\tdirection\x18\x04 \x02(\x0e\x32\x1a.allego.WorldEdgeDirection\x1aZ\n\x0bGenericNode\x12%\n\x05label\x18\x01 \x02(\x0e\x32\x16.allego.WorldNodeLabel\x12\x11\n\tidPropKey\x18\x02 \x02(\t\x12\x11\n\tidPropVal\x18\x03 \x02(\t\"8\n\x10WorldEdgeRequest\x12$\n\x07payload\x18\x01 \x03(\x0b\x32\x13.allego.EdgePayload\"\x10\n\x0eWorldEdgeReply\"E\n\x11QueryWorldRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.WorldQueryCmd\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\"\xe6\x01\n\rQueryWorldRec\x12)\n\x03org\x18\x01 \x01(\x0b\x32\x1c.allego.ManageNodeOrgPayload\x12)\n\x03lab\x18\x02 \x01(\x0b\x32\x1c.allego.ManageNodeLabPayload\x12+\n\x04user\x18\x03 \x01(\x0b\x32\x1d.allego.ManageNodeUserPayload\x12-\n\x08\x63\x61tProbe\x18\x04 \x01(\x0b\x32\x1b.allego.CatalogProbePayload\x12#\n\x05probe\x18\x05 \x01(\x0b\x32\x14.allego.ProbePayload\"9\n\x0fQueryWorldReply\x12&\n\x07payload\x18\x01 \x03(\x0b\x32\x15.allego.QueryWorldRec\"/\n\x1aHighLowPassTransformParams\x12\x11\n\tfrequency\x18\x01 \x02(\x01\"B\n\x13\x42\x61ndTransformParams\x12\x14\n\x0clowFrequency\x18\x01 \x02(\x01\x12\x15\n\rhighFrequency\x18\x02 \x02(\x01\"F\n\x14NotchTransformParams\x12\x16\n\x0enotchFrequency\x18\x01 \x02(\x01\x12\x16\n\x0enotchBandwidth\x18\x02 \x02(\x01\"\x14\n\x12\x43\x41RTransformParams\"2\n\x19VirtualRefTransformParams\x12\x15\n\rrefNtvChanIdx\x18\x01 \x02(\x05\"K\n\x18PairedRefTransformParams\x12\x15\n\rrefNtvChanIdx\x18\x01 \x02(\x05\x12\x18\n\x10targetNtvChanIdx\x18\x02 \x02(\x05\"i\n\x1d\x44\x61taSourceSinkTransformParams\x12\x10\n\x08\x64srcName\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12(\n\x08\x66ileType\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\">\n\x18SliceTimeTransformParams\x12\x11\n\ttimeStart\x18\x01 \x02(\x01\x12\x0f\n\x07timeEnd\x18\x02 \x02(\x01\"3\n\x1cSliceChannelsTransformParams\x12\x13\n\x0bsysChanIdxs\x18\x01 \x03(\x05\"1\n\x19\x44ownsampleTransformParams\x12\x14\n\x0csampleFactor\x18\x01 \x02(\x05\" \n\x08Position\x12\t\n\x01x\x18\x01 \x02(\x05\x12\t\n\x01y\x18\x02 \x02(\x05\"\xd9\x05\n\rTransformNode\x12\n\n\x02id\x18\x01 \x02(\t\x12\'\n\x04type\x18\x02 \x02(\x0e\x32\x19.allego.TransformNodeType\x12\"\n\x08position\x18\x03 \x01(\x0b\x32\x10.allego.Position\x12\x0f\n\x07invalid\x18\x04 \x02(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x05 \x01(\t\x12=\n\x11highLowPassParams\x18\x06 \x01(\x0b\x32\".allego.HighLowPassTransformParams\x12/\n\nbandParams\x18\x07 \x01(\x0b\x32\x1b.allego.BandTransformParams\x12\x31\n\x0bnotchParams\x18\x08 \x01(\x0b\x32\x1c.allego.NotchTransformParams\x12-\n\tcarParams\x18\t \x01(\x0b\x32\x1a.allego.CARTransformParams\x12;\n\x10virtualRefParams\x18\n \x01(\x0b\x32!.allego.VirtualRefTransformParams\x12\x39\n\x0fpairedRefParams\x18\x0b \x01(\x0b\x32 .allego.PairedRefTransformParams\x12\x43\n\x14\x64\x61tasourceSinkParams\x18\x0c \x01(\x0b\x32%.allego.DataSourceSinkTransformParams\x12\x39\n\x0fsliceTimeParams\x18\r \x01(\x0b\x32 .allego.SliceTimeTransformParams\x12\x41\n\x13sliceChannelsParams\x18\x0e \x01(\x0b\x32$.allego.SliceChannelsTransformParams\x12;\n\x10\x64ownsampleParams\x18\x0f \x01(\x0b\x32!.allego.DownsampleTransformParams\";\n\rTransformEdge\x12\n\n\x02id\x18\x01 \x02(\t\x12\x0e\n\x06source\x18\x02 \x02(\t\x12\x0e\n\x06target\x18\x03 \x02(\t\"t\n\x08Protocol\x12\n\n\x02id\x18\x01 \x02(\t\x12-\n\x0etransformNodes\x18\x02 \x03(\x0b\x32\x15.allego.TransformNode\x12-\n\x0etransformEdges\x18\x03 \x03(\x0b\x32\x15.allego.TransformEdge\"%\n\x0fProtocolRequest\x12\x12\n\nprotocolID\x18\x01 \x02(\t\"B\n\x15RenameProtocolRequest\x12\x12\n\nprotocolID\x18\x01 \x02(\t\x12\x15\n\rnewProtocolID\x18\x02 \x02(\t\";\n\x14GetAllProtocolsReply\x12#\n\tprotocols\x18\x01 \x03(\x0b\x32\x10.allego.Protocol\"O\n\x15\x41pplyProtocolProgress\x12\x1c\n\x14lastTimestampWritten\x18\x01 \x02(\x05\x12\x18\n\x10\x64srcTimestampEnd\x18\x02 \x02(\x05\"\x9a\x01\n\x1aSpikeSorterSetParamRequest\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12,\n\x03\x63md\x18\x02 \x02(\x0e\x32\x1f.allego.SpikeSorterParamCommand\x12\x12\n\nregFloat64\x18\x03 \x03(\x01\x12\x0f\n\x07regBool\x18\x05 \x03(\x08\x12\x12\n\nntvChanIdx\x18\x06 \x03(\x05\"Q\n\x1bSpikeSorterSetParamsRequest\x12\x32\n\x06params\x18\x01 \x03(\x0b\x32\".allego.SpikeSorterSetParamRequest\"\xa7\x02\n\x1dSpikeSorterParamCommandRecord\x12\x11\n\tisEnabled\x18\x01 \x02(\x08\x12\x12\n\nntvChanIdx\x18\x02 \x02(\x05\x12\x0b\n\x03thr\x18\x03 \x03(\x01\x12\r\n\x05thrSd\x18\x04 \x03(\x01\x12\x11\n\tthrWdwPts\x18\x05 \x03(\x05\x12\x0e\n\x06thrWdw\x18\x06 \x03(\x01\x12\x0e\n\x06shadow\x18\x07 \x02(\x01\x12\x11\n\tshadowPts\x18\x08 \x02(\x05\x12\x10\n\x08isSetThr\x18\t \x03(\x08\x12\x0f\n\x07weakThr\x18\n \x03(\x01\x12\x11\n\tweakThrSd\x18\x0b \x03(\x01\x12\x14\n\x0cisSetWeakThr\x18\x0c \x03(\x08\x12\x12\n\npeakWdwPts\x18\r \x03(\x05\x12\x0f\n\x07peakWdw\x18\x0e \x03(\x01\x12\x0c\n\x04isSD\x18\x0f \x02(\x08\"V\n\x0eWrangleRequest\x12!\n\x04mode\x18\x01 \x02(\x0e\x32\x13.allego.WrangleMode\x12!\n\x04spec\x18\x02 \x02(\x0b\x32\x13.allego.WrangleSpec\"Y\n\x0bWrangleSpec\x12%\n\x06import\x18\x01 \x03(\x0b\x32\x15.allego.WrangleImport\x12#\n\x05merge\x18\x02 \x03(\x0b\x32\x14.allego.WrangleMerge\"H\n\rWrangleImport\x12\x37\n\x0cvexSpikesSim\x18\x01 \x01(\x0b\x32!.allego.WrangleImportVexSpikesSim\"g\n\x19WrangleImportVexSpikesSim\x12\'\n\x06source\x18\x01 \x02(\x0b\x32\x17.allego.WrangleFileDesc\x12\x13\n\x0bisOverwrite\x18\x02 \x01(\x08\x12\x0c\n\x04note\x18\x03 \x01(\t\"C\n\x0fWrangleFileDesc\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x02 \x02(\t\x12\x10\n\x08\x66ileType\x18\x03 \x01(\t\"H\n\x0cWrangleMerge\x12\x38\n\rvexSpikesView\x18\x01 \x01(\x0b\x32!.allego.WrangleMergeVexSpikesView\"\xaf\x02\n\x19WrangleMergeVexSpikesView\x12*\n\tsourceVex\x18\x01 \x02(\x0b\x32\x17.allego.WrangleFileDesc\x12*\n\tsourceBio\x18\x02 \x02(\x0b\x32\x17.allego.WrangleFileDesc\x12\x33\n\x04view\x18\x03 \x03(\x0b\x32%.allego.WrangleMergeVexSpikesViewSpec\x12\x0c\n\x04note\x18\x04 \x01(\t\x12\x18\n\x10isBandpassFilter\x18\x05 \x01(\x08\x12\x1a\n\x12\x62\x61ndpassFilterSpec\x18\x06 \x03(\x01\x12\x13\n\x0bisOverwrite\x18\x07 \x01(\x08\x12\x15\n\rspikeWindowMs\x18\x08 \x03(\x01\x12\x15\n\rspikeShadowMs\x18\t \x01(\x01\"\xc0\x01\n\x1dWrangleMergeVexSpikesViewSpec\x12(\n\x07sinkBio\x18\x01 \x02(\x0b\x32\x17.allego.WrangleFileDesc\x12\x1c\n\x14siteNeighborRadiusUm\x18\x02 \x01(\x01\x12\x1b\n\x13reqNumSiteNeighbors\x18\x03 \x01(\x05\x12\x15\n\rspikeWindowMs\x18\x04 \x03(\x01\x12\x15\n\rspikeShadowMs\x18\x05 \x01(\x01\x12\x0c\n\x04note\x18\x06 \x01(\t\"J\n\x10\x44\x41\x43StreamRequest\x12\x0b\n\x03\x44\x41\x43\x18\x01 \x02(\x05\x12\x12\n\nNtvChanIdx\x18\x02 \x02(\x05\x12\x15\n\rstreamGroupId\x18\x03 \x01(\t\"\xde\x01\n\x11\x45ventViewerConfig\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\x12\x19\n\x11triggerSysChanIdx\x18\x03 \x01(\x05\x12\x1a\n\x12triggerThresholdUV\x18\x04 \x01(\x01\x12\x14\n\x0cpreTriggerMs\x18\x05 \x02(\x01\x12\x15\n\rpostTriggerMs\x18\x06 \x02(\x01\x12\'\n\x0btriggerType\x18\x07 \x01(\x0e\x32\x12.allego.SignalType\x12\x0e\n\x06ntvIdx\x18\x08 \x01(\x05\"=\n\rEventViewerID\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\"D\n\x1aGetEventViewerEventRequest\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12\x0f\n\x07\x65ventId\x18\x02 \x02(\t\"Y\n\x14\x45ventViewerEventDesc\x12\x0f\n\x07\x65ventId\x18\x01 \x02(\t\x12\x18\n\x10triggerTimestamp\x18\x02 \x02(\x03\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\"\x8f\x01\n\x10\x45ventViewerEvent\x12\x0f\n\x07\x65ventId\x18\x01 \x02(\t\x12\x18\n\x10triggerTimestamp\x18\x02 \x02(\x03\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\x12#\n\x07signals\x18\x04 \x02(\x0b\x32\x12.allego.RawSignals\x12\x13\n\x0bsysChanIdxs\x18\x05 \x03(\x05\"a\n\x1aListEventViewerEventsReply\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12,\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x1c.allego.EventViewerEventDesc\"D\n\x15ListEventViewersReply\x12+\n\x0c\x65ventViewers\x18\x01 \x03(\x0b\x32\x15.allego.EventViewerID\"3\n\x1fStatusPollFieldsToUpdateRequest\x12\x10\n\x08\x63lientId\x18\x01 \x02(\t\"^\n\x18StatusPollFieldsToUpdate\x12\x10\n\x08\x63lientId\x18\x01 \x02(\t\x12\x30\n\x0e\x66ieldsToUpdate\x18\x02 \x03(\x0e\x32\x18.allego.StatusPollFields*\x85\x02\n\x0eRadixFileTypes\x12\x07\n\x03RHD\x10\x00\x12\x08\n\x04XDAT\x10\x01\x12\x07\n\x03\x43SV\x10\x02\x12\x08\n\x04HDF5\x10\x03\x12\x08\n\x04NEX5\x10\x04\x12\x07\n\x03NWB\x10\x05\x12\x10\n\x0c\x42IOINTERFACE\x10\x07\x12\r\n\tKILOSORT2\x10\x08\x12\x07\n\x03\x41NC\x10\t\x12\x0f\n\x0bSPKTRAIN_MU\x10\n\x12\x1b\n\x17\x42IO_RADIENS_EXPORT_HDF5\x10\x0b\x12\x1b\n\x17\x42IO_RADIENS_EXPORT_MAT5\x10\x0c\x12\x07\n\x03NSX\x10\r\x12\x07\n\x03PL2\x10\x0e\x12\x07\n\x03TDT\x10\x0f\x12\n\n\x06SPIKES\x10\x10\x12\x07\n\x03KPI\x10\x11\x12\x15\n\x11UNKNOWN_FILE_TYPE\x10\x12*1\n\nSignalType\x12\x07\n\x03PRI\x10\x00\x12\x07\n\x03\x41UX\x10\x01\x12\x07\n\x03\x44IN\x10\x02\x12\x08\n\x04\x44OUT\x10\x03*+\n\x0fResampleRoutine\x12\t\n\x05NAIVE\x10\x00\x12\r\n\tRETENTIVE\x10\x01*>\n\x04Port\x12\x05\n\x01\x41\x10\x00\x12\x05\n\x01\x42\x10\x01\x12\x05\n\x01\x43\x10\x02\x12\x05\n\x01\x44\x10\x03\x12\x05\n\x01\x45\x10\x04\x12\x05\n\x01\x46\x10\x05\x12\x05\n\x01G\x10\x06\x12\x05\n\x01H\x10\x07*2\n\x0cWorkspaceApp\x12\n\n\x06\x41llego\x10\x00\x12\n\n\x06\x43urate\x10\x01\x12\n\n\x06Videre\x10\x02*\xa0\x01\n\x11WorkspaceCommands\x12\x0f\n\x0bWSPACE_Save\x10\x00\x12\x11\n\rWSPACE_SaveAs\x10\x01\x12\x11\n\rWSPACE_Export\x10\x02\x12\x11\n\rWSPACE_Import\x10\x03\x12\x11\n\rWSPACE_Delete\x10\x04\x12\x11\n\rWSPACE_Switch\x10\x07\x12\x1b\n\x17WSPACE_SwitchToLastUsed\x10\x08*C\n\x14GetWorkspaceCommands\x12\x13\n\x0fGET_WSPACE_List\x10\x01\x12\x16\n\x12GET_WSPACE_Current\x10\x02*8\n\x11RadiensServerType\x12\x10\n\x0c\x41llegoserver\x10\x00\x12\x11\n\rRadiensserver\x10\x01*\x96\x01\n\x0fGrpcServiceType\x12\x0f\n\x0b\x41LLEGO_CORE\x10\x00\x12\x11\n\rALLEGO_PCACHE\x10\x01\x12\x0e\n\nALLEGO_KPI\x10\x02\x12\x12\n\x0e\x41LLEGO_NEURONS\x10\x03\x12\x10\n\x0cRADIENS_CORE\x10\x04\x12\x18\n\x14RADIENS_SPIKE_SORTER\x10\x05\x12\x0f\n\x0bRADIENS_DEV\x10\x06*?\n\x0e\x44\x65vDatasetType\x12\x08\n\x04\x42\x41SE\x10\x00\x12\t\n\x05TRAIN\x10\x01\x12\x0e\n\nVALIDATION\x10\x02\x12\x08\n\x04TEST\x10\x03*X\n\x0e\x44\x61taSourceSort\x12\x10\n\x0c\x44SOURCE_DATE\x10\x00\x12\x10\n\x0c\x44SOURCE_NAME\x10\x01\x12\x10\n\x0c\x44SOURCE_SIZE\x10\x02\x12\x10\n\x0c\x44SOURCE_TYPE\x10\x03*.\n\x0fSignalGroupType\x12\x11\n\rPRIMARY_CACHE\x10\x00\x12\x08\n\x04\x46ILE\x10\x03*\x81\x01\n\x07\x44SPType\x12\x0b\n\x07LOWPASS\x10\x00\x12\x0c\n\x08HIGHPASS\x10\x01\x12\x0c\n\x08\x42\x41NDPASS\x10\x02\x12\t\n\x05NOTCH\x10\x03\x12\x0c\n\x08\x42\x41NDSTOP\x10\x04\x12\x07\n\x03\x43\x41R\x10\x05\x12\x15\n\x11VIRTUAL_REFERENCE\x10\x06\x12\x14\n\x10PAIRED_REFERENCE\x10\x07*9\n\x0b\x46ilterStage\x12\x12\n\x0eSTAGE_HARDWARE\x10\x00\x12\n\n\x06STAGE1\x10\x01\x12\n\n\x06STAGE2\x10\x02*\xd3\x02\n\x0e\x46\x65\x61tureLicense\x12\x1a\n\x16\x46\x65\x61t_NoLicenseRequired\x10\x00\x12\x0c\n\x08\x46\x65\x61t_Any\x10\x01\x12\x0f\n\x0b\x46\x65\x61t_Power9\x10\x02\x12\x11\n\rFeat_RadixAPI\x10\x03\x12\x0e\n\nFeat_Scope\x10\x04\x12\x13\n\x0f\x46\x65\x61t_Electrodes\x10\x05\x12\x13\n\x0f\x46\x65\x61t_HDSnapshot\x10\x06\x12\x12\n\x0e\x46\x65\x61t_Impedance\x10\x07\x12\x10\n\x0c\x46\x65\x61t_Monitor\x10\x08\x12\x16\n\x12\x46\x65\x61t_SignalMetrics\x10\t\x12\x19\n\x15\x46\x65\x61t_SignalProcessing\x10\n\x12\x0f\n\x0b\x46\x65\x61t_System\x10\x0b\x12\x12\n\x0e\x46\x65\x61t_SpikeGrid\x10\x0c\x12\x14\n\x10\x46\x65\x61t_SpikeSorter\x10\r\x12\x0f\n\x0b\x46\x65\x61t_Raster\x10\x0e\x12\x14\n\x10\x46\x65\x61t_ThreeDModel\x10\x0f*_\n\x0eKpiMetricsMode\x12\x18\n\x14Kpi_MetricsMode_Base\x10\x00\x12\x17\n\x13Kpi_MetricsMode_Avg\x10\x01\x12\x1a\n\x16Kpi_MetricsMode_Stream\x10\x02*\xfd\x05\n\x0eKpiMetricsEnum\x12\x0f\n\x0bKPI_NUM_PTS\x10\x00\x12\x13\n\x0fKPI_NUM_PTS_ISI\x10\x01\x12\x0f\n\x0bKPI_DUR_SEC\x10\x02\x12\x0c\n\x08KPI_MEAN\x10\x03\x12\x0b\n\x07KPI_MIN\x10\x04\x12\x0f\n\x0bKPI_MIN_ISI\x10\x05\x12\x0b\n\x07KPI_MAX\x10\x06\x12\x0f\n\x0bKPI_MAX_ISI\x10\x07\x12\x0f\n\x0bKPI_MAX_ABS\x10\x08\x12\x13\n\x0fKPI_MAX_ABS_ISI\x10\t\x12\x15\n\x11KPI_TIMESTAMP_MIN\x10\n\x12\x15\n\x11KPI_TIMESTAMP_MAX\x10\x0b\x12\x18\n\x14KPI_MAX_MIN_DIFF_ABS\x10\x0c\x12\x1c\n\x18KPI_MAX_MIN_DIFF_ABS_ISI\x10\r\x12\n\n\x06KPI_SD\x10\x0e\x12\x0e\n\nKPI_SD_ISI\x10\x0f\x12\x0b\n\x07KPI_VAR\x10\x10\x12\x0f\n\x0bKPI_VAR_ISI\x10\x11\x12\x0b\n\x07KPI_RMS\x10\x12\x12\x0f\n\x0bKPI_RMS_ISI\x10\x13\x12\x10\n\x0cKPI_NOISE_UV\x10\x14\x12\x0b\n\x07KPI_SNR\x10\x15\x12\x12\n\x0eKPI_NUM_EVENTS\x10\x16\x12\x12\n\x0eKPI_EVENT_RATE\x10\x17\x12\x11\n\rKPI_EVENT_MAX\x10\x18\x12\x11\n\rKPI_EVENT_MIN\x10\x19\x12\x15\n\x11KPI_EVENT_MAX_ABS\x10\x1a\x12\x1e\n\x1aKPI_EVENT_MAX_MIN_DIFF_ABS\x10\x1b\x12\x1b\n\x17KPI_EVENT_TIMESTAMP_MIN\x10\x1c\x12\x1b\n\x17KPI_EVENT_TIMESTAMP_MAX\x10\x1d\x12\x1f\n\x1bKPI_EVENT_TIMESTAMP_MAX_ABS\x10\x1e\x12(\n$KPI_EVENT_TIMESTAMP_MAX_MIN_DIFF_ABS\x10\x1f\x12\x10\n\x0cKPI_MEAN_MAX\x10 \x12\x10\n\x0cKPI_MEAN_MIN\x10!\x12\x14\n\x10KPI_MEAN_MAX_ABS\x10\"\x12#\n\x1fKPI_EVENT_MEAN_MAX_MIN_DIFF_ABS\x10#*\x8b\x01\n\x13KpiMetricsStatsEnum\x12\x1e\n\x1aKPI_BDL_METRICS_STATS_MEAN\x10\x00\x12\x1d\n\x19KPI_BDL_METRICS_STATS_MAX\x10\x01\x12\x1d\n\x19KPI_BDL_METRICS_STATS_MIN\x10\x02\x12\x16\n\x12KPI_BDL_METRICS_SD\x10\x03*\xc0\x02\n\x19KpiBundlePacketsStatsEnum\x12\x14\n\x10KPI_BDL_NUM_SIGS\x10\x00\x12\x13\n\x0fKPI_BDL_DUR_SEC\x10\x01\x12\x1d\n\x19KPI_BDL_NUM_SIGS_W_EVENTS\x10\x02\x12\x15\n\x11KPI_BDL_SIG_YIELD\x10\x03\x12\x13\n\x0fKPI_BDL_RMS_AVG\x10\x04\x12\x13\n\x0fKPI_BDL_SNR_AVG\x10\x05\x12\x13\n\x0fKPI_BDL_SIG_MAX\x10\x06\x12\x13\n\x0fKPI_BDL_SIG_MIN\x10\x07\x12\x18\n\x14KPI_BDL_NOISE_UV_AVG\x10\x08\x12\x1c\n\x18KPI_BDL_NUM_EVENTS_TOTAL\x10\t\x12\x1a\n\x16KPI_BDL_NUM_EVENTS_AVG\x10\n\x12\x1a\n\x16KPI_BDL_EVENT_RATE_AVG\x10\x0b*\x97\x01\n\rKpiBundleName\x12\t\n\x05Kpi_A\x10\x00\x12\t\n\x05Kpi_B\x10\x01\x12\t\n\x05Kpi_C\x10\x02\x12\t\n\x05Kpi_D\x10\x03\x12\x0c\n\x08Kpi_Aux0\x10\x04\x12\x0c\n\x08Kpi_Aux1\x10\x05\x12\x12\n\x0eKpi_Datasource\x10\x06\x12\t\n\x05Kpi_E\x10\x07\x12\t\n\x05Kpi_F\x10\x08\x12\t\n\x05Kpi_G\x10\t\x12\t\n\x05Kpi_H\x10\n*F\n\x10TimeRangeSelMode\x12\x0e\n\nTRS_SUBSET\x10\x00\x12\x0f\n\x0bTRS_TO_HEAD\x10\x01\x12\x11\n\rTRS_FROM_HEAD\x10\x02*B\n\x10KpiThresholdName\x12\x11\n\rKpi_Thr_Event\x10\x00\x12\x1b\n\x17Kpi_Thr_Artifact_Reject\x10\x01*@\n\x0eKpiWindowdName\x12\x11\n\rKpi_Wdw_Event\x10\x00\x12\x1b\n\x17Kpi_Wdw_Artifact_Reject\x10\x01*N\n\x16OutfitterComponentType\x12\x16\n\x12OUTFIT_COMP_SENSOR\x10\x00\x12\x1c\n\x18OUTFIT_COMP_SPIKE_SORTER\x10\x01*}\n\x0eWorldNodeLabel\x12\x12\n\x0eWORLD_NODE_ORG\x10\x01\x12\x12\n\x0eWORLD_NODE_LAB\x10\x02\x12\x13\n\x0fWORLD_NODE_USER\x10\x03\x12\x18\n\x14WORLD_NODE_CAT_PROBE\x10\x04\x12\x14\n\x10WORLD_NODE_PROBE\x10\x05*\'\n\x0eWorldEdgeLabel\x12\x15\n\x11WORLD_EDGE_MEMBER\x10\x01*`\n\x12WorldEdgeDirection\x12\x18\n\x14WORLD_EDGE_DIR_RIGHT\x10\x01\x12\x17\n\x13WORLD_EDGE_DIR_LEFT\x10\x02\x12\x17\n\x13WORLD_EDGE_DIR_BOTH\x10\x03*\x9f\x01\n\x0cUserRoleType\x12\x0b\n\x07USER_PI\x10\x01\x12\x12\n\x0eUSER_SCIENTIST\x10\x02\x12\x11\n\rUSER_POST_DOC\x10\x03\x12\x15\n\x11USER_GRAD_STUDENT\x10\x04\x12\x13\n\x0fUSER_UG_STUDENT\x10\x05\x12\x10\n\x0cUSER_MANAGER\x10\x06\x12\r\n\tUSER_TECH\x10\x07\x12\x0e\n\nUSER_OTHER\x10\x08*G\n\rManageNodeCmd\x12\x10\n\x0cNODE_CMD_NEW\x10\x01\x12\x12\n\x0eNODE_CMD_MERGE\x10\x02\x12\x10\n\x0cNODE_CMD_DEL\x10\x03*\xe8\x01\n\rWorldQueryCmd\x12\x15\n\x11WQ_LIST_ALL_USERS\x10\x01\x12\x14\n\x10WQ_LIST_ALL_LABS\x10\x02\x12\x14\n\x10WQ_LIST_ALL_ORGS\x10\x03\x12\x1a\n\x16WQ_LIST_ALL_CAT_PROBES\x10\x04\x12\x16\n\x12WQ_LIST_ALL_PROBES\x10\x05\x12\x18\n\x14WQ_CAT_PROBE_BY_NAME\x10\x06\x12\x11\n\rWQ_USER_BY_ID\x10\x07\x12\x19\n\x15WQ_USER_AND_LAB_BY_ID\x10\x08\x12\x18\n\x14WQ2_LIST_ALL_DEVICES\x10\x1e*\xf0\x01\n\x11TransformNodeType\x12\x10\n\x0cNOTCH_FILTER\x10\x00\x12\x13\n\x0f\x42\x41NDPASS_FILTER\x10\x01\x12\x13\n\x0f\x42\x41NDSTOP_FILTER\x10\x02\x12\x13\n\x0fHIGHPASS_FILTER\x10\x03\x12\x12\n\x0eLOWPASS_FILTER\x10\x04\x12\x0e\n\nPAIRED_REF\x10\x05\x12\x0f\n\x0bVIRTUAL_REF\x10\x06\x12\x0b\n\x07\x43\x41R_REF\x10\x07\x12\x0e\n\nSLICE_TIME\x10\t\x12\x12\n\x0eSLICE_CHANNELS\x10\n\x12\n\n\x06SOURCE\x10\x0b\x12\x08\n\x04SINK\x10\x0c\x12\x0e\n\nDOWNSAMPLE\x10\r*\xdf\x01\n\x17SpikeSorterParamCommand\x12\x14\n\x10SORTER_THR_LEVEL\x10\x01\x12\x17\n\x13SORTER_THR_LEVEL_SD\x10\x04\x12\x12\n\x0eSORTER_THR_WDW\x10\x08\x12\x19\n\x15SORTER_WEAK_THR_LEVEL\x10\n\x12\x1c\n\x18SORTER_WEAK_THR_LEVEL_SD\x10\r\x12\x11\n\rSORTER_SHADOW\x10\x11\x12\x17\n\x13SORTER_THR_ACTIVATE\x10\x13\x12\x1c\n\x18SORTER_WEAK_THR_ACTIVATE\x10\x15*Z\n\x0bWrangleMode\x12*\n&WRANGLE_MODE_IMPORT_NNX_VEX_SPIKES_SIM\x10\x00\x12\x1f\n\x1bWRANGLE_MODE_MERGE_FIT_VIEW\x10\x01*\xd7\x03\n\x10StatusPollFields\x12\x19\n\x15PORT_CONNECTION_STATE\x10\x00\x12\x14\n\x10RECORDING_ERRORS\x10\x01\x12\x15\n\x11STREAM_TIME_RANGE\x10\x02\x12\x11\n\rSTREAM_STATUS\x10\x03\x12\x11\n\rRECORD_STATUS\x10\x04\x12\x16\n\x12GPIO_CHANNEL_COUNT\x10\x05\x12\x10\n\x0cIS_CONNECTED\x10\x06\x12\x0e\n\nRECORD_DUR\x10\x07\x12\x11\n\rBACKBONE_MODE\x10\t\x12\x10\n\x0cSIGNAL_GROUP\x10\n\x12\x14\n\x10SINAPS_REGISTERS\x10\x0b\x12\x14\n\x10RECORDING_CONFIG\x10\x0c\x12\x0b\n\x07\x46ILTERS\x10\r\x12\x17\n\x13\x45VENT_THRESH_PARAMS\x10\x0e\x12\x10\n\x0c\x44\x41\x43_REGISTER\x10\x0f\x12\x10\n\x0c\x44IO_REGISTER\x10\x10\x12\x10\n\x0cTRIGGER_MODE\x10\x11\x12\x11\n\rCABLE_LENGTHS\x10\x12\x12\x11\n\rEVENT_VIEWERS\x10\x13\x12\x0f\n\x0bSAMPLE_RATE\x10\x14\x12\x0e\n\nALL_FIELDS\x10\x15\x12\x16\n\x12SPIKE_SORTER_STATE\x10\x16\x12\x0f\n\x0bSTIM_PARAMS\x10\x17\x42\x15Z\x13internal/radix/grpc'
)

_RADIXFILETYPES = _descriptor.EnumDescriptor(
  name='RadixFileTypes',
  full_name='allego.RadixFileTypes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RHD', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='XDAT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CSV', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HDF5', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEX5', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NWB', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIOINTERFACE', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KILOSORT2', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANC', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPKTRAIN_MU', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIO_RADIENS_EXPORT_HDF5', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIO_RADIENS_EXPORT_MAT5', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NSX', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PL2', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TDT', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPIKES', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_FILE_TYPE', index=17, number=18,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21688,
  serialized_end=21949,
)
_sym_db.RegisterEnumDescriptor(_RADIXFILETYPES)

RadixFileTypes = enum_type_wrapper.EnumTypeWrapper(_RADIXFILETYPES)
_SIGNALTYPE = _descriptor.EnumDescriptor(
  name='SignalType',
  full_name='allego.SignalType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRI', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUX', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUT', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21951,
  serialized_end=22000,
)
_sym_db.RegisterEnumDescriptor(_SIGNALTYPE)

SignalType = enum_type_wrapper.EnumTypeWrapper(_SIGNALTYPE)
_RESAMPLEROUTINE = _descriptor.EnumDescriptor(
  name='ResampleRoutine',
  full_name='allego.ResampleRoutine',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NAIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RETENTIVE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22002,
  serialized_end=22045,
)
_sym_db.RegisterEnumDescriptor(_RESAMPLEROUTINE)

ResampleRoutine = enum_type_wrapper.EnumTypeWrapper(_RESAMPLEROUTINE)
_PORT = _descriptor.EnumDescriptor(
  name='Port',
  full_name='allego.Port',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='A', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='B', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='C', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='D', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='E', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='F', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='H', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22047,
  serialized_end=22109,
)
_sym_db.RegisterEnumDescriptor(_PORT)

Port = enum_type_wrapper.EnumTypeWrapper(_PORT)
_WORKSPACEAPP = _descriptor.EnumDescriptor(
  name='WorkspaceApp',
  full_name='allego.WorkspaceApp',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Allego', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Curate', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Videre', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22111,
  serialized_end=22161,
)
_sym_db.RegisterEnumDescriptor(_WORKSPACEAPP)

WorkspaceApp = enum_type_wrapper.EnumTypeWrapper(_WORKSPACEAPP)
_WORKSPACECOMMANDS = _descriptor.EnumDescriptor(
  name='WorkspaceCommands',
  full_name='allego.WorkspaceCommands',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WSPACE_Save', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WSPACE_SaveAs', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WSPACE_Export', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WSPACE_Import', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WSPACE_Delete', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WSPACE_Switch', index=5, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WSPACE_SwitchToLastUsed', index=6, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22164,
  serialized_end=22324,
)
_sym_db.RegisterEnumDescriptor(_WORKSPACECOMMANDS)

WorkspaceCommands = enum_type_wrapper.EnumTypeWrapper(_WORKSPACECOMMANDS)
_GETWORKSPACECOMMANDS = _descriptor.EnumDescriptor(
  name='GetWorkspaceCommands',
  full_name='allego.GetWorkspaceCommands',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GET_WSPACE_List', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_WSPACE_Current', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22326,
  serialized_end=22393,
)
_sym_db.RegisterEnumDescriptor(_GETWORKSPACECOMMANDS)

GetWorkspaceCommands = enum_type_wrapper.EnumTypeWrapper(_GETWORKSPACECOMMANDS)
_RADIENSSERVERTYPE = _descriptor.EnumDescriptor(
  name='RadiensServerType',
  full_name='allego.RadiensServerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Allegoserver', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Radiensserver', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22395,
  serialized_end=22451,
)
_sym_db.RegisterEnumDescriptor(_RADIENSSERVERTYPE)

RadiensServerType = enum_type_wrapper.EnumTypeWrapper(_RADIENSSERVERTYPE)
_GRPCSERVICETYPE = _descriptor.EnumDescriptor(
  name='GrpcServiceType',
  full_name='allego.GrpcServiceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALLEGO_CORE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALLEGO_PCACHE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALLEGO_KPI', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALLEGO_NEURONS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RADIENS_CORE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RADIENS_SPIKE_SORTER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RADIENS_DEV', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22454,
  serialized_end=22604,
)
_sym_db.RegisterEnumDescriptor(_GRPCSERVICETYPE)

GrpcServiceType = enum_type_wrapper.EnumTypeWrapper(_GRPCSERVICETYPE)
_DEVDATASETTYPE = _descriptor.EnumDescriptor(
  name='DevDatasetType',
  full_name='allego.DevDatasetType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRAIN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALIDATION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEST', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22606,
  serialized_end=22669,
)
_sym_db.RegisterEnumDescriptor(_DEVDATASETTYPE)

DevDatasetType = enum_type_wrapper.EnumTypeWrapper(_DEVDATASETTYPE)
_DATASOURCESORT = _descriptor.EnumDescriptor(
  name='DataSourceSort',
  full_name='allego.DataSourceSort',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DSOURCE_DATE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DSOURCE_NAME', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DSOURCE_SIZE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DSOURCE_TYPE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22671,
  serialized_end=22759,
)
_sym_db.RegisterEnumDescriptor(_DATASOURCESORT)

DataSourceSort = enum_type_wrapper.EnumTypeWrapper(_DATASOURCESORT)
_SIGNALGROUPTYPE = _descriptor.EnumDescriptor(
  name='SignalGroupType',
  full_name='allego.SignalGroupType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRIMARY_CACHE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE', index=1, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22761,
  serialized_end=22807,
)
_sym_db.RegisterEnumDescriptor(_SIGNALGROUPTYPE)

SignalGroupType = enum_type_wrapper.EnumTypeWrapper(_SIGNALGROUPTYPE)
_DSPTYPE = _descriptor.EnumDescriptor(
  name='DSPType',
  full_name='allego.DSPType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOWPASS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HIGHPASS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BANDPASS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOTCH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BANDSTOP', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAR', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL_REFERENCE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAIRED_REFERENCE', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22810,
  serialized_end=22939,
)
_sym_db.RegisterEnumDescriptor(_DSPTYPE)

DSPType = enum_type_wrapper.EnumTypeWrapper(_DSPTYPE)
_FILTERSTAGE = _descriptor.EnumDescriptor(
  name='FilterStage',
  full_name='allego.FilterStage',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STAGE_HARDWARE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STAGE1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STAGE2', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22941,
  serialized_end=22998,
)
_sym_db.RegisterEnumDescriptor(_FILTERSTAGE)

FilterStage = enum_type_wrapper.EnumTypeWrapper(_FILTERSTAGE)
_FEATURELICENSE = _descriptor.EnumDescriptor(
  name='FeatureLicense',
  full_name='allego.FeatureLicense',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Feat_NoLicenseRequired', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_Any', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_Power9', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_RadixAPI', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_Scope', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_Electrodes', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_HDSnapshot', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_Impedance', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_Monitor', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_SignalMetrics', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_SignalProcessing', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_System', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_SpikeGrid', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_SpikeSorter', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_Raster', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Feat_ThreeDModel', index=15, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23001,
  serialized_end=23340,
)
_sym_db.RegisterEnumDescriptor(_FEATURELICENSE)

FeatureLicense = enum_type_wrapper.EnumTypeWrapper(_FEATURELICENSE)
_KPIMETRICSMODE = _descriptor.EnumDescriptor(
  name='KpiMetricsMode',
  full_name='allego.KpiMetricsMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Kpi_MetricsMode_Base', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_MetricsMode_Avg', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_MetricsMode_Stream', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23342,
  serialized_end=23437,
)
_sym_db.RegisterEnumDescriptor(_KPIMETRICSMODE)

KpiMetricsMode = enum_type_wrapper.EnumTypeWrapper(_KPIMETRICSMODE)
_KPIMETRICSENUM = _descriptor.EnumDescriptor(
  name='KpiMetricsEnum',
  full_name='allego.KpiMetricsEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KPI_NUM_PTS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_NUM_PTS_ISI', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_DUR_SEC', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MEAN', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MIN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MIN_ISI', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MAX', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MAX_ISI', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MAX_ABS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MAX_ABS_ISI', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_TIMESTAMP_MIN', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_TIMESTAMP_MAX', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MAX_MIN_DIFF_ABS', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MAX_MIN_DIFF_ABS_ISI', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_SD', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_SD_ISI', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_VAR', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_VAR_ISI', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_RMS', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_RMS_ISI', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_NOISE_UV', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_SNR', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_NUM_EVENTS', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT_RATE', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT_MAX', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT_MIN', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT_MAX_ABS', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT_MAX_MIN_DIFF_ABS', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT_TIMESTAMP_MIN', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT_TIMESTAMP_MAX', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT_TIMESTAMP_MAX_ABS', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT_TIMESTAMP_MAX_MIN_DIFF_ABS', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MEAN_MAX', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MEAN_MIN', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_MEAN_MAX_ABS', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_EVENT_MEAN_MAX_MIN_DIFF_ABS', index=35, number=35,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23440,
  serialized_end=24205,
)
_sym_db.RegisterEnumDescriptor(_KPIMETRICSENUM)

KpiMetricsEnum = enum_type_wrapper.EnumTypeWrapper(_KPIMETRICSENUM)
_KPIMETRICSSTATSENUM = _descriptor.EnumDescriptor(
  name='KpiMetricsStatsEnum',
  full_name='allego.KpiMetricsStatsEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_METRICS_STATS_MEAN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_METRICS_STATS_MAX', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_METRICS_STATS_MIN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_METRICS_SD', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=24208,
  serialized_end=24347,
)
_sym_db.RegisterEnumDescriptor(_KPIMETRICSSTATSENUM)

KpiMetricsStatsEnum = enum_type_wrapper.EnumTypeWrapper(_KPIMETRICSSTATSENUM)
_KPIBUNDLEPACKETSSTATSENUM = _descriptor.EnumDescriptor(
  name='KpiBundlePacketsStatsEnum',
  full_name='allego.KpiBundlePacketsStatsEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_NUM_SIGS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_DUR_SEC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_NUM_SIGS_W_EVENTS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_SIG_YIELD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_RMS_AVG', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_SNR_AVG', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_SIG_MAX', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_SIG_MIN', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_NOISE_UV_AVG', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_NUM_EVENTS_TOTAL', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_NUM_EVENTS_AVG', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KPI_BDL_EVENT_RATE_AVG', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=24350,
  serialized_end=24670,
)
_sym_db.RegisterEnumDescriptor(_KPIBUNDLEPACKETSSTATSENUM)

KpiBundlePacketsStatsEnum = enum_type_wrapper.EnumTypeWrapper(_KPIBUNDLEPACKETSSTATSENUM)
_KPIBUNDLENAME = _descriptor.EnumDescriptor(
  name='KpiBundleName',
  full_name='allego.KpiBundleName',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Kpi_A', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_B', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_C', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_D', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_Aux0', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_Aux1', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_Datasource', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_E', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_F', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_G', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_H', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=24673,
  serialized_end=24824,
)
_sym_db.RegisterEnumDescriptor(_KPIBUNDLENAME)

KpiBundleName = enum_type_wrapper.EnumTypeWrapper(_KPIBUNDLENAME)
_TIMERANGESELMODE = _descriptor.EnumDescriptor(
  name='TimeRangeSelMode',
  full_name='allego.TimeRangeSelMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRS_SUBSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRS_TO_HEAD', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRS_FROM_HEAD', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=24826,
  serialized_end=24896,
)
_sym_db.RegisterEnumDescriptor(_TIMERANGESELMODE)

TimeRangeSelMode = enum_type_wrapper.EnumTypeWrapper(_TIMERANGESELMODE)
_KPITHRESHOLDNAME = _descriptor.EnumDescriptor(
  name='KpiThresholdName',
  full_name='allego.KpiThresholdName',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Kpi_Thr_Event', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_Thr_Artifact_Reject', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=24898,
  serialized_end=24964,
)
_sym_db.RegisterEnumDescriptor(_KPITHRESHOLDNAME)

KpiThresholdName = enum_type_wrapper.EnumTypeWrapper(_KPITHRESHOLDNAME)
_KPIWINDOWDNAME = _descriptor.EnumDescriptor(
  name='KpiWindowdName',
  full_name='allego.KpiWindowdName',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Kpi_Wdw_Event', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Kpi_Wdw_Artifact_Reject', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=24966,
  serialized_end=25030,
)
_sym_db.RegisterEnumDescriptor(_KPIWINDOWDNAME)

KpiWindowdName = enum_type_wrapper.EnumTypeWrapper(_KPIWINDOWDNAME)
_OUTFITTERCOMPONENTTYPE = _descriptor.EnumDescriptor(
  name='OutfitterComponentType',
  full_name='allego.OutfitterComponentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUTFIT_COMP_SENSOR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUTFIT_COMP_SPIKE_SORTER', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25032,
  serialized_end=25110,
)
_sym_db.RegisterEnumDescriptor(_OUTFITTERCOMPONENTTYPE)

OutfitterComponentType = enum_type_wrapper.EnumTypeWrapper(_OUTFITTERCOMPONENTTYPE)
_WORLDNODELABEL = _descriptor.EnumDescriptor(
  name='WorldNodeLabel',
  full_name='allego.WorldNodeLabel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WORLD_NODE_ORG', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORLD_NODE_LAB', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORLD_NODE_USER', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORLD_NODE_CAT_PROBE', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORLD_NODE_PROBE', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25112,
  serialized_end=25237,
)
_sym_db.RegisterEnumDescriptor(_WORLDNODELABEL)

WorldNodeLabel = enum_type_wrapper.EnumTypeWrapper(_WORLDNODELABEL)
_WORLDEDGELABEL = _descriptor.EnumDescriptor(
  name='WorldEdgeLabel',
  full_name='allego.WorldEdgeLabel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WORLD_EDGE_MEMBER', index=0, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25239,
  serialized_end=25278,
)
_sym_db.RegisterEnumDescriptor(_WORLDEDGELABEL)

WorldEdgeLabel = enum_type_wrapper.EnumTypeWrapper(_WORLDEDGELABEL)
_WORLDEDGEDIRECTION = _descriptor.EnumDescriptor(
  name='WorldEdgeDirection',
  full_name='allego.WorldEdgeDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WORLD_EDGE_DIR_RIGHT', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORLD_EDGE_DIR_LEFT', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WORLD_EDGE_DIR_BOTH', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25280,
  serialized_end=25376,
)
_sym_db.RegisterEnumDescriptor(_WORLDEDGEDIRECTION)

WorldEdgeDirection = enum_type_wrapper.EnumTypeWrapper(_WORLDEDGEDIRECTION)
_USERROLETYPE = _descriptor.EnumDescriptor(
  name='UserRoleType',
  full_name='allego.UserRoleType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER_PI', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_SCIENTIST', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_POST_DOC', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_GRAD_STUDENT', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_UG_STUDENT', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_MANAGER', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_TECH', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_OTHER', index=7, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25379,
  serialized_end=25538,
)
_sym_db.RegisterEnumDescriptor(_USERROLETYPE)

UserRoleType = enum_type_wrapper.EnumTypeWrapper(_USERROLETYPE)
_MANAGENODECMD = _descriptor.EnumDescriptor(
  name='ManageNodeCmd',
  full_name='allego.ManageNodeCmd',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NODE_CMD_NEW', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NODE_CMD_MERGE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NODE_CMD_DEL', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25540,
  serialized_end=25611,
)
_sym_db.RegisterEnumDescriptor(_MANAGENODECMD)

ManageNodeCmd = enum_type_wrapper.EnumTypeWrapper(_MANAGENODECMD)
_WORLDQUERYCMD = _descriptor.EnumDescriptor(
  name='WorldQueryCmd',
  full_name='allego.WorldQueryCmd',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WQ_LIST_ALL_USERS', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WQ_LIST_ALL_LABS', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WQ_LIST_ALL_ORGS', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WQ_LIST_ALL_CAT_PROBES', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WQ_LIST_ALL_PROBES', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WQ_CAT_PROBE_BY_NAME', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WQ_USER_BY_ID', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WQ_USER_AND_LAB_BY_ID', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WQ2_LIST_ALL_DEVICES', index=8, number=30,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25614,
  serialized_end=25846,
)
_sym_db.RegisterEnumDescriptor(_WORLDQUERYCMD)

WorldQueryCmd = enum_type_wrapper.EnumTypeWrapper(_WORLDQUERYCMD)
_TRANSFORMNODETYPE = _descriptor.EnumDescriptor(
  name='TransformNodeType',
  full_name='allego.TransformNodeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOTCH_FILTER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BANDPASS_FILTER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BANDSTOP_FILTER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HIGHPASS_FILTER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOWPASS_FILTER', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAIRED_REF', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL_REF', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAR_REF', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SLICE_TIME', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SLICE_CHANNELS', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOURCE', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SINK', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOWNSAMPLE', index=12, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25849,
  serialized_end=26089,
)
_sym_db.RegisterEnumDescriptor(_TRANSFORMNODETYPE)

TransformNodeType = enum_type_wrapper.EnumTypeWrapper(_TRANSFORMNODETYPE)
_SPIKESORTERPARAMCOMMAND = _descriptor.EnumDescriptor(
  name='SpikeSorterParamCommand',
  full_name='allego.SpikeSorterParamCommand',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SORTER_THR_LEVEL', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_THR_LEVEL_SD', index=1, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_THR_WDW', index=2, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_WEAK_THR_LEVEL', index=3, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_WEAK_THR_LEVEL_SD', index=4, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_SHADOW', index=5, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_THR_ACTIVATE', index=6, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORTER_WEAK_THR_ACTIVATE', index=7, number=21,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=26092,
  serialized_end=26315,
)
_sym_db.RegisterEnumDescriptor(_SPIKESORTERPARAMCOMMAND)

SpikeSorterParamCommand = enum_type_wrapper.EnumTypeWrapper(_SPIKESORTERPARAMCOMMAND)
_WRANGLEMODE = _descriptor.EnumDescriptor(
  name='WrangleMode',
  full_name='allego.WrangleMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WRANGLE_MODE_IMPORT_NNX_VEX_SPIKES_SIM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRANGLE_MODE_MERGE_FIT_VIEW', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=26317,
  serialized_end=26407,
)
_sym_db.RegisterEnumDescriptor(_WRANGLEMODE)

WrangleMode = enum_type_wrapper.EnumTypeWrapper(_WRANGLEMODE)
_STATUSPOLLFIELDS = _descriptor.EnumDescriptor(
  name='StatusPollFields',
  full_name='allego.StatusPollFields',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PORT_CONNECTION_STATE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECORDING_ERRORS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STREAM_TIME_RANGE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STREAM_STATUS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECORD_STATUS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GPIO_CHANNEL_COUNT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IS_CONNECTED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECORD_DUR', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BACKBONE_MODE', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNAL_GROUP', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SINAPS_REGISTERS', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECORDING_CONFIG', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILTERS', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_THRESH_PARAMS', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DAC_REGISTER', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIO_REGISTER', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRIGGER_MODE', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CABLE_LENGTHS', index=17, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EVENT_VIEWERS', index=18, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAMPLE_RATE', index=19, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL_FIELDS', index=20, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPIKE_SORTER_STATE', index=21, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STIM_PARAMS', index=22, number=23,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=26410,
  serialized_end=26881,
)
_sym_db.RegisterEnumDescriptor(_STATUSPOLLFIELDS)

StatusPollFields = enum_type_wrapper.EnumTypeWrapper(_STATUSPOLLFIELDS)
RHD = 0
XDAT = 1
CSV = 2
HDF5 = 3
NEX5 = 4
NWB = 5
BIOINTERFACE = 7
KILOSORT2 = 8
ANC = 9
SPKTRAIN_MU = 10
BIO_RADIENS_EXPORT_HDF5 = 11
BIO_RADIENS_EXPORT_MAT5 = 12
NSX = 13
PL2 = 14
TDT = 15
SPIKES = 16
KPI = 17
UNKNOWN_FILE_TYPE = 18
PRI = 0
AUX = 1
DIN = 2
DOUT = 3
NAIVE = 0
RETENTIVE = 1
A = 0
B = 1
C = 2
D = 3
E = 4
F = 5
G = 6
H = 7
Allego = 0
Curate = 1
Videre = 2
WSPACE_Save = 0
WSPACE_SaveAs = 1
WSPACE_Export = 2
WSPACE_Import = 3
WSPACE_Delete = 4
WSPACE_Switch = 7
WSPACE_SwitchToLastUsed = 8
GET_WSPACE_List = 1
GET_WSPACE_Current = 2
Allegoserver = 0
Radiensserver = 1
ALLEGO_CORE = 0
ALLEGO_PCACHE = 1
ALLEGO_KPI = 2
ALLEGO_NEURONS = 3
RADIENS_CORE = 4
RADIENS_SPIKE_SORTER = 5
RADIENS_DEV = 6
BASE = 0
TRAIN = 1
VALIDATION = 2
TEST = 3
DSOURCE_DATE = 0
DSOURCE_NAME = 1
DSOURCE_SIZE = 2
DSOURCE_TYPE = 3
PRIMARY_CACHE = 0
FILE = 3
LOWPASS = 0
HIGHPASS = 1
BANDPASS = 2
NOTCH = 3
BANDSTOP = 4
CAR = 5
VIRTUAL_REFERENCE = 6
PAIRED_REFERENCE = 7
STAGE_HARDWARE = 0
STAGE1 = 1
STAGE2 = 2
Feat_NoLicenseRequired = 0
Feat_Any = 1
Feat_Power9 = 2
Feat_RadixAPI = 3
Feat_Scope = 4
Feat_Electrodes = 5
Feat_HDSnapshot = 6
Feat_Impedance = 7
Feat_Monitor = 8
Feat_SignalMetrics = 9
Feat_SignalProcessing = 10
Feat_System = 11
Feat_SpikeGrid = 12
Feat_SpikeSorter = 13
Feat_Raster = 14
Feat_ThreeDModel = 15
Kpi_MetricsMode_Base = 0
Kpi_MetricsMode_Avg = 1
Kpi_MetricsMode_Stream = 2
KPI_NUM_PTS = 0
KPI_NUM_PTS_ISI = 1
KPI_DUR_SEC = 2
KPI_MEAN = 3
KPI_MIN = 4
KPI_MIN_ISI = 5
KPI_MAX = 6
KPI_MAX_ISI = 7
KPI_MAX_ABS = 8
KPI_MAX_ABS_ISI = 9
KPI_TIMESTAMP_MIN = 10
KPI_TIMESTAMP_MAX = 11
KPI_MAX_MIN_DIFF_ABS = 12
KPI_MAX_MIN_DIFF_ABS_ISI = 13
KPI_SD = 14
KPI_SD_ISI = 15
KPI_VAR = 16
KPI_VAR_ISI = 17
KPI_RMS = 18
KPI_RMS_ISI = 19
KPI_NOISE_UV = 20
KPI_SNR = 21
KPI_NUM_EVENTS = 22
KPI_EVENT_RATE = 23
KPI_EVENT_MAX = 24
KPI_EVENT_MIN = 25
KPI_EVENT_MAX_ABS = 26
KPI_EVENT_MAX_MIN_DIFF_ABS = 27
KPI_EVENT_TIMESTAMP_MIN = 28
KPI_EVENT_TIMESTAMP_MAX = 29
KPI_EVENT_TIMESTAMP_MAX_ABS = 30
KPI_EVENT_TIMESTAMP_MAX_MIN_DIFF_ABS = 31
KPI_MEAN_MAX = 32
KPI_MEAN_MIN = 33
KPI_MEAN_MAX_ABS = 34
KPI_EVENT_MEAN_MAX_MIN_DIFF_ABS = 35
KPI_BDL_METRICS_STATS_MEAN = 0
KPI_BDL_METRICS_STATS_MAX = 1
KPI_BDL_METRICS_STATS_MIN = 2
KPI_BDL_METRICS_SD = 3
KPI_BDL_NUM_SIGS = 0
KPI_BDL_DUR_SEC = 1
KPI_BDL_NUM_SIGS_W_EVENTS = 2
KPI_BDL_SIG_YIELD = 3
KPI_BDL_RMS_AVG = 4
KPI_BDL_SNR_AVG = 5
KPI_BDL_SIG_MAX = 6
KPI_BDL_SIG_MIN = 7
KPI_BDL_NOISE_UV_AVG = 8
KPI_BDL_NUM_EVENTS_TOTAL = 9
KPI_BDL_NUM_EVENTS_AVG = 10
KPI_BDL_EVENT_RATE_AVG = 11
Kpi_A = 0
Kpi_B = 1
Kpi_C = 2
Kpi_D = 3
Kpi_Aux0 = 4
Kpi_Aux1 = 5
Kpi_Datasource = 6
Kpi_E = 7
Kpi_F = 8
Kpi_G = 9
Kpi_H = 10
TRS_SUBSET = 0
TRS_TO_HEAD = 1
TRS_FROM_HEAD = 2
Kpi_Thr_Event = 0
Kpi_Thr_Artifact_Reject = 1
Kpi_Wdw_Event = 0
Kpi_Wdw_Artifact_Reject = 1
OUTFIT_COMP_SENSOR = 0
OUTFIT_COMP_SPIKE_SORTER = 1
WORLD_NODE_ORG = 1
WORLD_NODE_LAB = 2
WORLD_NODE_USER = 3
WORLD_NODE_CAT_PROBE = 4
WORLD_NODE_PROBE = 5
WORLD_EDGE_MEMBER = 1
WORLD_EDGE_DIR_RIGHT = 1
WORLD_EDGE_DIR_LEFT = 2
WORLD_EDGE_DIR_BOTH = 3
USER_PI = 1
USER_SCIENTIST = 2
USER_POST_DOC = 3
USER_GRAD_STUDENT = 4
USER_UG_STUDENT = 5
USER_MANAGER = 6
USER_TECH = 7
USER_OTHER = 8
NODE_CMD_NEW = 1
NODE_CMD_MERGE = 2
NODE_CMD_DEL = 3
WQ_LIST_ALL_USERS = 1
WQ_LIST_ALL_LABS = 2
WQ_LIST_ALL_ORGS = 3
WQ_LIST_ALL_CAT_PROBES = 4
WQ_LIST_ALL_PROBES = 5
WQ_CAT_PROBE_BY_NAME = 6
WQ_USER_BY_ID = 7
WQ_USER_AND_LAB_BY_ID = 8
WQ2_LIST_ALL_DEVICES = 30
NOTCH_FILTER = 0
BANDPASS_FILTER = 1
BANDSTOP_FILTER = 2
HIGHPASS_FILTER = 3
LOWPASS_FILTER = 4
PAIRED_REF = 5
VIRTUAL_REF = 6
CAR_REF = 7
SLICE_TIME = 9
SLICE_CHANNELS = 10
SOURCE = 11
SINK = 12
DOWNSAMPLE = 13
SORTER_THR_LEVEL = 1
SORTER_THR_LEVEL_SD = 4
SORTER_THR_WDW = 8
SORTER_WEAK_THR_LEVEL = 10
SORTER_WEAK_THR_LEVEL_SD = 13
SORTER_SHADOW = 17
SORTER_THR_ACTIVATE = 19
SORTER_WEAK_THR_ACTIVATE = 21
WRANGLE_MODE_IMPORT_NNX_VEX_SPIKES_SIM = 0
WRANGLE_MODE_MERGE_FIT_VIEW = 1
PORT_CONNECTION_STATE = 0
RECORDING_ERRORS = 1
STREAM_TIME_RANGE = 2
STREAM_STATUS = 3
RECORD_STATUS = 4
GPIO_CHANNEL_COUNT = 5
IS_CONNECTED = 6
RECORD_DUR = 7
BACKBONE_MODE = 9
SIGNAL_GROUP = 10
SINAPS_REGISTERS = 11
RECORDING_CONFIG = 12
FILTERS = 13
EVENT_THRESH_PARAMS = 14
DAC_REGISTER = 15
DIO_REGISTER = 16
TRIGGER_MODE = 17
CABLE_LENGTHS = 18
EVENT_VIEWERS = 19
SAMPLE_RATE = 20
ALL_FIELDS = 21
SPIKE_SORTER_STATE = 22
STIM_PARAMS = 23


_SUBOPSORT_SORTFIELD = _descriptor.EnumDescriptor(
  name='SortField',
  full_name='allego.SubOpSort.SortField',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SITE_CTR_X', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SITE_CTR_Y', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SITE_CTR_Z', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6151,
  serialized_end=6210,
)
_sym_db.RegisterEnumDescriptor(_SUBOPSORT_SORTFIELD)

_UPDATESIGNALGROUPREQUEST_OPERATION = _descriptor.EnumDescriptor(
  name='Operation',
  full_name='allego.UpdateSignalGroupRequest.Operation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COLOR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SELECT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEPRECATED_AUDIO', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SORT', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6496,
  serialized_end=6562,
)
_sym_db.RegisterEnumDescriptor(_UPDATESIGNALGROUPREQUEST_OPERATION)

_UPDATESIGNALGROUPREQUEST_SUBOPERATION = _descriptor.EnumDescriptor(
  name='SubOperation',
  full_name='allego.UpdateSignalGroupRequest.SubOperation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADD', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOVE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6564,
  serialized_end=6599,
)
_sym_db.RegisterEnumDescriptor(_UPDATESIGNALGROUPREQUEST_SUBOPERATION)


_RADIXENVIRONMENT = _descriptor.Descriptor(
  name='RadixEnvironment',
  full_name='allego.RadixEnvironment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='allego.RadixEnvironment.version', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userDataPath', full_name='allego.RadixEnvironment.userDataPath', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=81,
)


_STANDARDREQUEST = _descriptor.Descriptor(
  name='StandardRequest',
  full_name='allego.StandardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=100,
)


_STANDARDREPLY = _descriptor.Descriptor(
  name='StandardReply',
  full_name='allego.StandardReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errMsg', full_name='allego.StandardReply.errMsg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=133,
)


_DACOFFREQUEST = _descriptor.Descriptor(
  name='DACOffRequest',
  full_name='allego.DACOffRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.DACOffRequest.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=173,
)


_WORKSPACEDESCRIPTOR = _descriptor.Descriptor(
  name='WorkspaceDescriptor',
  full_name='allego.WorkspaceDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iD', full_name='allego.WorkspaceDescriptor.iD', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app', full_name='allego.WorkspaceDescriptor.app', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isModified', full_name='allego.WorkspaceDescriptor.isModified', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampLastUsed', full_name='allego.WorkspaceDescriptor.timestampLastUsed', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampModified', full_name='allego.WorkspaceDescriptor.timestampModified', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation', full_name='allego.WorkspaceDescriptor.annotation', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=362,
)


_WORKSPACECONTROLREQUEST = _descriptor.Descriptor(
  name='WorkspaceControlRequest',
  full_name='allego.WorkspaceControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='allego.WorkspaceControlRequest.cmd', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspaceID', full_name='allego.WorkspaceControlRequest.workspaceID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation', full_name='allego.WorkspaceControlRequest.annotation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetFullFileName', full_name='allego.WorkspaceControlRequest.targetFullFileName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isForceOverwrite', full_name='allego.WorkspaceControlRequest.isForceOverwrite', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=549,
)


_GETWORKSPACEREQUEST = _descriptor.Descriptor(
  name='GetWorkspaceRequest',
  full_name='allego.GetWorkspaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='allego.GetWorkspaceRequest.cmd', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspaceID', full_name='allego.GetWorkspaceRequest.workspaceID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspaceDir', full_name='allego.GetWorkspaceRequest.workspaceDir', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appMask', full_name='allego.GetWorkspaceRequest.appMask', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotateMask', full_name='allego.GetWorkspaceRequest.annotateMask', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isBrowser', full_name='allego.GetWorkspaceRequest.isBrowser', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=763,
)


_GETWORKSPACEREPLY_WORKSPACEDESCENTRY = _descriptor.Descriptor(
  name='WorkspaceDescEntry',
  full_name='allego.GetWorkspaceReply.WorkspaceDescEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.GetWorkspaceReply.WorkspaceDescEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.GetWorkspaceReply.WorkspaceDescEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=937,
)

_GETWORKSPACEREPLY = _descriptor.Descriptor(
  name='GetWorkspaceReply',
  full_name='allego.GetWorkspaceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspaceDesc', full_name='allego.GetWorkspaceReply.workspaceDesc', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETWORKSPACEREPLY_WORKSPACEDESCENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=937,
)


_GETRADIENSSERVERSREQUEST = _descriptor.Descriptor(
  name='GetRadiensServersRequest',
  full_name='allego.GetRadiensServersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hostIPaddress', full_name='allego.GetRadiensServersRequest.hostIPaddress', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverType', full_name='allego.GetRadiensServersRequest.serverType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=1035,
)


_SERVERSPEC_GRPCSERVICE = _descriptor.Descriptor(
  name='GrpcService',
  full_name='allego.ServerSpec.GrpcService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.ServerSpec.GrpcService.port', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1179,
  serialized_end=1206,
)

_SERVERSPEC_SPAWNEDPROCESS = _descriptor.Descriptor(
  name='SpawnedProcess',
  full_name='allego.ServerSpec.SpawnedProcess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='allego.ServerSpec.SpawnedProcess.pid', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1237,
)

_SERVERSPEC_SERVICEENTRY = _descriptor.Descriptor(
  name='ServiceEntry',
  full_name='allego.ServerSpec.ServiceEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.ServerSpec.ServiceEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.ServerSpec.ServiceEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1317,
)

_SERVERSPEC = _descriptor.Descriptor(
  name='ServerSpec',
  full_name='allego.ServerSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='allego.ServerSpec.host', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pid', full_name='allego.ServerSpec.pid', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='allego.ServerSpec.service', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spawn', full_name='allego.ServerSpec.spawn', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SERVERSPEC_GRPCSERVICE, _SERVERSPEC_SPAWNEDPROCESS, _SERVERSPEC_SERVICEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1317,
)


_RADIENSSERVERSREPLY = _descriptor.Descriptor(
  name='RadiensServersReply',
  full_name='allego.RadiensServersReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='allegoserver', full_name='allego.RadiensServersReply.allegoserver', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='radiensserver', full_name='allego.RadiensServersReply.radiensserver', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1319,
  serialized_end=1425,
)


_SIGNALGROUPIDREQUEST = _descriptor.Descriptor(
  name='SignalGroupIDRequest',
  full_name='allego.SignalGroupIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.SignalGroupIDRequest.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=1472,
)


_SIGNALMAP = _descriptor.Descriptor(
  name='SignalMap',
  full_name='allego.SignalMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='siteIdx', full_name='allego.SignalMap.siteIdx', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compSiteNum', full_name='allego.SignalMap.compSiteNum', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbeUmX', full_name='allego.SignalMap.posProbeUmX', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbeUmY', full_name='allego.SignalMap.posProbeUmY', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbeUmZ', full_name='allego.SignalMap.posProbeUmZ', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posTissueUmX', full_name='allego.SignalMap.posTissueUmX', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posTissueUmY', full_name='allego.SignalMap.posTissueUmY', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posTissueUmZ', full_name='allego.SignalMap.posTissueUmZ', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorID', full_name='allego.SignalMap.sensorID', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1475,
  serialized_end=1671,
)


_GPIOCHANNELCOUNT = _descriptor.Descriptor(
  name='GPIOChannelCount',
  full_name='allego.GPIOChannelCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nAux', full_name='allego.GPIOChannelCount.nAux', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nDin', full_name='allego.GPIOChannelCount.nDin', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nDout', full_name='allego.GPIOChannelCount.nDout', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1673,
  serialized_end=1734,
)


_PORTCHANNELCOUNT = _descriptor.Descriptor(
  name='PortChannelCount',
  full_name='allego.PortChannelCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.PortChannelCount.port', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channelCount', full_name='allego.PortChannelCount.channelCount', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1736,
  serialized_end=1804,
)


_SETPORTREQUEST = _descriptor.Descriptor(
  name='SetPortRequest',
  full_name='allego.SetPortRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.SetPortRequest.port', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probeUID', full_name='allego.SetPortRequest.probeUID', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hstageUID', full_name='allego.SetPortRequest.hstageUID', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1806,
  serialized_end=1887,
)


_HDSNAPSHOTREQUEST_SELECTEDSIGNALS = _descriptor.Descriptor(
  name='SelectedSignals',
  full_name='allego.HDSnapshotRequest.SelectedSignals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdxs', full_name='allego.HDSnapshotRequest.SelectedSignals.ntvChanIdxs', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2206,
  serialized_end=2244,
)

_HDSNAPSHOTREQUEST = _descriptor.Descriptor(
  name='HDSnapshotRequest',
  full_name='allego.HDSnapshotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.HDSnapshotRequest.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.HDSnapshotRequest.timeRange', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priSignals', full_name='allego.HDSnapshotRequest.priSignals', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auxSignals', full_name='allego.HDSnapshotRequest.auxSignals', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dinSignals', full_name='allego.HDSnapshotRequest.dinSignals', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doutSignals', full_name='allego.HDSnapshotRequest.doutSignals', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HDSNAPSHOTREQUEST_SELECTEDSIGNALS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1890,
  serialized_end=2244,
)


_HDSNAPSHOTMETA = _descriptor.Descriptor(
  name='HDSnapshotMeta',
  full_name='allego.HDSnapshotMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='globalMin', full_name='allego.HDSnapshotMeta.globalMin', index=0,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='globalMax', full_name='allego.HDSnapshotMeta.globalMax', index=1,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigGroup', full_name='allego.HDSnapshotMeta.sigGroup', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2246,
  serialized_end=2339,
)


_HDSNAPSHOT = _descriptor.Descriptor(
  name='HDSnapshot',
  full_name='allego.HDSnapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='allego.HDSnapshot.meta', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.HDSnapshot.sampFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeSamples', full_name='allego.HDSnapshot.timeSamples', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signals', full_name='allego.HDSnapshot.signals', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priSignals', full_name='allego.HDSnapshot.priSignals', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auxSignals', full_name='allego.HDSnapshot.auxSignals', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dinSignals', full_name='allego.HDSnapshot.dinSignals', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doutSignals', full_name='allego.HDSnapshot.doutSignals', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2342,
  serialized_end=2629,
)


_GETSIGNALSREQUEST_GETSIGSPARAMS = _descriptor.Descriptor(
  name='GetSigsParams',
  full_name='allego.GetSignalsRequest.GetSigsParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.GetSignalsRequest.GetSigsParams.timeRange', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeWindow', full_name='allego.GetSignalsRequest.GetSigsParams.timeWindow', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spacing', full_name='allego.GetSignalsRequest.GetSigsParams.spacing', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='magnitude', full_name='allego.GetSignalsRequest.GetSigsParams.magnitude', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plotWidthPoints', full_name='allego.GetSignalsRequest.GetSigsParams.plotWidthPoints', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpioOnTop', full_name='allego.GetSignalsRequest.GetSigsParams.gpioOnTop', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auxMagnitude', full_name='allego.GetSignalsRequest.GetSigsParams.auxMagnitude', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='componentID', full_name='allego.GetSignalsRequest.GetSigsParams.componentID', index=7,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resampleType', full_name='allego.GetSignalsRequest.GetSigsParams.resampleType', index=8,
      number=9, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2734,
  serialized_end=2958,
)

_GETSIGNALSREQUEST = _descriptor.Descriptor(
  name='GetSignalsRequest',
  full_name='allego.GetSignalsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.GetSignalsRequest.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='allego.GetSignalsRequest.params', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETSIGNALSREQUEST_GETSIGSPARAMS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2632,
  serialized_end=2958,
)


_RAWSIGNALS = _descriptor.Descriptor(
  name='RawSignals',
  full_name='allego.RawSignals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='allego.RawSignals.shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.RawSignals.timeRange', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='allego.RawSignals.data', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2960,
  serialized_end=3020,
)


_LISTSENSORSPECSREPLY_SPECWITHCHANNELCOUNT = _descriptor.Descriptor(
  name='SpecWithChannelCount',
  full_name='allego.ListSensorSpecsReply.SpecWithChannelCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.ListSensorSpecsReply.SpecWithChannelCount.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channelCount', full_name='allego.ListSensorSpecsReply.SpecWithChannelCount.channelCount', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3226,
  serialized_end=3284,
)

_LISTSENSORSPECSREPLY = _descriptor.Descriptor(
  name='ListSensorSpecsReply',
  full_name='allego.ListSensorSpecsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='probes', full_name='allego.ListSensorSpecsReply.probes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headstages', full_name='allego.ListSensorSpecsReply.headstages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ports', full_name='allego.ListSensorSpecsReply.ports', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTSENSORSPECSREPLY_SPECWITHCHANNELCOUNT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3023,
  serialized_end=3284,
)


_LISTDATASOURCESREQUEST = _descriptor.Descriptor(
  name='ListDataSourcesRequest',
  full_name='allego.ListDataSourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='directory', full_name='allego.ListDataSourcesRequest.directory', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortBy', full_name='allego.ListDataSourcesRequest.sortBy', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3286,
  serialized_end=3369,
)


_GETSIGNALGROUPIDSREPLY = _descriptor.Descriptor(
  name='GetSignalGroupIDsReply',
  full_name='allego.GetSignalGroupIDsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='continuous', full_name='allego.GetSignalGroupIDsReply.continuous', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='discrete', full_name='allego.GetSignalGroupIDsReply.discrete', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3371,
  serialized_end=3433,
)


_DATASOURCE = _descriptor.Descriptor(
  name='DataSource',
  full_name='allego.DataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.DataSource.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='allego.DataSource.date', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='durationSeconds', full_name='allego.DataSource.durationSeconds', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='durationMinutes', full_name='allego.DataSource.durationMinutes', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='durationHours', full_name='allego.DataSource.durationHours', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileType', full_name='allego.DataSource.fileType', index=5,
      number=6, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSignals', full_name='allego.DataSource.numSignals', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3436,
  serialized_end=3611,
)


_FILEDESCRIPTOR = _descriptor.Descriptor(
  name='FileDescriptor',
  full_name='allego.FileDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='allego.FileDescriptor.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseName', full_name='allego.FileDescriptor.baseName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileType', full_name='allego.FileDescriptor.fileType', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileNameUID', full_name='allego.FileDescriptor.fileNameUID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3613,
  serialized_end=3724,
)


_TIMESPEC_TIMERANGEL = _descriptor.Descriptor(
  name='TimeRangeL',
  full_name='allego.TimeSpec.TimeRangeL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.TimeSpec.TimeRangeL.timeRange', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3849,
  serialized_end=3880,
)

_TIMESPEC_TIMESTAMPRANGEL = _descriptor.Descriptor(
  name='TimestampRangeL',
  full_name='allego.TimeSpec.TimestampRangeL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.TimeSpec.TimestampRangeL.timestampRange', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3882,
  serialized_end=3923,
)

_TIMESPEC = _descriptor.Descriptor(
  name='TimeSpec',
  full_name='allego.TimeSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.TimeSpec.timeRange', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.TimeSpec.timestampRange', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TIMESPEC_TIMERANGEL, _TIMESPEC_TIMESTAMPRANGEL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='timeDesc', full_name='allego.TimeSpec.timeDesc',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3727,
  serialized_end=3935,
)


_SIGNALSPEC_SITENUML = _descriptor.Descriptor(
  name='SiteNumL',
  full_name='allego.SignalSpec.SiteNumL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='siteNum', full_name='allego.SignalSpec.SiteNumL.siteNum', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4054,
  serialized_end=4081,
)

_SIGNALSPEC_NTVCHANIDXL = _descriptor.Descriptor(
  name='NtvChanIdxL',
  full_name='allego.SignalSpec.NtvChanIdxL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SignalSpec.NtvChanIdxL.ntvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4083,
  serialized_end=4116,
)

_SIGNALSPEC = _descriptor.Descriptor(
  name='SignalSpec',
  full_name='allego.SignalSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='siteNum', full_name='allego.SignalSpec.siteNum', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SignalSpec.ntvChanIdx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SIGNALSPEC_SITENUML, _SIGNALSPEC_NTVCHANIDXL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='siteDesc', full_name='allego.SignalSpec.siteDesc',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3938,
  serialized_end=4128,
)


_CHANNELRECORD = _descriptor.Descriptor(
  name='ChannelRecord',
  full_name='allego.ChannelRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chanName', full_name='allego.ChannelRecord.chanName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chanType', full_name='allego.ChannelRecord.chanType', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.ChannelRecord.ntvChanIdx', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteNum', full_name='allego.ChannelRecord.siteNum', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='colorGroupIdx', full_name='allego.ChannelRecord.colorGroupIdx', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSelected', full_name='allego.ChannelRecord.isSelected', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isAudioLeft', full_name='allego.ChannelRecord.isAudioLeft', index=6,
      number=7, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.ChannelRecord.port', index=7,
      number=8, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteShape', full_name='allego.ChannelRecord.siteShape', index=8,
      number=9, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteCtrX', full_name='allego.ChannelRecord.siteCtrX', index=9,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteCtrY', full_name='allego.ChannelRecord.siteCtrY', index=10,
      number=11, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteCtrZ', full_name='allego.ChannelRecord.siteCtrZ', index=11,
      number=12, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteLimXMin', full_name='allego.ChannelRecord.siteLimXMin', index=12,
      number=13, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteLimXMax', full_name='allego.ChannelRecord.siteLimXMax', index=13,
      number=14, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteLimYMin', full_name='allego.ChannelRecord.siteLimYMin', index=14,
      number=15, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteLimYMax', full_name='allego.ChannelRecord.siteLimYMax', index=15,
      number=16, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteLimZMin', full_name='allego.ChannelRecord.siteLimZMin', index=16,
      number=17, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteLimZMax', full_name='allego.ChannelRecord.siteLimZMax', index=17,
      number=18, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteCtrTcsX', full_name='allego.ChannelRecord.siteCtrTcsX', index=18,
      number=19, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteCtrTcsY', full_name='allego.ChannelRecord.siteCtrTcsY', index=19,
      number=20, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteCtrTcsZ', full_name='allego.ChannelRecord.siteCtrTcsZ', index=20,
      number=21, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorUnits', full_name='allego.ChannelRecord.sensorUnits', index=21,
      number=22, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absIdx', full_name='allego.ChannelRecord.absIdx', index=22,
      number=23, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isAudioRight', full_name='allego.ChannelRecord.isAudioRight', index=23,
      number=24, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sysChanIdx', full_name='allego.ChannelRecord.sysChanIdx', index=24,
      number=25, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteAreaMicron2', full_name='allego.ChannelRecord.siteAreaMicron2', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scsToTcsX', full_name='allego.ChannelRecord.scsToTcsX', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scsToTcsY', full_name='allego.ChannelRecord.scsToTcsY', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scsToTcsZ', full_name='allego.ChannelRecord.scsToTcsZ', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorID', full_name='allego.ChannelRecord.sensorID', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probeID', full_name='allego.ChannelRecord.probeID', index=30,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headstageID', full_name='allego.ChannelRecord.headstageID', index=31,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasetRidx', full_name='allego.ChannelRecord.datasetRidx', index=32,
      number=33, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasetAidx', full_name='allego.ChannelRecord.datasetAidx', index=33,
      number=34, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanName', full_name='allego.ChannelRecord.ntvChanName', index=34,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorUID', full_name='allego.ChannelRecord.sensorUID', index=35,
      number=36, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4131,
  serialized_end=4892,
)


_XYCOORD = _descriptor.Descriptor(
  name='XYCoord',
  full_name='allego.XYCoord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='allego.XYCoord.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='allego.XYCoord.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4894,
  serialized_end=4925,
)


_XYZCOORD = _descriptor.Descriptor(
  name='XYZCoord',
  full_name='allego.XYZCoord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='allego.XYZCoord.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='allego.XYZCoord.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='allego.XYZCoord.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4927,
  serialized_end=4970,
)


_SENSOR_WIREFRAME = _descriptor.Descriptor(
  name='WireFrame',
  full_name='allego.Sensor.WireFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vtx', full_name='allego.Sensor.WireFrame.vtx', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vtxXlim', full_name='allego.Sensor.WireFrame.vtxXlim', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vtxYlim', full_name='allego.Sensor.WireFrame.vtxYlim', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5186,
  serialized_end=5295,
)

_SENSOR = _descriptor.Descriptor(
  name='Sensor',
  full_name='allego.Sensor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='probeId', full_name='allego.Sensor.probeId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headstageId', full_name='allego.Sensor.headstageId', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wireframe', full_name='allego.Sensor.wireframe', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xMin', full_name='allego.Sensor.xMin', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xMax', full_name='allego.Sensor.xMax', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yMin', full_name='allego.Sensor.yMin', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yMax', full_name='allego.Sensor.yMax', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='allego.Sensor.position', index=7,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorUID', full_name='allego.Sensor.sensorUID', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SENSOR_WIREFRAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4973,
  serialized_end=5295,
)


_SENSORPORTSPEC = _descriptor.Descriptor(
  name='SensorPortSpec',
  full_name='allego.SensorPortSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensorA', full_name='allego.SensorPortSpec.sensorA', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorB', full_name='allego.SensorPortSpec.sensorB', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorC', full_name='allego.SensorPortSpec.sensorC', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorD', full_name='allego.SensorPortSpec.sensorD', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorE', full_name='allego.SensorPortSpec.sensorE', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorF', full_name='allego.SensorPortSpec.sensorF', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorG', full_name='allego.SensorPortSpec.sensorG', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorH', full_name='allego.SensorPortSpec.sensorH', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5298,
  serialized_end=5578,
)


_SIGNALGROUPUNITS_UNITSENTRY = _descriptor.Descriptor(
  name='UnitsEntry',
  full_name='allego.SignalGroupUnits.UnitsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.SignalGroupUnits.UnitsEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.SignalGroupUnits.UnitsEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5652,
  serialized_end=5696,
)

_SIGNALGROUPUNITS = _descriptor.Descriptor(
  name='SignalGroupUnits',
  full_name='allego.SignalGroupUnits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='units', full_name='allego.SignalGroupUnits.units', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SIGNALGROUPUNITS_UNITSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5580,
  serialized_end=5696,
)


_SIGNALGROUP = _descriptor.Descriptor(
  name='SignalGroup',
  full_name='allego.SignalGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channels', full_name='allego.SignalGroup.channels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorPortSpec', full_name='allego.SignalGroup.sensorPortSpec', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasetUID', full_name='allego.SignalGroup.datasetUID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.SignalGroup.sampFreq', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceLabel', full_name='allego.SignalGroup.sourceLabel', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neighborMaxRadius', full_name='allego.SignalGroup.neighborMaxRadius', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signalUnits', full_name='allego.SignalGroup.signalUnits', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasDiscrete', full_name='allego.SignalGroup.hasDiscrete', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5699,
  serialized_end=5955,
)


_CREATESIGNALGROUPREQUEST = _descriptor.Descriptor(
  name='CreateSignalGroupRequest',
  full_name='allego.CreateSignalGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataSourceName', full_name='allego.CreateSignalGroupRequest.dataSourceName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSourcePath', full_name='allego.CreateSignalGroupRequest.dataSourcePath', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='allego.CreateSignalGroupRequest.type', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.CreateSignalGroupRequest.streamGroupId', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5958,
  serialized_end=6093,
)


_SUBOPSORT = _descriptor.Descriptor(
  name='SubOpSort',
  full_name='allego.SubOpSort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sort', full_name='allego.SubOpSort.sort', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SUBOPSORT_SORTFIELD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6095,
  serialized_end=6210,
)


_UPDATESIGNALGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateSignalGroupRequest',
  full_name='allego.UpdateSignalGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.UpdateSignalGroupRequest.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation', full_name='allego.UpdateSignalGroupRequest.operation', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='addRemove', full_name='allego.UpdateSignalGroupRequest.addRemove', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortOp', full_name='allego.UpdateSignalGroupRequest.sortOp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.UpdateSignalGroupRequest.ntvChanIdx', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signalType', full_name='allego.UpdateSignalGroupRequest.signalType', index=5,
      number=6, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPDATESIGNALGROUPREQUEST_OPERATION,
    _UPDATESIGNALGROUPREQUEST_SUBOPERATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='subOperation', full_name='allego.UpdateSignalGroupRequest.subOperation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=6213,
  serialized_end=6615,
)


_LICENSESTATUS = _descriptor.Descriptor(
  name='LicenseStatus',
  full_name='allego.LicenseStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6617,
  serialized_end=6632,
)


_SETDSPGROUPREQUEST = _descriptor.Descriptor(
  name='SetDSPGroupRequest',
  full_name='allego.SetDSPGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.SetDSPGroupRequest.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stage', full_name='allego.SetDSPGroupRequest.stage', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dspParams', full_name='allego.SetDSPGroupRequest.dspParams', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6634,
  serialized_end=6751,
)


_DSPPARAMS_FREQSPECBAND = _descriptor.Descriptor(
  name='FreqSpecBand',
  full_name='allego.DSPParams.FreqSpecBand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lowFreq', full_name='allego.DSPParams.FreqSpecBand.lowFreq', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='highFreq', full_name='allego.DSPParams.FreqSpecBand.highFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7063,
  serialized_end=7112,
)

_DSPPARAMS = _descriptor.Descriptor(
  name='DSPParams',
  full_name='allego.DSPParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='allego.DSPParams.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stage', full_name='allego.DSPParams.stage', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='freq', full_name='allego.DSPParams.freq', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='freqSpecBand', full_name='allego.DSPParams.freqSpecBand', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refNtvChanIdx', full_name='allego.DSPParams.refNtvChanIdx', index=4,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notchBandwidth', full_name='allego.DSPParams.notchBandwidth', index=5,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userLabel', full_name='allego.DSPParams.userLabel', index=6,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.DSPParams.port', index=7,
      number=7, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetNtvChanIdx', full_name='allego.DSPParams.targetNtvChanIdx', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isAux', full_name='allego.DSPParams.isAux', index=9,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auxChanIdx', full_name='allego.DSPParams.auxChanIdx', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DSPPARAMS_FREQSPECBAND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='freqSpec', full_name='allego.DSPParams.freqSpec',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=6754,
  serialized_end=7124,
)


_DSPGROUP = _descriptor.Descriptor(
  name='DSPGroup',
  full_name='allego.DSPGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hardware', full_name='allego.DSPGroup.hardware', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='softwareStage1', full_name='allego.DSPGroup.softwareStage1', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='softwareStage2', full_name='allego.DSPGroup.softwareStage2', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7127,
  serialized_end=7260,
)


_SETSENSORREQUEST = _descriptor.Descriptor(
  name='SetSensorRequest',
  full_name='allego.SetSensorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.SetSensorRequest.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.SetSensorRequest.port', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probeId', full_name='allego.SetSensorRequest.probeId', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headstageId', full_name='allego.SetSensorRequest.headstageId', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7262,
  serialized_end=7369,
)


_SENSORPOSITIONTCS = _descriptor.Descriptor(
  name='SensorPositionTcs',
  full_name='allego.SensorPositionTcs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='X', full_name='allego.SensorPositionTcs.X', index=0,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Y', full_name='allego.SensorPositionTcs.Y', index=1,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Z', full_name='allego.SensorPositionTcs.Z', index=2,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='RingAngle', full_name='allego.SensorPositionTcs.RingAngle', index=3,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='AxialAngle', full_name='allego.SensorPositionTcs.AxialAngle', index=4,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ArcAngle', full_name='allego.SensorPositionTcs.ArcAngle', index=5,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7371,
  serialized_end=7480,
)


_SETSENSORPOSITIONTCSREQUEST = _descriptor.Descriptor(
  name='SetSensorPositionTcsRequest',
  full_name='allego.SetSensorPositionTcsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.SetSensorPositionTcsRequest.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.SetSensorPositionTcsRequest.port', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='allego.SetSensorPositionTcsRequest.position', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7482,
  serialized_end=7607,
)


_SITEPOSITIONTCS = _descriptor.Descriptor(
  name='SitePositionTcs',
  full_name='allego.SitePositionTcs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SitePositionTcs.ntvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='X', full_name='allego.SitePositionTcs.X', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Y', full_name='allego.SitePositionTcs.Y', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Z', full_name='allego.SitePositionTcs.Z', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7609,
  serialized_end=7679,
)


_SETSITEPOSITIONSTCSREQUEST = _descriptor.Descriptor(
  name='SetSitePositionsTcsRequest',
  full_name='allego.SetSitePositionsTcsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.SetSitePositionsTcsRequest.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='allego.SetSitePositionsTcsRequest.port', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sitePositions', full_name='allego.SetSitePositionsTcsRequest.sitePositions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7681,
  serialized_end=7808,
)


_FEATURESTARTSTOPREQUEST = _descriptor.Descriptor(
  name='FeatureStartStopRequest',
  full_name='allego.FeatureStartStopRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodeId', full_name='allego.FeatureStartStopRequest.nodeId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featureLicense', full_name='allego.FeatureStartStopRequest.featureLicense', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7810,
  serialized_end=7899,
)


_PRIVACYREPLY = _descriptor.Descriptor(
  name='PrivacyReply',
  full_name='allego.PrivacyReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isPrivate', full_name='allego.PrivacyReply.isPrivate', index=0,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7901,
  serialized_end=7934,
)


_SETPRIVACYREQUEST = _descriptor.Descriptor(
  name='SetPrivacyRequest',
  full_name='allego.SetPrivacyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isPrivate', full_name='allego.SetPrivacyRequest.isPrivate', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7936,
  serialized_end=7974,
)


_DENSEMATRIX = _descriptor.Descriptor(
  name='DenseMatrix',
  full_name='allego.DenseMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rows', full_name='allego.DenseMatrix.rows', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cols', full_name='allego.DenseMatrix.cols', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='allego.DenseMatrix.data', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7976,
  serialized_end=8031,
)


_KPIMETRICID = _descriptor.Descriptor(
  name='KpiMetricID',
  full_name='allego.KpiMetricID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.KpiMetricID.mode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.KpiMetricID.name', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8033,
  serialized_end=8122,
)


_TIMERANGE = _descriptor.Descriptor(
  name='TimeRange',
  full_name='allego.TimeRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeRangeSec', full_name='allego.TimeRange.timeRangeSec', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='allego.TimeRange.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fs', full_name='allego.TimeRange.fs', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wallTimeStart', full_name='allego.TimeRange.wallTimeStart', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8124,
  serialized_end=8211,
)


_BUNDLEREQ = _descriptor.Descriptor(
  name='BundleReq',
  full_name='allego.BundleReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvIdxs', full_name='allego.BundleReq.ntvIdxs', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tR', full_name='allego.BundleReq.tR', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='allego.BundleReq.metrics', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isTail', full_name='allego.BundleReq.isTail', index=3,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8213,
  serialized_end=8326,
)


_KPIMETRICSREQ = _descriptor.Descriptor(
  name='KpiMetricsReq',
  full_name='allego.KpiMetricsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.KpiMetricsReq.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stype', full_name='allego.KpiMetricsReq.stype', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg', full_name='allego.KpiMetricsReq.arg', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bundleName', full_name='allego.KpiMetricsReq.bundleName', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8329,
  serialized_end=8477,
)


_KPIMETRICSDATA_METRICSTATS = _descriptor.Descriptor(
  name='MetricStats',
  full_name='allego.KpiMetricsData.MetricStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean', full_name='allego.KpiMetricsData.MetricStats.mean', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sD', full_name='allego.KpiMetricsData.MetricStats.sD', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='allego.KpiMetricsData.MetricStats.max', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min', full_name='allego.KpiMetricsData.MetricStats.min', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8802,
  serialized_end=8867,
)

_KPIMETRICSDATA = _descriptor.Descriptor(
  name='KpiMetricsData',
  full_name='allego.KpiMetricsData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numPackets', full_name='allego.KpiMetricsData.numPackets', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSigs', full_name='allego.KpiMetricsData.numSigs', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numMetrics', full_name='allego.KpiMetricsData.numMetrics', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metric', full_name='allego.KpiMetricsData.metric', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pktIdxs', full_name='allego.KpiMetricsData.pktIdxs', index=4,
      number=5, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='allego.KpiMetricsData.val', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statsPkts', full_name='allego.KpiMetricsData.statsPkts', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='allego.KpiMetricsData.stats', index=7,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packetDurSec', full_name='allego.KpiMetricsData.packetDurSec', index=8,
      number=9, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tR', full_name='allego.KpiMetricsData.tR', index=9,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_KPIMETRICSDATA_METRICSTATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8480,
  serialized_end=8867,
)


_KPIBUNDLEPACKETMETRICS = _descriptor.Descriptor(
  name='KpiBundlePacketMetrics',
  full_name='allego.KpiBundlePacketMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvIdxs', full_name='allego.KpiBundlePacketMetrics.ntvIdxs', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sigType', full_name='allego.KpiBundlePacketMetrics.sigType', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='allego.KpiBundlePacketMetrics.metrics', index=2,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8869,
  serialized_end=8988,
)


_KPIMETRICS = _descriptor.Descriptor(
  name='KpiMetrics',
  full_name='allego.KpiMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.KpiMetrics.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bundle', full_name='allego.KpiMetrics.bundle', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8990,
  serialized_end=9073,
)


_KPICONTROLREQUEST = _descriptor.Descriptor(
  name='KpiControlRequest',
  full_name='allego.KpiControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.KpiControlRequest.streamGroupId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stype', full_name='allego.KpiControlRequest.stype', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isAllBundles', full_name='allego.KpiControlRequest.isAllBundles', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.KpiControlRequest.name', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9076,
  serialized_end=9212,
)


_SETKPIUPDATEPERIODREQUEST = _descriptor.Descriptor(
  name='SetKpiUpdatePeriodRequest',
  full_name='allego.SetKpiUpdatePeriodRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stype', full_name='allego.SetKpiUpdatePeriodRequest.stype', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.SetKpiUpdatePeriodRequest.streamGroupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updatePeriod', full_name='allego.SetKpiUpdatePeriodRequest.updatePeriod', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.SetKpiUpdatePeriodRequest.name', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9215,
  serialized_end=9359,
)


_SETKPITHRESHOLDREQUEST = _descriptor.Descriptor(
  name='SetKpiThresholdRequest',
  full_name='allego.SetKpiThresholdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stype', full_name='allego.SetKpiThresholdRequest.stype', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.SetKpiThresholdRequest.streamGroupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isUpdatePos', full_name='allego.SetKpiThresholdRequest.isUpdatePos', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isClearPos', full_name='allego.SetKpiThresholdRequest.isClearPos', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSdPos', full_name='allego.SetKpiThresholdRequest.isSdPos', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levelPos', full_name='allego.SetKpiThresholdRequest.levelPos', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isUpdateNeg', full_name='allego.SetKpiThresholdRequest.isUpdateNeg', index=6,
      number=7, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isClearNeg', full_name='allego.SetKpiThresholdRequest.isClearNeg', index=7,
      number=8, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSdNeg', full_name='allego.SetKpiThresholdRequest.isSdNeg', index=8,
      number=9, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='levelNeg', full_name='allego.SetKpiThresholdRequest.levelNeg', index=9,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SetKpiThresholdRequest.ntvChanIdx', index=10,
      number=11, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thrName', full_name='allego.SetKpiThresholdRequest.thrName', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.SetKpiThresholdRequest.name', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9362,
  serialized_end=9700,
)


_SETKPIEVENTDETECTREQUEST = _descriptor.Descriptor(
  name='SetKpiEventDetectRequest',
  full_name='allego.SetKpiEventDetectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stype', full_name='allego.SetKpiEventDetectRequest.stype', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.SetKpiEventDetectRequest.streamGroupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isEventDetect', full_name='allego.SetKpiEventDetectRequest.isEventDetect', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SetKpiEventDetectRequest.ntvChanIdx', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thrName', full_name='allego.SetKpiEventDetectRequest.thrName', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isPosThr', full_name='allego.SetKpiEventDetectRequest.isPosThr', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isNegThr', full_name='allego.SetKpiEventDetectRequest.isNegThr', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9703,
  serialized_end=9913,
)


_SETKPIEVENTSHADOWREQUEST = _descriptor.Descriptor(
  name='SetKpiEventShadowRequest',
  full_name='allego.SetKpiEventShadowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stype', full_name='allego.SetKpiEventShadowRequest.stype', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.SetKpiEventShadowRequest.streamGroupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow', full_name='allego.SetKpiEventShadowRequest.shadow', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SetKpiEventShadowRequest.ntvChanIdx', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wdwName', full_name='allego.SetKpiEventShadowRequest.wdwName', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9916,
  serialized_end=10081,
)


_SETKPIEVENTWINDOWREQUEST = _descriptor.Descriptor(
  name='SetKpiEventWindowRequest',
  full_name='allego.SetKpiEventWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stype', full_name='allego.SetKpiEventWindowRequest.stype', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.SetKpiEventWindowRequest.streamGroupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preThr', full_name='allego.SetKpiEventWindowRequest.preThr', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postThr', full_name='allego.SetKpiEventWindowRequest.postThr', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SetKpiEventWindowRequest.ntvChanIdx', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wdwName', full_name='allego.SetKpiEventWindowRequest.wdwName', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10084,
  serialized_end=10266,
)


_GETKPISTATUSREQUEST = _descriptor.Descriptor(
  name='GetKpiStatusRequest',
  full_name='allego.GetKpiStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.GetKpiStatusRequest.streamGroupId', index=0,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.GetKpiStatusRequest.name', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10268,
  serialized_end=10349,
)


_KPISTATUSREPLY = _descriptor.Descriptor(
  name='KpiStatusReply',
  full_name='allego.KpiStatusReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.KpiStatusReply.streamGroupId', index=0,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.KpiStatusReply.timeRange', index=1,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.KpiStatusReply.timestampRange', index=2,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numPacketsMemory', full_name='allego.KpiStatusReply.numPacketsMemory', index=3,
      number=5, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packetDur', full_name='allego.KpiStatusReply.packetDur', index=4,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updatePeriod', full_name='allego.KpiStatusReply.updatePeriod', index=5,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistence', full_name='allego.KpiStatusReply.persistence', index=6,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='beta', full_name='allego.KpiStatusReply.beta', index=7,
      number=9, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isTrackingSignalCache', full_name='allego.KpiStatusReply.isTrackingSignalCache', index=8,
      number=11, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numPackets', full_name='allego.KpiStatusReply.numPackets', index=9,
      number=12, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memoryBytes', full_name='allego.KpiStatusReply.memoryBytes', index=10,
      number=13, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fs', full_name='allego.KpiStatusReply.fs', index=11,
      number=14, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wallTimeStart', full_name='allego.KpiStatusReply.wallTimeStart', index=12,
      number=15, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10352,
  serialized_end=10643,
)


_SIGKPIPARAMRECORD = _descriptor.Descriptor(
  name='SigKpiParamRecord',
  full_name='allego.SigKpiParamRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isEventDetect', full_name='allego.SigKpiParamRecord.isEventDetect', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SigKpiParamRecord.ntvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventThr0', full_name='allego.SigKpiParamRecord.eventThr0', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventThr1', full_name='allego.SigKpiParamRecord.eventThr1', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventThrSd0', full_name='allego.SigKpiParamRecord.eventThrSd0', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventThrSd1', full_name='allego.SigKpiParamRecord.eventThrSd1', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preThrPts', full_name='allego.SigKpiParamRecord.preThrPts', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postThrPts', full_name='allego.SigKpiParamRecord.postThrPts', index=7,
      number=8, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evtDurPts', full_name='allego.SigKpiParamRecord.evtDurPts', index=8,
      number=9, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadowPts', full_name='allego.SigKpiParamRecord.shadowPts', index=9,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preThr', full_name='allego.SigKpiParamRecord.preThr', index=10,
      number=11, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postThr', full_name='allego.SigKpiParamRecord.postThr', index=11,
      number=12, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evtDur', full_name='allego.SigKpiParamRecord.evtDur', index=12,
      number=13, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow', full_name='allego.SigKpiParamRecord.shadow', index=13,
      number=14, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSetThr0', full_name='allego.SigKpiParamRecord.isSetThr0', index=14,
      number=15, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSetThr1', full_name='allego.SigKpiParamRecord.isSetThr1', index=15,
      number=16, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSDThr0', full_name='allego.SigKpiParamRecord.isSDThr0', index=16,
      number=17, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSDThr1', full_name='allego.SigKpiParamRecord.isSDThr1', index=17,
      number=18, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10646,
  serialized_end=11004,
)


_ANNOTATEBUNDLE = _descriptor.Descriptor(
  name='AnnotateBundle',
  full_name='allego.AnnotateBundle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.AnnotateBundle.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='allego.AnnotateBundle.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notes', full_name='allego.AnnotateBundle.notes', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='allego.AnnotateBundle.tags', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11006,
  serialized_end=11080,
)


_PROJECTMETADATA = _descriptor.Descriptor(
  name='ProjectMetadata',
  full_name='allego.ProjectMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='projectUID', full_name='allego.ProjectMetadata.projectUID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caseUID', full_name='allego.ProjectMetadata.caseUID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trialUID', full_name='allego.ProjectMetadata.trialUID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotateUID', full_name='allego.ProjectMetadata.annotateUID', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11082,
  serialized_end=11175,
)


_SENSOREXTENDEDMETADATA = _descriptor.Descriptor(
  name='SensorExtendedMetadata',
  full_name='allego.SensorExtendedMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensorInstanceUID', full_name='allego.SensorExtendedMetadata.sensorInstanceUID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11177,
  serialized_end=11228,
)


_GONUMMATRIXLIST = _descriptor.Descriptor(
  name='GonumMatrixList',
  full_name='allego.GonumMatrixList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mdataBytes', full_name='allego.GonumMatrixList.mdataBytes', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11230,
  serialized_end=11267,
)


_RADIXMATRIXLIST = _descriptor.Descriptor(
  name='RadixMatrixList',
  full_name='allego.RadixMatrixList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matrix', full_name='allego.RadixMatrixList.matrix', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11269,
  serialized_end=11323,
)


_RADIXMATRIX = _descriptor.Descriptor(
  name='RadixMatrix',
  full_name='allego.RadixMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='allego.RadixMatrix.data', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='allego.RadixMatrix.shape', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11325,
  serialized_end=11367,
)


_RADIXSIGNALSLIST = _descriptor.Descriptor(
  name='RadixSignalsList',
  full_name='allego.RadixSignalsList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matrix', full_name='allego.RadixSignalsList.matrix', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11369,
  serialized_end=11425,
)


_RADIXSIGNALS = _descriptor.Descriptor(
  name='RadixSignals',
  full_name='allego.RadixSignals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.RadixSignals.sampFreq', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pri', full_name='allego.RadixSignals.pri', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aux', full_name='allego.RadixSignals.aux', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='din', full_name='allego.RadixSignals.din', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dout', full_name='allego.RadixSignals.dout', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11428,
  serialized_end=11597,
)


_VECTORSTRING = _descriptor.Descriptor(
  name='VectorString',
  full_name='allego.VectorString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='allego.VectorString.x', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11599,
  serialized_end=11624,
)


_VECTORFLOAT64 = _descriptor.Descriptor(
  name='VectorFloat64',
  full_name='allego.VectorFloat64',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='allego.VectorFloat64.x', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11626,
  serialized_end=11652,
)


_VECTORSLICEFLOAT64 = _descriptor.Descriptor(
  name='VectorSliceFloat64',
  full_name='allego.VectorSliceFloat64',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vec', full_name='allego.VectorSliceFloat64.vec', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='allego.VectorSliceFloat64.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11654,
  serialized_end=11725,
)


_LOGSYSKPISTATUSREPLY = _descriptor.Descriptor(
  name='LogsysKpiStatusReply',
  full_name='allego.LogsysKpiStatusReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='portA', full_name='allego.LogsysKpiStatusReply.portA', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portB', full_name='allego.LogsysKpiStatusReply.portB', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portC', full_name='allego.LogsysKpiStatusReply.portC', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portD', full_name='allego.LogsysKpiStatusReply.portD', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portE', full_name='allego.LogsysKpiStatusReply.portE', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portF', full_name='allego.LogsysKpiStatusReply.portF', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portG', full_name='allego.LogsysKpiStatusReply.portG', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portH', full_name='allego.LogsysKpiStatusReply.portH', index=7,
      number=8, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aux0', full_name='allego.LogsysKpiStatusReply.aux0', index=8,
      number=9, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aux1', full_name='allego.LogsysKpiStatusReply.aux1', index=9,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11728,
  serialized_end=12078,
)


_KPICACHE = _descriptor.Descriptor(
  name='KpiCache',
  full_name='allego.KpiCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.KpiCache.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.KpiCache.sampFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistDur', full_name='allego.KpiCache.persistDur', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minNumPackets', full_name='allego.KpiCache.minNumPackets', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeBytes', full_name='allego.KpiCache.sizeBytes', index=4,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numPackets', full_name='allego.KpiCache.numPackets', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tRange', full_name='allego.KpiCache.tRange', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tsRange', full_name='allego.KpiCache.tsRange', index=7,
      number=8, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meanPacketDur', full_name='allego.KpiCache.meanPacketDur', index=8,
      number=9, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meanCalcPacketDur', full_name='allego.KpiCache.meanCalcPacketDur', index=9,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packetDur', full_name='allego.KpiCache.packetDur', index=10,
      number=11, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalPacketsProcessed', full_name='allego.KpiCache.totalPacketsProcessed', index=11,
      number=12, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signalType', full_name='allego.KpiCache.signalType', index=12,
      number=13, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numPriSigs', full_name='allego.KpiCache.numPriSigs', index=13,
      number=14, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numAuxSigs', full_name='allego.KpiCache.numAuxSigs', index=14,
      number=15, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numDinSigs', full_name='allego.KpiCache.numDinSigs', index=15,
      number=16, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numDoutSigs', full_name='allego.KpiCache.numDoutSigs', index=16,
      number=17, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updatePeriod', full_name='allego.KpiCache.updatePeriod', index=17,
      number=18, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12081,
  serialized_end=12461,
)


_LOGSYSKPITAILREPLY = _descriptor.Descriptor(
  name='LogsysKpiTailReply',
  full_name='allego.LogsysKpiTailReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='portA', full_name='allego.LogsysKpiTailReply.portA', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portB', full_name='allego.LogsysKpiTailReply.portB', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portC', full_name='allego.LogsysKpiTailReply.portC', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portD', full_name='allego.LogsysKpiTailReply.portD', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portE', full_name='allego.LogsysKpiTailReply.portE', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portF', full_name='allego.LogsysKpiTailReply.portF', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portG', full_name='allego.LogsysKpiTailReply.portG', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='portH', full_name='allego.LogsysKpiTailReply.portH', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aux0', full_name='allego.LogsysKpiTailReply.aux0', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aux1', full_name='allego.LogsysKpiTailReply.aux1', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12464,
  serialized_end=12842,
)


_KPIPORTINFO = _descriptor.Descriptor(
  name='KpiPortInfo',
  full_name='allego.KpiPortInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kpiTail', full_name='allego.KpiPortInfo.kpiTail', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12844,
  serialized_end=12895,
)


_KPITAILROWS = _descriptor.Descriptor(
  name='KpiTailRows',
  full_name='allego.KpiTailRows',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wallTime', full_name='allego.KpiTailRows.wallTime', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.KpiTailRows.timeRange', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localSigType', full_name='allego.KpiTailRows.localSigType', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.KpiTailRows.ntvChanIdx', index=3,
      number=4, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dur', full_name='allego.KpiTailRows.dur', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stdDev', full_name='allego.KpiTailRows.stdDev', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cStdDev', full_name='allego.KpiTailRows.cStdDev', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absEvtAmp', full_name='allego.KpiTailRows.absEvtAmp', index=7,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cabsEvtAmp', full_name='allego.KpiTailRows.cabsEvtAmp', index=8,
      number=9, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SNR', full_name='allego.KpiTailRows.SNR', index=9,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cSNR', full_name='allego.KpiTailRows.cSNR', index=10,
      number=11, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numEvts', full_name='allego.KpiTailRows.numEvts', index=11,
      number=12, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cnumEvts', full_name='allego.KpiTailRows.cnumEvts', index=12,
      number=13, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evtRate', full_name='allego.KpiTailRows.evtRate', index=13,
      number=14, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cEvtRate', full_name='allego.KpiTailRows.cEvtRate', index=14,
      number=15, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='allego.KpiTailRows.max', index=15,
      number=16, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmax', full_name='allego.KpiTailRows.cmax', index=16,
      number=17, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min', full_name='allego.KpiTailRows.min', index=17,
      number=18, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmin', full_name='allego.KpiTailRows.cmin', index=18,
      number=19, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meanPosPkAmp', full_name='allego.KpiTailRows.meanPosPkAmp', index=19,
      number=20, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meanNegPkAmp', full_name='allego.KpiTailRows.meanNegPkAmp', index=20,
      number=21, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12898,
  serialized_end=13270,
)


_WAREHOUSEHEALTHCHECKSPEC = _descriptor.Descriptor(
  name='WarehouseHealthcheckSpec',
  full_name='allego.WarehouseHealthcheckSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errMsg', full_name='allego.WarehouseHealthcheckSpec.errMsg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13272,
  serialized_end=13314,
)


_OUTFITTERGETDEVICEREQUEST = _descriptor.Descriptor(
  name='OutfitterGetDeviceRequest',
  full_name='allego.OutfitterGetDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.OutfitterGetDeviceRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13316,
  serialized_end=13356,
)


_SENSORCOMPREQUEST = _descriptor.Descriptor(
  name='SensorCompRequest',
  full_name='allego.SensorCompRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='probe', full_name='allego.SensorCompRequest.probe', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headstage', full_name='allego.SensorCompRequest.headstage', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isIncludeModel', full_name='allego.SensorCompRequest.isIncludeModel', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isIncludeMetadata', full_name='allego.SensorCompRequest.isIncludeMetadata', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iD', full_name='allego.SensorCompRequest.iD', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13359,
  serialized_end=13517,
)


_REGISTERSENSORCOMPREQUEST = _descriptor.Descriptor(
  name='RegisterSensorCompRequest',
  full_name='allego.RegisterSensorCompRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='probe', full_name='allego.RegisterSensorCompRequest.probe', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headstage', full_name='allego.RegisterSensorCompRequest.headstage', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profileID', full_name='allego.RegisterSensorCompRequest.profileID', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13519,
  serialized_end=13641,
)


_SAVESENSORCOMPINSTANCEREQUEST = _descriptor.Descriptor(
  name='SaveSensorCompInstanceRequest',
  full_name='allego.SaveSensorCompInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='probe', full_name='allego.SaveSensorCompInstanceRequest.probe', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headstage', full_name='allego.SaveSensorCompInstanceRequest.headstage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isIncludeMetadata', full_name='allego.SaveSensorCompInstanceRequest.isIncludeMetadata', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iD', full_name='allego.SaveSensorCompInstanceRequest.iD', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13644,
  serialized_end=13790,
)


_PROBEDESC = _descriptor.Descriptor(
  name='ProbeDesc',
  full_name='allego.ProbeDesc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.ProbeDesc.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uID', full_name='allego.ProbeDesc.uID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13792,
  serialized_end=13830,
)


_HEADSTAGEDESC = _descriptor.Descriptor(
  name='HeadstageDesc',
  full_name='allego.HeadstageDesc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='allego.HeadstageDesc.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uID', full_name='allego.HeadstageDesc.uID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13832,
  serialized_end=13874,
)


_GETSENSORCOMPREPLY = _descriptor.Descriptor(
  name='GetSensorCompReply',
  full_name='allego.GetSensorCompReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='probe', full_name='allego.GetSensorCompReply.probe', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headstage', full_name='allego.GetSensorCompReply.headstage', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13876,
  serialized_end=13972,
)


_PROBESPEC = _descriptor.Descriptor(
  name='ProbeSpec',
  full_name='allego.ProbeSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='allego.ProbeSpec.desc', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='allego.ProbeSpec.model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metaData', full_name='allego.ProbeSpec.metaData', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13974,
  serialized_end=14094,
)


_HEADSTAGESPEC = _descriptor.Descriptor(
  name='HeadstageSpec',
  full_name='allego.HeadstageSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='allego.HeadstageSpec.desc', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='allego.HeadstageSpec.model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metaData', full_name='allego.HeadstageSpec.metaData', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14097,
  serialized_end=14233,
)


_PROBEMODEL_PROBESITEDESC = _descriptor.Descriptor(
  name='ProbeSiteDesc',
  full_name='allego.ProbeModel.ProbeSiteDesc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='area', full_name='allego.ProbeModel.ProbeSiteDesc.area', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='centerX', full_name='allego.ProbeModel.ProbeSiteDesc.centerX', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='centerY', full_name='allego.ProbeModel.ProbeSiteDesc.centerY', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='centerZ', full_name='allego.ProbeModel.ProbeSiteDesc.centerZ', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limitXMax', full_name='allego.ProbeModel.ProbeSiteDesc.limitXMax', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limitXMin', full_name='allego.ProbeModel.ProbeSiteDesc.limitXMin', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limitYMax', full_name='allego.ProbeModel.ProbeSiteDesc.limitYMax', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limitYMin', full_name='allego.ProbeModel.ProbeSiteDesc.limitYMin', index=7,
      number=8, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limitZMax', full_name='allego.ProbeModel.ProbeSiteDesc.limitZMax', index=8,
      number=9, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limitZMin', full_name='allego.ProbeModel.ProbeSiteDesc.limitZMin', index=9,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num', full_name='allego.ProbeModel.ProbeSiteDesc.num', index=10,
      number=11, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape', full_name='allego.ProbeModel.ProbeSiteDesc.shape', index=11,
      number=12, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14473,
  serialized_end=14695,
)

_PROBEMODEL_PROBEWIREFRAME = _descriptor.Descriptor(
  name='ProbeWireFrame',
  full_name='allego.ProbeModel.ProbeWireFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertex', full_name='allego.ProbeModel.ProbeWireFrame.vertex', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limitX', full_name='allego.ProbeModel.ProbeWireFrame.limitX', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limitY', full_name='allego.ProbeModel.ProbeWireFrame.limitY', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14697,
  serialized_end=14791,
)

_PROBEMODEL_PROBEPTXY = _descriptor.Descriptor(
  name='ProbePtXY',
  full_name='allego.ProbeModel.ProbePtXY',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='allego.ProbeModel.ProbePtXY.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='allego.ProbeModel.ProbePtXY.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14793,
  serialized_end=14826,
)

_PROBEMODEL = _descriptor.Descriptor(
  name='ProbeModel',
  full_name='allego.ProbeModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iD', full_name='allego.ProbeModel.iD', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='site', full_name='allego.ProbeModel.site', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wireframe', full_name='allego.ProbeModel.wireframe', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteOverallMin', full_name='allego.ProbeModel.siteOverallMin', index=3,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteOverallMax', full_name='allego.ProbeModel.siteOverallMax', index=4,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PROBEMODEL_PROBESITEDESC, _PROBEMODEL_PROBEWIREFRAME, _PROBEMODEL_PROBEPTXY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14236,
  serialized_end=14826,
)


_PROBEMETADATA = _descriptor.Descriptor(
  name='ProbeMetaData',
  full_name='allego.ProbeMetaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='probeName', full_name='allego.ProbeMetaData.probeName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSites', full_name='allego.ProbeMetaData.numSites', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='catalogTags', full_name='allego.ProbeMetaData.catalogTags', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instanceTags', full_name='allego.ProbeMetaData.instanceTags', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14828,
  serialized_end=14923,
)


_HEADSTAGEMODEL_HEADSTAGEROW = _descriptor.Descriptor(
  name='HeadstageRow',
  full_name='allego.HeadstageModel.HeadstageRow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.HeadstageModel.HeadstageRow.ntvChanIdx', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteNum', full_name='allego.HeadstageModel.HeadstageRow.siteNum', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15007,
  serialized_end=15058,
)

_HEADSTAGEMODEL = _descriptor.Descriptor(
  name='HeadstageModel',
  full_name='allego.HeadstageModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iD', full_name='allego.HeadstageModel.iD', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows', full_name='allego.HeadstageModel.rows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HEADSTAGEMODEL_HEADSTAGEROW, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14926,
  serialized_end=15058,
)


_HEADSTAGEMETADATA = _descriptor.Descriptor(
  name='HeadstageMetaData',
  full_name='allego.HeadstageMetaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15060,
  serialized_end=15079,
)


_USERPROFILE = _descriptor.Descriptor(
  name='UserProfile',
  full_name='allego.UserProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='profileID', full_name='allego.UserProfile.profileID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='licenseCode', full_name='allego.UserProfile.licenseCode', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15081,
  serialized_end=15134,
)


_GETCURRENTPROFILEREPLY = _descriptor.Descriptor(
  name='GetCurrentProfileReply',
  full_name='allego.GetCurrentProfileReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userProfile', full_name='allego.GetCurrentProfileReply.userProfile', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15136,
  serialized_end=15202,
)


_GETALLPROFILESREPLY = _descriptor.Descriptor(
  name='GetAllProfilesReply',
  full_name='allego.GetAllProfilesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userProfiles', full_name='allego.GetAllProfilesReply.userProfiles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15204,
  serialized_end=15268,
)


_SETCURRENTPROFILEREQUEST = _descriptor.Descriptor(
  name='SetCurrentProfileRequest',
  full_name='allego.SetCurrentProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='profileID', full_name='allego.SetCurrentProfileRequest.profileID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15270,
  serialized_end=15315,
)


_MANAGENODEORGPAYLOAD = _descriptor.Descriptor(
  name='ManageNodeOrgPayload',
  full_name='allego.ManageNodeOrgPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgID', full_name='allego.ManageNodeOrgPayload.orgID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orgName', full_name='allego.ManageNodeOrgPayload.orgName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orgShortName', full_name='allego.ManageNodeOrgPayload.orgShortName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='city', full_name='allego.ManageNodeOrgPayload.city', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country', full_name='allego.ManageNodeOrgPayload.country', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='allego.ManageNodeOrgPayload.state', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='allego.ManageNodeOrgPayload.tags', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15318,
  serialized_end=15454,
)


_MANAGENODEORGREQUEST = _descriptor.Descriptor(
  name='ManageNodeOrgRequest',
  full_name='allego.ManageNodeOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='allego.ManageNodeOrgRequest.cmd', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='allego.ManageNodeOrgRequest.payload', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15456,
  serialized_end=15561,
)


_MANAGENODEORGREPLY = _descriptor.Descriptor(
  name='ManageNodeOrgReply',
  full_name='allego.ManageNodeOrgReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='allego.ManageNodeOrgReply.payload', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errMsg', full_name='allego.ManageNodeOrgReply.errMsg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15563,
  serialized_end=15646,
)


_MANAGENODELABPAYLOAD = _descriptor.Descriptor(
  name='ManageNodeLabPayload',
  full_name='allego.ManageNodeLabPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='labID', full_name='allego.ManageNodeLabPayload.labID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labDesc', full_name='allego.ManageNodeLabPayload.labDesc', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dept', full_name='allego.ManageNodeLabPayload.dept', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='organization', full_name='allego.ManageNodeLabPayload.organization', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adminID', full_name='allego.ManageNodeLabPayload.adminID', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labHeadID', full_name='allego.ManageNodeLabPayload.labHeadID', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labManagerID', full_name='allego.ManageNodeLabPayload.labManagerID', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='allego.ManageNodeLabPayload.tags', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15649,
  serialized_end=15811,
)


_MANAGENODELABREQUEST = _descriptor.Descriptor(
  name='ManageNodeLabRequest',
  full_name='allego.ManageNodeLabRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='allego.ManageNodeLabRequest.cmd', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='allego.ManageNodeLabRequest.payload', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15813,
  serialized_end=15918,
)


_MANAGENODELABREPLY = _descriptor.Descriptor(
  name='ManageNodeLabReply',
  full_name='allego.ManageNodeLabReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='allego.ManageNodeLabReply.payload', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errMsg', full_name='allego.ManageNodeLabReply.errMsg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15920,
  serialized_end=16003,
)


_MANAGENODEUSERPAYLOAD = _descriptor.Descriptor(
  name='ManageNodeUserPayload',
  full_name='allego.ManageNodeUserPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='allego.ManageNodeUserPayload.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Name', full_name='allego.ManageNodeUserPayload.Name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='allego.ManageNodeUserPayload.password', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='role', full_name='allego.ManageNodeUserPayload.role', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='allego.ManageNodeUserPayload.email', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labName', full_name='allego.ManageNodeUserPayload.labName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='allego.ManageNodeUserPayload.tags', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16006,
  serialized_end=16159,
)


_MANAGENODEUSERREQUEST = _descriptor.Descriptor(
  name='ManageNodeUserRequest',
  full_name='allego.ManageNodeUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='allego.ManageNodeUserRequest.cmd', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='allego.ManageNodeUserRequest.payload', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16161,
  serialized_end=16268,
)


_MANAGENODEUSERREPLY = _descriptor.Descriptor(
  name='ManageNodeUserReply',
  full_name='allego.ManageNodeUserReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='allego.ManageNodeUserReply.payload', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errMsg', full_name='allego.ManageNodeUserReply.errMsg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16270,
  serialized_end=16355,
)


_CATALOGPROBEPAYLOAD = _descriptor.Descriptor(
  name='CatalogProbePayload',
  full_name='allego.CatalogProbePayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec', full_name='allego.CatalogProbePayload.spec', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16357,
  serialized_end=16411,
)


_PROBENODEREQUEST = _descriptor.Descriptor(
  name='ProbeNodeRequest',
  full_name='allego.ProbeNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='allego.ProbeNodeRequest.cmd', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='allego.ProbeNodeRequest.payload', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16413,
  serialized_end=16506,
)


_PROBENODEREPLY = _descriptor.Descriptor(
  name='ProbeNodeReply',
  full_name='allego.ProbeNodeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='allego.ProbeNodeReply.payload', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16508,
  serialized_end=16563,
)


_PROBEPAYLOAD = _descriptor.Descriptor(
  name='ProbePayload',
  full_name='allego.ProbePayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec', full_name='allego.ProbePayload.spec', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16565,
  serialized_end=16612,
)


_EDGEPAYLOAD_GENERICNODE = _descriptor.Descriptor(
  name='GenericNode',
  full_name='allego.EdgePayload.GenericNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='allego.EdgePayload.GenericNode.label', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='idPropKey', full_name='allego.EdgePayload.GenericNode.idPropKey', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='idPropVal', full_name='allego.EdgePayload.GenericNode.idPropVal', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16818,
  serialized_end=16908,
)

_EDGEPAYLOAD = _descriptor.Descriptor(
  name='EdgePayload',
  full_name='allego.EdgePayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='allego.EdgePayload.source', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='allego.EdgePayload.target', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edgeLabel', full_name='allego.EdgePayload.edgeLabel', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='allego.EdgePayload.direction', index=3,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_EDGEPAYLOAD_GENERICNODE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16615,
  serialized_end=16908,
)


_WORLDEDGEREQUEST = _descriptor.Descriptor(
  name='WorldEdgeRequest',
  full_name='allego.WorldEdgeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='allego.WorldEdgeRequest.payload', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16910,
  serialized_end=16966,
)


_WORLDEDGEREPLY = _descriptor.Descriptor(
  name='WorldEdgeReply',
  full_name='allego.WorldEdgeReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16968,
  serialized_end=16984,
)


_QUERYWORLDREQUEST = _descriptor.Descriptor(
  name='QueryWorldRequest',
  full_name='allego.QueryWorldRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='allego.QueryWorldRequest.cmd', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='allego.QueryWorldRequest.args', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16986,
  serialized_end=17055,
)


_QUERYWORLDREC = _descriptor.Descriptor(
  name='QueryWorldRec',
  full_name='allego.QueryWorldRec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='org', full_name='allego.QueryWorldRec.org', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lab', full_name='allego.QueryWorldRec.lab', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='allego.QueryWorldRec.user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='catProbe', full_name='allego.QueryWorldRec.catProbe', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probe', full_name='allego.QueryWorldRec.probe', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17058,
  serialized_end=17288,
)


_QUERYWORLDREPLY = _descriptor.Descriptor(
  name='QueryWorldReply',
  full_name='allego.QueryWorldReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='allego.QueryWorldReply.payload', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17290,
  serialized_end=17347,
)


_HIGHLOWPASSTRANSFORMPARAMS = _descriptor.Descriptor(
  name='HighLowPassTransformParams',
  full_name='allego.HighLowPassTransformParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frequency', full_name='allego.HighLowPassTransformParams.frequency', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17349,
  serialized_end=17396,
)


_BANDTRANSFORMPARAMS = _descriptor.Descriptor(
  name='BandTransformParams',
  full_name='allego.BandTransformParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lowFrequency', full_name='allego.BandTransformParams.lowFrequency', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='highFrequency', full_name='allego.BandTransformParams.highFrequency', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17398,
  serialized_end=17464,
)


_NOTCHTRANSFORMPARAMS = _descriptor.Descriptor(
  name='NotchTransformParams',
  full_name='allego.NotchTransformParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='notchFrequency', full_name='allego.NotchTransformParams.notchFrequency', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notchBandwidth', full_name='allego.NotchTransformParams.notchBandwidth', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17466,
  serialized_end=17536,
)


_CARTRANSFORMPARAMS = _descriptor.Descriptor(
  name='CARTransformParams',
  full_name='allego.CARTransformParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17538,
  serialized_end=17558,
)


_VIRTUALREFTRANSFORMPARAMS = _descriptor.Descriptor(
  name='VirtualRefTransformParams',
  full_name='allego.VirtualRefTransformParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='refNtvChanIdx', full_name='allego.VirtualRefTransformParams.refNtvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17560,
  serialized_end=17610,
)


_PAIREDREFTRANSFORMPARAMS = _descriptor.Descriptor(
  name='PairedRefTransformParams',
  full_name='allego.PairedRefTransformParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='refNtvChanIdx', full_name='allego.PairedRefTransformParams.refNtvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targetNtvChanIdx', full_name='allego.PairedRefTransformParams.targetNtvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17612,
  serialized_end=17687,
)


_DATASOURCESINKTRANSFORMPARAMS = _descriptor.Descriptor(
  name='DataSourceSinkTransformParams',
  full_name='allego.DataSourceSinkTransformParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsrcName', full_name='allego.DataSourceSinkTransformParams.dsrcName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='allego.DataSourceSinkTransformParams.path', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileType', full_name='allego.DataSourceSinkTransformParams.fileType', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17689,
  serialized_end=17794,
)


_SLICETIMETRANSFORMPARAMS = _descriptor.Descriptor(
  name='SliceTimeTransformParams',
  full_name='allego.SliceTimeTransformParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeStart', full_name='allego.SliceTimeTransformParams.timeStart', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeEnd', full_name='allego.SliceTimeTransformParams.timeEnd', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17796,
  serialized_end=17858,
)


_SLICECHANNELSTRANSFORMPARAMS = _descriptor.Descriptor(
  name='SliceChannelsTransformParams',
  full_name='allego.SliceChannelsTransformParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sysChanIdxs', full_name='allego.SliceChannelsTransformParams.sysChanIdxs', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17860,
  serialized_end=17911,
)


_DOWNSAMPLETRANSFORMPARAMS = _descriptor.Descriptor(
  name='DownsampleTransformParams',
  full_name='allego.DownsampleTransformParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sampleFactor', full_name='allego.DownsampleTransformParams.sampleFactor', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17913,
  serialized_end=17962,
)


_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='allego.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='allego.Position.x', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='allego.Position.y', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17964,
  serialized_end=17996,
)


_TRANSFORMNODE = _descriptor.Descriptor(
  name='TransformNode',
  full_name='allego.TransformNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='allego.TransformNode.id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='allego.TransformNode.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='allego.TransformNode.position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalid', full_name='allego.TransformNode.invalid', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='allego.TransformNode.errorMessage', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='highLowPassParams', full_name='allego.TransformNode.highLowPassParams', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bandParams', full_name='allego.TransformNode.bandParams', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notchParams', full_name='allego.TransformNode.notchParams', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='carParams', full_name='allego.TransformNode.carParams', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='virtualRefParams', full_name='allego.TransformNode.virtualRefParams', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pairedRefParams', full_name='allego.TransformNode.pairedRefParams', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasourceSinkParams', full_name='allego.TransformNode.datasourceSinkParams', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sliceTimeParams', full_name='allego.TransformNode.sliceTimeParams', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sliceChannelsParams', full_name='allego.TransformNode.sliceChannelsParams', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downsampleParams', full_name='allego.TransformNode.downsampleParams', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17999,
  serialized_end=18728,
)


_TRANSFORMEDGE = _descriptor.Descriptor(
  name='TransformEdge',
  full_name='allego.TransformEdge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='allego.TransformEdge.id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='allego.TransformEdge.source', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='allego.TransformEdge.target', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18730,
  serialized_end=18789,
)


_PROTOCOL = _descriptor.Descriptor(
  name='Protocol',
  full_name='allego.Protocol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='allego.Protocol.id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transformNodes', full_name='allego.Protocol.transformNodes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transformEdges', full_name='allego.Protocol.transformEdges', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18791,
  serialized_end=18907,
)


_PROTOCOLREQUEST = _descriptor.Descriptor(
  name='ProtocolRequest',
  full_name='allego.ProtocolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocolID', full_name='allego.ProtocolRequest.protocolID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18909,
  serialized_end=18946,
)


_RENAMEPROTOCOLREQUEST = _descriptor.Descriptor(
  name='RenameProtocolRequest',
  full_name='allego.RenameProtocolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocolID', full_name='allego.RenameProtocolRequest.protocolID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newProtocolID', full_name='allego.RenameProtocolRequest.newProtocolID', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18948,
  serialized_end=19014,
)


_GETALLPROTOCOLSREPLY = _descriptor.Descriptor(
  name='GetAllProtocolsReply',
  full_name='allego.GetAllProtocolsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocols', full_name='allego.GetAllProtocolsReply.protocols', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19016,
  serialized_end=19075,
)


_APPLYPROTOCOLPROGRESS = _descriptor.Descriptor(
  name='ApplyProtocolProgress',
  full_name='allego.ApplyProtocolProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lastTimestampWritten', full_name='allego.ApplyProtocolProgress.lastTimestampWritten', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dsrcTimestampEnd', full_name='allego.ApplyProtocolProgress.dsrcTimestampEnd', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19077,
  serialized_end=19156,
)


_SPIKESORTERSETPARAMREQUEST = _descriptor.Descriptor(
  name='SpikeSorterSetParamRequest',
  full_name='allego.SpikeSorterSetParamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeSorterID', full_name='allego.SpikeSorterSetParamRequest.spikeSorterID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='allego.SpikeSorterSetParamRequest.cmd', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regFloat64', full_name='allego.SpikeSorterSetParamRequest.regFloat64', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regBool', full_name='allego.SpikeSorterSetParamRequest.regBool', index=3,
      number=5, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SpikeSorterSetParamRequest.ntvChanIdx', index=4,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19159,
  serialized_end=19313,
)


_SPIKESORTERSETPARAMSREQUEST = _descriptor.Descriptor(
  name='SpikeSorterSetParamsRequest',
  full_name='allego.SpikeSorterSetParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='allego.SpikeSorterSetParamsRequest.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19315,
  serialized_end=19396,
)


_SPIKESORTERPARAMCOMMANDRECORD = _descriptor.Descriptor(
  name='SpikeSorterParamCommandRecord',
  full_name='allego.SpikeSorterParamCommandRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isEnabled', full_name='allego.SpikeSorterParamCommandRecord.isEnabled', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SpikeSorterParamCommandRecord.ntvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thr', full_name='allego.SpikeSorterParamCommandRecord.thr', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thrSd', full_name='allego.SpikeSorterParamCommandRecord.thrSd', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thrWdwPts', full_name='allego.SpikeSorterParamCommandRecord.thrWdwPts', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thrWdw', full_name='allego.SpikeSorterParamCommandRecord.thrWdw', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow', full_name='allego.SpikeSorterParamCommandRecord.shadow', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadowPts', full_name='allego.SpikeSorterParamCommandRecord.shadowPts', index=7,
      number=8, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSetThr', full_name='allego.SpikeSorterParamCommandRecord.isSetThr', index=8,
      number=9, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weakThr', full_name='allego.SpikeSorterParamCommandRecord.weakThr', index=9,
      number=10, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weakThrSd', full_name='allego.SpikeSorterParamCommandRecord.weakThrSd', index=10,
      number=11, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSetWeakThr', full_name='allego.SpikeSorterParamCommandRecord.isSetWeakThr', index=11,
      number=12, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peakWdwPts', full_name='allego.SpikeSorterParamCommandRecord.peakWdwPts', index=12,
      number=13, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peakWdw', full_name='allego.SpikeSorterParamCommandRecord.peakWdw', index=13,
      number=14, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isSD', full_name='allego.SpikeSorterParamCommandRecord.isSD', index=14,
      number=15, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19399,
  serialized_end=19694,
)


_WRANGLEREQUEST = _descriptor.Descriptor(
  name='WrangleRequest',
  full_name='allego.WrangleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.WrangleRequest.mode', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='allego.WrangleRequest.spec', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19696,
  serialized_end=19782,
)


_WRANGLESPEC = _descriptor.Descriptor(
  name='WrangleSpec',
  full_name='allego.WrangleSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='import', full_name='allego.WrangleSpec.import', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='merge', full_name='allego.WrangleSpec.merge', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19784,
  serialized_end=19873,
)


_WRANGLEIMPORT = _descriptor.Descriptor(
  name='WrangleImport',
  full_name='allego.WrangleImport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vexSpikesSim', full_name='allego.WrangleImport.vexSpikesSim', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19875,
  serialized_end=19947,
)


_WRANGLEIMPORTVEXSPIKESSIM = _descriptor.Descriptor(
  name='WrangleImportVexSpikesSim',
  full_name='allego.WrangleImportVexSpikesSim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='allego.WrangleImportVexSpikesSim.source', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isOverwrite', full_name='allego.WrangleImportVexSpikesSim.isOverwrite', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='note', full_name='allego.WrangleImportVexSpikesSim.note', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19949,
  serialized_end=20052,
)


_WRANGLEFILEDESC = _descriptor.Descriptor(
  name='WrangleFileDesc',
  full_name='allego.WrangleFileDesc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='allego.WrangleFileDesc.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseName', full_name='allego.WrangleFileDesc.baseName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileType', full_name='allego.WrangleFileDesc.fileType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20054,
  serialized_end=20121,
)


_WRANGLEMERGE = _descriptor.Descriptor(
  name='WrangleMerge',
  full_name='allego.WrangleMerge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vexSpikesView', full_name='allego.WrangleMerge.vexSpikesView', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20123,
  serialized_end=20195,
)


_WRANGLEMERGEVEXSPIKESVIEW = _descriptor.Descriptor(
  name='WrangleMergeVexSpikesView',
  full_name='allego.WrangleMergeVexSpikesView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sourceVex', full_name='allego.WrangleMergeVexSpikesView.sourceVex', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceBio', full_name='allego.WrangleMergeVexSpikesView.sourceBio', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='allego.WrangleMergeVexSpikesView.view', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='note', full_name='allego.WrangleMergeVexSpikesView.note', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isBandpassFilter', full_name='allego.WrangleMergeVexSpikesView.isBandpassFilter', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bandpassFilterSpec', full_name='allego.WrangleMergeVexSpikesView.bandpassFilterSpec', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isOverwrite', full_name='allego.WrangleMergeVexSpikesView.isOverwrite', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeWindowMs', full_name='allego.WrangleMergeVexSpikesView.spikeWindowMs', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeShadowMs', full_name='allego.WrangleMergeVexSpikesView.spikeShadowMs', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20198,
  serialized_end=20501,
)


_WRANGLEMERGEVEXSPIKESVIEWSPEC = _descriptor.Descriptor(
  name='WrangleMergeVexSpikesViewSpec',
  full_name='allego.WrangleMergeVexSpikesViewSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sinkBio', full_name='allego.WrangleMergeVexSpikesViewSpec.sinkBio', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteNeighborRadiusUm', full_name='allego.WrangleMergeVexSpikesViewSpec.siteNeighborRadiusUm', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reqNumSiteNeighbors', full_name='allego.WrangleMergeVexSpikesViewSpec.reqNumSiteNeighbors', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeWindowMs', full_name='allego.WrangleMergeVexSpikesViewSpec.spikeWindowMs', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeShadowMs', full_name='allego.WrangleMergeVexSpikesViewSpec.spikeShadowMs', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='note', full_name='allego.WrangleMergeVexSpikesViewSpec.note', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20504,
  serialized_end=20696,
)


_DACSTREAMREQUEST = _descriptor.Descriptor(
  name='DACStreamRequest',
  full_name='allego.DACStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='DAC', full_name='allego.DACStreamRequest.DAC', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='NtvChanIdx', full_name='allego.DACStreamRequest.NtvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.DACStreamRequest.streamGroupId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20698,
  serialized_end=20772,
)


_EVENTVIEWERCONFIG = _descriptor.Descriptor(
  name='EventViewerConfig',
  full_name='allego.EventViewerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventViewerId', full_name='allego.EventViewerConfig.eventViewerId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.EventViewerConfig.streamGroupId', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerSysChanIdx', full_name='allego.EventViewerConfig.triggerSysChanIdx', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerThresholdUV', full_name='allego.EventViewerConfig.triggerThresholdUV', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preTriggerMs', full_name='allego.EventViewerConfig.preTriggerMs', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='postTriggerMs', full_name='allego.EventViewerConfig.postTriggerMs', index=5,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerType', full_name='allego.EventViewerConfig.triggerType', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvIdx', full_name='allego.EventViewerConfig.ntvIdx', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20775,
  serialized_end=20997,
)


_EVENTVIEWERID = _descriptor.Descriptor(
  name='EventViewerID',
  full_name='allego.EventViewerID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventViewerId', full_name='allego.EventViewerID.eventViewerId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamGroupId', full_name='allego.EventViewerID.streamGroupId', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20999,
  serialized_end=21060,
)


_GETEVENTVIEWEREVENTREQUEST = _descriptor.Descriptor(
  name='GetEventViewerEventRequest',
  full_name='allego.GetEventViewerEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventViewerId', full_name='allego.GetEventViewerEventRequest.eventViewerId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventId', full_name='allego.GetEventViewerEventRequest.eventId', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21062,
  serialized_end=21130,
)


_EVENTVIEWEREVENTDESC = _descriptor.Descriptor(
  name='EventViewerEventDesc',
  full_name='allego.EventViewerEventDesc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventId', full_name='allego.EventViewerEventDesc.eventId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerTimestamp', full_name='allego.EventViewerEventDesc.triggerTimestamp', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.EventViewerEventDesc.timestampRange', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21132,
  serialized_end=21221,
)


_EVENTVIEWEREVENT = _descriptor.Descriptor(
  name='EventViewerEvent',
  full_name='allego.EventViewerEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventId', full_name='allego.EventViewerEvent.eventId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='triggerTimestamp', full_name='allego.EventViewerEvent.triggerTimestamp', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.EventViewerEvent.timestampRange', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signals', full_name='allego.EventViewerEvent.signals', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sysChanIdxs', full_name='allego.EventViewerEvent.sysChanIdxs', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21224,
  serialized_end=21367,
)


_LISTEVENTVIEWEREVENTSREPLY = _descriptor.Descriptor(
  name='ListEventViewerEventsReply',
  full_name='allego.ListEventViewerEventsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventViewerId', full_name='allego.ListEventViewerEventsReply.eventViewerId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='allego.ListEventViewerEventsReply.events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21369,
  serialized_end=21466,
)


_LISTEVENTVIEWERSREPLY = _descriptor.Descriptor(
  name='ListEventViewersReply',
  full_name='allego.ListEventViewersReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventViewers', full_name='allego.ListEventViewersReply.eventViewers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21468,
  serialized_end=21536,
)


_STATUSPOLLFIELDSTOUPDATEREQUEST = _descriptor.Descriptor(
  name='StatusPollFieldsToUpdateRequest',
  full_name='allego.StatusPollFieldsToUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientId', full_name='allego.StatusPollFieldsToUpdateRequest.clientId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21538,
  serialized_end=21589,
)


_STATUSPOLLFIELDSTOUPDATE = _descriptor.Descriptor(
  name='StatusPollFieldsToUpdate',
  full_name='allego.StatusPollFieldsToUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientId', full_name='allego.StatusPollFieldsToUpdate.clientId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fieldsToUpdate', full_name='allego.StatusPollFieldsToUpdate.fieldsToUpdate', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21591,
  serialized_end=21685,
)

_WORKSPACEDESCRIPTOR.fields_by_name['app'].enum_type = _WORKSPACEAPP
_WORKSPACEDESCRIPTOR.fields_by_name['annotation'].message_type = _ANNOTATEBUNDLE
_WORKSPACECONTROLREQUEST.fields_by_name['cmd'].enum_type = _WORKSPACECOMMANDS
_WORKSPACECONTROLREQUEST.fields_by_name['annotation'].message_type = _ANNOTATEBUNDLE
_GETWORKSPACEREQUEST.fields_by_name['cmd'].enum_type = _GETWORKSPACECOMMANDS
_GETWORKSPACEREQUEST.fields_by_name['appMask'].enum_type = _WORKSPACEAPP
_GETWORKSPACEREQUEST.fields_by_name['annotateMask'].message_type = _ANNOTATEBUNDLE
_GETWORKSPACEREPLY_WORKSPACEDESCENTRY.fields_by_name['value'].message_type = _WORKSPACEDESCRIPTOR
_GETWORKSPACEREPLY_WORKSPACEDESCENTRY.containing_type = _GETWORKSPACEREPLY
_GETWORKSPACEREPLY.fields_by_name['workspaceDesc'].message_type = _GETWORKSPACEREPLY_WORKSPACEDESCENTRY
_GETRADIENSSERVERSREQUEST.fields_by_name['serverType'].enum_type = _RADIENSSERVERTYPE
_SERVERSPEC_GRPCSERVICE.containing_type = _SERVERSPEC
_SERVERSPEC_SPAWNEDPROCESS.containing_type = _SERVERSPEC
_SERVERSPEC_SERVICEENTRY.fields_by_name['value'].message_type = _SERVERSPEC_GRPCSERVICE
_SERVERSPEC_SERVICEENTRY.containing_type = _SERVERSPEC
_SERVERSPEC.fields_by_name['service'].message_type = _SERVERSPEC_SERVICEENTRY
_SERVERSPEC.fields_by_name['spawn'].message_type = _SERVERSPEC_SPAWNEDPROCESS
_RADIENSSERVERSREPLY.fields_by_name['allegoserver'].message_type = _SERVERSPEC
_RADIENSSERVERSREPLY.fields_by_name['radiensserver'].message_type = _SERVERSPEC
_PORTCHANNELCOUNT.fields_by_name['port'].enum_type = _PORT
_SETPORTREQUEST.fields_by_name['port'].enum_type = _PORT
_HDSNAPSHOTREQUEST_SELECTEDSIGNALS.containing_type = _HDSNAPSHOTREQUEST
_HDSNAPSHOTREQUEST.fields_by_name['priSignals'].message_type = _HDSNAPSHOTREQUEST_SELECTEDSIGNALS
_HDSNAPSHOTREQUEST.fields_by_name['auxSignals'].message_type = _HDSNAPSHOTREQUEST_SELECTEDSIGNALS
_HDSNAPSHOTREQUEST.fields_by_name['dinSignals'].message_type = _HDSNAPSHOTREQUEST_SELECTEDSIGNALS
_HDSNAPSHOTREQUEST.fields_by_name['doutSignals'].message_type = _HDSNAPSHOTREQUEST_SELECTEDSIGNALS
_HDSNAPSHOTMETA.fields_by_name['sigGroup'].message_type = _SIGNALGROUP
_HDSNAPSHOT.fields_by_name['meta'].message_type = _HDSNAPSHOTMETA
_HDSNAPSHOT.fields_by_name['signals'].message_type = _RAWSIGNALS
_HDSNAPSHOT.fields_by_name['priSignals'].message_type = _RAWSIGNALS
_HDSNAPSHOT.fields_by_name['auxSignals'].message_type = _RAWSIGNALS
_HDSNAPSHOT.fields_by_name['dinSignals'].message_type = _RAWSIGNALS
_HDSNAPSHOT.fields_by_name['doutSignals'].message_type = _RAWSIGNALS
_GETSIGNALSREQUEST_GETSIGSPARAMS.fields_by_name['resampleType'].enum_type = _RESAMPLEROUTINE
_GETSIGNALSREQUEST_GETSIGSPARAMS.containing_type = _GETSIGNALSREQUEST
_GETSIGNALSREQUEST.fields_by_name['params'].message_type = _GETSIGNALSREQUEST_GETSIGSPARAMS
_LISTSENSORSPECSREPLY_SPECWITHCHANNELCOUNT.containing_type = _LISTSENSORSPECSREPLY
_LISTSENSORSPECSREPLY.fields_by_name['probes'].message_type = _LISTSENSORSPECSREPLY_SPECWITHCHANNELCOUNT
_LISTSENSORSPECSREPLY.fields_by_name['headstages'].message_type = _LISTSENSORSPECSREPLY_SPECWITHCHANNELCOUNT
_LISTSENSORSPECSREPLY.fields_by_name['ports'].message_type = _PORTCHANNELCOUNT
_LISTDATASOURCESREQUEST.fields_by_name['sortBy'].enum_type = _DATASOURCESORT
_DATASOURCE.fields_by_name['fileType'].enum_type = _RADIXFILETYPES
_FILEDESCRIPTOR.fields_by_name['fileType'].enum_type = _RADIXFILETYPES
_TIMESPEC_TIMERANGEL.containing_type = _TIMESPEC
_TIMESPEC_TIMESTAMPRANGEL.containing_type = _TIMESPEC
_TIMESPEC.fields_by_name['timeRange'].message_type = _TIMESPEC_TIMERANGEL
_TIMESPEC.fields_by_name['timestampRange'].message_type = _TIMESPEC_TIMESTAMPRANGEL
_TIMESPEC.oneofs_by_name['timeDesc'].fields.append(
  _TIMESPEC.fields_by_name['timeRange'])
_TIMESPEC.fields_by_name['timeRange'].containing_oneof = _TIMESPEC.oneofs_by_name['timeDesc']
_TIMESPEC.oneofs_by_name['timeDesc'].fields.append(
  _TIMESPEC.fields_by_name['timestampRange'])
_TIMESPEC.fields_by_name['timestampRange'].containing_oneof = _TIMESPEC.oneofs_by_name['timeDesc']
_SIGNALSPEC_SITENUML.containing_type = _SIGNALSPEC
_SIGNALSPEC_NTVCHANIDXL.containing_type = _SIGNALSPEC
_SIGNALSPEC.fields_by_name['siteNum'].message_type = _SIGNALSPEC_SITENUML
_SIGNALSPEC.fields_by_name['ntvChanIdx'].message_type = _SIGNALSPEC_NTVCHANIDXL
_SIGNALSPEC.oneofs_by_name['siteDesc'].fields.append(
  _SIGNALSPEC.fields_by_name['siteNum'])
_SIGNALSPEC.fields_by_name['siteNum'].containing_oneof = _SIGNALSPEC.oneofs_by_name['siteDesc']
_SIGNALSPEC.oneofs_by_name['siteDesc'].fields.append(
  _SIGNALSPEC.fields_by_name['ntvChanIdx'])
_SIGNALSPEC.fields_by_name['ntvChanIdx'].containing_oneof = _SIGNALSPEC.oneofs_by_name['siteDesc']
_CHANNELRECORD.fields_by_name['chanType'].enum_type = _SIGNALTYPE
_CHANNELRECORD.fields_by_name['port'].enum_type = _PORT
_SENSOR_WIREFRAME.fields_by_name['vtx'].message_type = _XYCOORD
_SENSOR_WIREFRAME.fields_by_name['vtxXlim'].message_type = _XYCOORD
_SENSOR_WIREFRAME.fields_by_name['vtxYlim'].message_type = _XYCOORD
_SENSOR_WIREFRAME.containing_type = _SENSOR
_SENSOR.fields_by_name['wireframe'].message_type = _SENSOR_WIREFRAME
_SENSOR.fields_by_name['position'].message_type = _SENSORPOSITIONTCS
_SENSORPORTSPEC.fields_by_name['sensorA'].message_type = _SENSOR
_SENSORPORTSPEC.fields_by_name['sensorB'].message_type = _SENSOR
_SENSORPORTSPEC.fields_by_name['sensorC'].message_type = _SENSOR
_SENSORPORTSPEC.fields_by_name['sensorD'].message_type = _SENSOR
_SENSORPORTSPEC.fields_by_name['sensorE'].message_type = _SENSOR
_SENSORPORTSPEC.fields_by_name['sensorF'].message_type = _SENSOR
_SENSORPORTSPEC.fields_by_name['sensorG'].message_type = _SENSOR
_SENSORPORTSPEC.fields_by_name['sensorH'].message_type = _SENSOR
_SIGNALGROUPUNITS_UNITSENTRY.containing_type = _SIGNALGROUPUNITS
_SIGNALGROUPUNITS.fields_by_name['units'].message_type = _SIGNALGROUPUNITS_UNITSENTRY
_SIGNALGROUP.fields_by_name['channels'].message_type = _CHANNELRECORD
_SIGNALGROUP.fields_by_name['sensorPortSpec'].message_type = _SENSORPORTSPEC
_SIGNALGROUP.fields_by_name['signalUnits'].message_type = _SIGNALGROUPUNITS
_CREATESIGNALGROUPREQUEST.fields_by_name['type'].enum_type = _RADIXFILETYPES
_SUBOPSORT.fields_by_name['sort'].enum_type = _SUBOPSORT_SORTFIELD
_SUBOPSORT_SORTFIELD.containing_type = _SUBOPSORT
_UPDATESIGNALGROUPREQUEST.fields_by_name['operation'].enum_type = _UPDATESIGNALGROUPREQUEST_OPERATION
_UPDATESIGNALGROUPREQUEST.fields_by_name['addRemove'].enum_type = _UPDATESIGNALGROUPREQUEST_SUBOPERATION
_UPDATESIGNALGROUPREQUEST.fields_by_name['sortOp'].message_type = _SUBOPSORT
_UPDATESIGNALGROUPREQUEST.fields_by_name['signalType'].enum_type = _SIGNALTYPE
_UPDATESIGNALGROUPREQUEST_OPERATION.containing_type = _UPDATESIGNALGROUPREQUEST
_UPDATESIGNALGROUPREQUEST_SUBOPERATION.containing_type = _UPDATESIGNALGROUPREQUEST
_UPDATESIGNALGROUPREQUEST.oneofs_by_name['subOperation'].fields.append(
  _UPDATESIGNALGROUPREQUEST.fields_by_name['addRemove'])
_UPDATESIGNALGROUPREQUEST.fields_by_name['addRemove'].containing_oneof = _UPDATESIGNALGROUPREQUEST.oneofs_by_name['subOperation']
_UPDATESIGNALGROUPREQUEST.oneofs_by_name['subOperation'].fields.append(
  _UPDATESIGNALGROUPREQUEST.fields_by_name['sortOp'])
_UPDATESIGNALGROUPREQUEST.fields_by_name['sortOp'].containing_oneof = _UPDATESIGNALGROUPREQUEST.oneofs_by_name['subOperation']
_SETDSPGROUPREQUEST.fields_by_name['stage'].enum_type = _FILTERSTAGE
_SETDSPGROUPREQUEST.fields_by_name['dspParams'].message_type = _DSPPARAMS
_DSPPARAMS_FREQSPECBAND.containing_type = _DSPPARAMS
_DSPPARAMS.fields_by_name['type'].enum_type = _DSPTYPE
_DSPPARAMS.fields_by_name['stage'].enum_type = _FILTERSTAGE
_DSPPARAMS.fields_by_name['freqSpecBand'].message_type = _DSPPARAMS_FREQSPECBAND
_DSPPARAMS.fields_by_name['port'].enum_type = _PORT
_DSPPARAMS.oneofs_by_name['freqSpec'].fields.append(
  _DSPPARAMS.fields_by_name['freq'])
_DSPPARAMS.fields_by_name['freq'].containing_oneof = _DSPPARAMS.oneofs_by_name['freqSpec']
_DSPPARAMS.oneofs_by_name['freqSpec'].fields.append(
  _DSPPARAMS.fields_by_name['freqSpecBand'])
_DSPPARAMS.fields_by_name['freqSpecBand'].containing_oneof = _DSPPARAMS.oneofs_by_name['freqSpec']
_DSPPARAMS.oneofs_by_name['freqSpec'].fields.append(
  _DSPPARAMS.fields_by_name['refNtvChanIdx'])
_DSPPARAMS.fields_by_name['refNtvChanIdx'].containing_oneof = _DSPPARAMS.oneofs_by_name['freqSpec']
_DSPGROUP.fields_by_name['hardware'].message_type = _DSPPARAMS
_DSPGROUP.fields_by_name['softwareStage1'].message_type = _DSPPARAMS
_DSPGROUP.fields_by_name['softwareStage2'].message_type = _DSPPARAMS
_SETSENSORREQUEST.fields_by_name['port'].enum_type = _PORT
_SETSENSORPOSITIONTCSREQUEST.fields_by_name['port'].enum_type = _PORT
_SETSENSORPOSITIONTCSREQUEST.fields_by_name['position'].message_type = _SENSORPOSITIONTCS
_SETSITEPOSITIONSTCSREQUEST.fields_by_name['port'].enum_type = _PORT
_SETSITEPOSITIONSTCSREQUEST.fields_by_name['sitePositions'].message_type = _SITEPOSITIONTCS
_FEATURESTARTSTOPREQUEST.fields_by_name['featureLicense'].enum_type = _FEATURELICENSE
_KPIMETRICID.fields_by_name['mode'].enum_type = _KPIMETRICSMODE
_KPIMETRICID.fields_by_name['name'].enum_type = _KPIMETRICSENUM
_BUNDLEREQ.fields_by_name['tR'].message_type = _TIMERANGE
_BUNDLEREQ.fields_by_name['metrics'].message_type = _KPIMETRICID
_KPIMETRICSREQ.fields_by_name['stype'].enum_type = _SIGNALTYPE
_KPIMETRICSREQ.fields_by_name['arg'].message_type = _BUNDLEREQ
_KPIMETRICSREQ.fields_by_name['bundleName'].enum_type = _KPIBUNDLENAME
_KPIMETRICSDATA_METRICSTATS.containing_type = _KPIMETRICSDATA
_KPIMETRICSDATA.fields_by_name['metric'].message_type = _KPIMETRICID
_KPIMETRICSDATA.fields_by_name['val'].message_type = _DENSEMATRIX
_KPIMETRICSDATA.fields_by_name['statsPkts'].message_type = _KPIMETRICSDATA_METRICSTATS
_KPIMETRICSDATA.fields_by_name['stats'].message_type = _KPIMETRICSDATA_METRICSTATS
_KPIMETRICSDATA.fields_by_name['tR'].message_type = _TIMERANGE
_KPIBUNDLEPACKETMETRICS.fields_by_name['sigType'].enum_type = _SIGNALTYPE
_KPIBUNDLEPACKETMETRICS.fields_by_name['metrics'].message_type = _KPIMETRICSDATA
_KPIMETRICS.fields_by_name['bundle'].message_type = _KPIBUNDLEPACKETMETRICS
_KPICONTROLREQUEST.fields_by_name['stype'].enum_type = _SIGNALTYPE
_KPICONTROLREQUEST.fields_by_name['name'].enum_type = _KPIBUNDLENAME
_SETKPIUPDATEPERIODREQUEST.fields_by_name['stype'].enum_type = _SIGNALTYPE
_SETKPIUPDATEPERIODREQUEST.fields_by_name['name'].enum_type = _KPIBUNDLENAME
_SETKPITHRESHOLDREQUEST.fields_by_name['stype'].enum_type = _SIGNALTYPE
_SETKPITHRESHOLDREQUEST.fields_by_name['thrName'].enum_type = _KPITHRESHOLDNAME
_SETKPITHRESHOLDREQUEST.fields_by_name['name'].enum_type = _KPIBUNDLENAME
_SETKPIEVENTDETECTREQUEST.fields_by_name['stype'].enum_type = _SIGNALTYPE
_SETKPIEVENTDETECTREQUEST.fields_by_name['thrName'].enum_type = _KPITHRESHOLDNAME
_SETKPIEVENTSHADOWREQUEST.fields_by_name['stype'].enum_type = _SIGNALTYPE
_SETKPIEVENTSHADOWREQUEST.fields_by_name['wdwName'].enum_type = _KPIWINDOWDNAME
_SETKPIEVENTWINDOWREQUEST.fields_by_name['stype'].enum_type = _SIGNALTYPE
_SETKPIEVENTWINDOWREQUEST.fields_by_name['wdwName'].enum_type = _KPIWINDOWDNAME
_GETKPISTATUSREQUEST.fields_by_name['name'].enum_type = _KPIBUNDLENAME
_RADIXMATRIXLIST.fields_by_name['matrix'].message_type = _RADIXMATRIX
_RADIXSIGNALSLIST.fields_by_name['matrix'].message_type = _RADIXSIGNALS
_RADIXSIGNALS.fields_by_name['pri'].message_type = _RADIXMATRIX
_RADIXSIGNALS.fields_by_name['aux'].message_type = _RADIXMATRIX
_RADIXSIGNALS.fields_by_name['din'].message_type = _RADIXMATRIX
_RADIXSIGNALS.fields_by_name['dout'].message_type = _RADIXMATRIX
_VECTORSLICEFLOAT64.fields_by_name['vec'].message_type = _VECTORFLOAT64
_LOGSYSKPISTATUSREPLY.fields_by_name['portA'].message_type = _KPICACHE
_LOGSYSKPISTATUSREPLY.fields_by_name['portB'].message_type = _KPICACHE
_LOGSYSKPISTATUSREPLY.fields_by_name['portC'].message_type = _KPICACHE
_LOGSYSKPISTATUSREPLY.fields_by_name['portD'].message_type = _KPICACHE
_LOGSYSKPISTATUSREPLY.fields_by_name['portE'].message_type = _KPICACHE
_LOGSYSKPISTATUSREPLY.fields_by_name['portF'].message_type = _KPICACHE
_LOGSYSKPISTATUSREPLY.fields_by_name['portG'].message_type = _KPICACHE
_LOGSYSKPISTATUSREPLY.fields_by_name['portH'].message_type = _KPICACHE
_LOGSYSKPISTATUSREPLY.fields_by_name['aux0'].message_type = _KPICACHE
_LOGSYSKPISTATUSREPLY.fields_by_name['aux1'].message_type = _KPICACHE
_LOGSYSKPITAILREPLY.fields_by_name['portA'].message_type = _KPIPORTINFO
_LOGSYSKPITAILREPLY.fields_by_name['portB'].message_type = _KPIPORTINFO
_LOGSYSKPITAILREPLY.fields_by_name['portC'].message_type = _KPIPORTINFO
_LOGSYSKPITAILREPLY.fields_by_name['portD'].message_type = _KPIPORTINFO
_LOGSYSKPITAILREPLY.fields_by_name['portE'].message_type = _KPIPORTINFO
_LOGSYSKPITAILREPLY.fields_by_name['portF'].message_type = _KPIPORTINFO
_LOGSYSKPITAILREPLY.fields_by_name['portG'].message_type = _KPIPORTINFO
_LOGSYSKPITAILREPLY.fields_by_name['portH'].message_type = _KPIPORTINFO
_LOGSYSKPITAILREPLY.fields_by_name['aux0'].message_type = _KPIPORTINFO
_LOGSYSKPITAILREPLY.fields_by_name['aux1'].message_type = _KPIPORTINFO
_KPIPORTINFO.fields_by_name['kpiTail'].message_type = _KPITAILROWS
_SENSORCOMPREQUEST.fields_by_name['probe'].message_type = _PROBEDESC
_SENSORCOMPREQUEST.fields_by_name['headstage'].message_type = _HEADSTAGEDESC
_REGISTERSENSORCOMPREQUEST.fields_by_name['probe'].message_type = _PROBEDESC
_REGISTERSENSORCOMPREQUEST.fields_by_name['headstage'].message_type = _HEADSTAGEDESC
_SAVESENSORCOMPINSTANCEREQUEST.fields_by_name['probe'].message_type = _PROBEDESC
_SAVESENSORCOMPINSTANCEREQUEST.fields_by_name['headstage'].message_type = _HEADSTAGEDESC
_GETSENSORCOMPREPLY.fields_by_name['probe'].message_type = _PROBESPEC
_GETSENSORCOMPREPLY.fields_by_name['headstage'].message_type = _HEADSTAGESPEC
_PROBESPEC.fields_by_name['desc'].message_type = _PROBEDESC
_PROBESPEC.fields_by_name['model'].message_type = _PROBEMODEL
_PROBESPEC.fields_by_name['metaData'].message_type = _PROBEMETADATA
_HEADSTAGESPEC.fields_by_name['desc'].message_type = _HEADSTAGEDESC
_HEADSTAGESPEC.fields_by_name['model'].message_type = _HEADSTAGEMODEL
_HEADSTAGESPEC.fields_by_name['metaData'].message_type = _HEADSTAGEMETADATA
_PROBEMODEL_PROBESITEDESC.containing_type = _PROBEMODEL
_PROBEMODEL_PROBEWIREFRAME.fields_by_name['vertex'].message_type = _PROBEMODEL_PROBEPTXY
_PROBEMODEL_PROBEWIREFRAME.containing_type = _PROBEMODEL
_PROBEMODEL_PROBEPTXY.containing_type = _PROBEMODEL
_PROBEMODEL.fields_by_name['site'].message_type = _PROBEMODEL_PROBESITEDESC
_PROBEMODEL.fields_by_name['wireframe'].message_type = _PROBEMODEL_PROBEWIREFRAME
_PROBEMODEL.fields_by_name['siteOverallMin'].message_type = _PROBEMODEL_PROBEPTXY
_PROBEMODEL.fields_by_name['siteOverallMax'].message_type = _PROBEMODEL_PROBEPTXY
_HEADSTAGEMODEL_HEADSTAGEROW.containing_type = _HEADSTAGEMODEL
_HEADSTAGEMODEL.fields_by_name['rows'].message_type = _HEADSTAGEMODEL_HEADSTAGEROW
_GETCURRENTPROFILEREPLY.fields_by_name['userProfile'].message_type = _USERPROFILE
_GETALLPROFILESREPLY.fields_by_name['userProfiles'].message_type = _USERPROFILE
_MANAGENODEORGREQUEST.fields_by_name['cmd'].enum_type = _MANAGENODECMD
_MANAGENODEORGREQUEST.fields_by_name['payload'].message_type = _MANAGENODEORGPAYLOAD
_MANAGENODEORGREPLY.fields_by_name['payload'].message_type = _MANAGENODEORGPAYLOAD
_MANAGENODELABREQUEST.fields_by_name['cmd'].enum_type = _MANAGENODECMD
_MANAGENODELABREQUEST.fields_by_name['payload'].message_type = _MANAGENODELABPAYLOAD
_MANAGENODELABREPLY.fields_by_name['payload'].message_type = _MANAGENODELABPAYLOAD
_MANAGENODEUSERPAYLOAD.fields_by_name['role'].enum_type = _USERROLETYPE
_MANAGENODEUSERREQUEST.fields_by_name['cmd'].enum_type = _MANAGENODECMD
_MANAGENODEUSERREQUEST.fields_by_name['payload'].message_type = _MANAGENODEUSERPAYLOAD
_MANAGENODEUSERREPLY.fields_by_name['payload'].message_type = _MANAGENODEUSERPAYLOAD
_CATALOGPROBEPAYLOAD.fields_by_name['spec'].message_type = _PROBESPEC
_PROBENODEREQUEST.fields_by_name['cmd'].enum_type = _MANAGENODECMD
_PROBENODEREQUEST.fields_by_name['payload'].message_type = _PROBEPAYLOAD
_PROBENODEREPLY.fields_by_name['payload'].message_type = _PROBEPAYLOAD
_PROBEPAYLOAD.fields_by_name['spec'].message_type = _PROBESPEC
_EDGEPAYLOAD_GENERICNODE.fields_by_name['label'].enum_type = _WORLDNODELABEL
_EDGEPAYLOAD_GENERICNODE.containing_type = _EDGEPAYLOAD
_EDGEPAYLOAD.fields_by_name['source'].message_type = _EDGEPAYLOAD_GENERICNODE
_EDGEPAYLOAD.fields_by_name['target'].message_type = _EDGEPAYLOAD_GENERICNODE
_EDGEPAYLOAD.fields_by_name['edgeLabel'].enum_type = _WORLDEDGELABEL
_EDGEPAYLOAD.fields_by_name['direction'].enum_type = _WORLDEDGEDIRECTION
_WORLDEDGEREQUEST.fields_by_name['payload'].message_type = _EDGEPAYLOAD
_QUERYWORLDREQUEST.fields_by_name['cmd'].enum_type = _WORLDQUERYCMD
_QUERYWORLDREC.fields_by_name['org'].message_type = _MANAGENODEORGPAYLOAD
_QUERYWORLDREC.fields_by_name['lab'].message_type = _MANAGENODELABPAYLOAD
_QUERYWORLDREC.fields_by_name['user'].message_type = _MANAGENODEUSERPAYLOAD
_QUERYWORLDREC.fields_by_name['catProbe'].message_type = _CATALOGPROBEPAYLOAD
_QUERYWORLDREC.fields_by_name['probe'].message_type = _PROBEPAYLOAD
_QUERYWORLDREPLY.fields_by_name['payload'].message_type = _QUERYWORLDREC
_DATASOURCESINKTRANSFORMPARAMS.fields_by_name['fileType'].enum_type = _RADIXFILETYPES
_TRANSFORMNODE.fields_by_name['type'].enum_type = _TRANSFORMNODETYPE
_TRANSFORMNODE.fields_by_name['position'].message_type = _POSITION
_TRANSFORMNODE.fields_by_name['highLowPassParams'].message_type = _HIGHLOWPASSTRANSFORMPARAMS
_TRANSFORMNODE.fields_by_name['bandParams'].message_type = _BANDTRANSFORMPARAMS
_TRANSFORMNODE.fields_by_name['notchParams'].message_type = _NOTCHTRANSFORMPARAMS
_TRANSFORMNODE.fields_by_name['carParams'].message_type = _CARTRANSFORMPARAMS
_TRANSFORMNODE.fields_by_name['virtualRefParams'].message_type = _VIRTUALREFTRANSFORMPARAMS
_TRANSFORMNODE.fields_by_name['pairedRefParams'].message_type = _PAIREDREFTRANSFORMPARAMS
_TRANSFORMNODE.fields_by_name['datasourceSinkParams'].message_type = _DATASOURCESINKTRANSFORMPARAMS
_TRANSFORMNODE.fields_by_name['sliceTimeParams'].message_type = _SLICETIMETRANSFORMPARAMS
_TRANSFORMNODE.fields_by_name['sliceChannelsParams'].message_type = _SLICECHANNELSTRANSFORMPARAMS
_TRANSFORMNODE.fields_by_name['downsampleParams'].message_type = _DOWNSAMPLETRANSFORMPARAMS
_PROTOCOL.fields_by_name['transformNodes'].message_type = _TRANSFORMNODE
_PROTOCOL.fields_by_name['transformEdges'].message_type = _TRANSFORMEDGE
_GETALLPROTOCOLSREPLY.fields_by_name['protocols'].message_type = _PROTOCOL
_SPIKESORTERSETPARAMREQUEST.fields_by_name['cmd'].enum_type = _SPIKESORTERPARAMCOMMAND
_SPIKESORTERSETPARAMSREQUEST.fields_by_name['params'].message_type = _SPIKESORTERSETPARAMREQUEST
_WRANGLEREQUEST.fields_by_name['mode'].enum_type = _WRANGLEMODE
_WRANGLEREQUEST.fields_by_name['spec'].message_type = _WRANGLESPEC
_WRANGLESPEC.fields_by_name['import'].message_type = _WRANGLEIMPORT
_WRANGLESPEC.fields_by_name['merge'].message_type = _WRANGLEMERGE
_WRANGLEIMPORT.fields_by_name['vexSpikesSim'].message_type = _WRANGLEIMPORTVEXSPIKESSIM
_WRANGLEIMPORTVEXSPIKESSIM.fields_by_name['source'].message_type = _WRANGLEFILEDESC
_WRANGLEMERGE.fields_by_name['vexSpikesView'].message_type = _WRANGLEMERGEVEXSPIKESVIEW
_WRANGLEMERGEVEXSPIKESVIEW.fields_by_name['sourceVex'].message_type = _WRANGLEFILEDESC
_WRANGLEMERGEVEXSPIKESVIEW.fields_by_name['sourceBio'].message_type = _WRANGLEFILEDESC
_WRANGLEMERGEVEXSPIKESVIEW.fields_by_name['view'].message_type = _WRANGLEMERGEVEXSPIKESVIEWSPEC
_WRANGLEMERGEVEXSPIKESVIEWSPEC.fields_by_name['sinkBio'].message_type = _WRANGLEFILEDESC
_EVENTVIEWERCONFIG.fields_by_name['triggerType'].enum_type = _SIGNALTYPE
_EVENTVIEWEREVENT.fields_by_name['signals'].message_type = _RAWSIGNALS
_LISTEVENTVIEWEREVENTSREPLY.fields_by_name['events'].message_type = _EVENTVIEWEREVENTDESC
_LISTEVENTVIEWERSREPLY.fields_by_name['eventViewers'].message_type = _EVENTVIEWERID
_STATUSPOLLFIELDSTOUPDATE.fields_by_name['fieldsToUpdate'].enum_type = _STATUSPOLLFIELDS
DESCRIPTOR.message_types_by_name['RadixEnvironment'] = _RADIXENVIRONMENT
DESCRIPTOR.message_types_by_name['StandardRequest'] = _STANDARDREQUEST
DESCRIPTOR.message_types_by_name['StandardReply'] = _STANDARDREPLY
DESCRIPTOR.message_types_by_name['DACOffRequest'] = _DACOFFREQUEST
DESCRIPTOR.message_types_by_name['WorkspaceDescriptor'] = _WORKSPACEDESCRIPTOR
DESCRIPTOR.message_types_by_name['WorkspaceControlRequest'] = _WORKSPACECONTROLREQUEST
DESCRIPTOR.message_types_by_name['GetWorkspaceRequest'] = _GETWORKSPACEREQUEST
DESCRIPTOR.message_types_by_name['GetWorkspaceReply'] = _GETWORKSPACEREPLY
DESCRIPTOR.message_types_by_name['GetRadiensServersRequest'] = _GETRADIENSSERVERSREQUEST
DESCRIPTOR.message_types_by_name['ServerSpec'] = _SERVERSPEC
DESCRIPTOR.message_types_by_name['RadiensServersReply'] = _RADIENSSERVERSREPLY
DESCRIPTOR.message_types_by_name['SignalGroupIDRequest'] = _SIGNALGROUPIDREQUEST
DESCRIPTOR.message_types_by_name['SignalMap'] = _SIGNALMAP
DESCRIPTOR.message_types_by_name['GPIOChannelCount'] = _GPIOCHANNELCOUNT
DESCRIPTOR.message_types_by_name['PortChannelCount'] = _PORTCHANNELCOUNT
DESCRIPTOR.message_types_by_name['SetPortRequest'] = _SETPORTREQUEST
DESCRIPTOR.message_types_by_name['HDSnapshotRequest'] = _HDSNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name['HDSnapshotMeta'] = _HDSNAPSHOTMETA
DESCRIPTOR.message_types_by_name['HDSnapshot'] = _HDSNAPSHOT
DESCRIPTOR.message_types_by_name['GetSignalsRequest'] = _GETSIGNALSREQUEST
DESCRIPTOR.message_types_by_name['RawSignals'] = _RAWSIGNALS
DESCRIPTOR.message_types_by_name['ListSensorSpecsReply'] = _LISTSENSORSPECSREPLY
DESCRIPTOR.message_types_by_name['ListDataSourcesRequest'] = _LISTDATASOURCESREQUEST
DESCRIPTOR.message_types_by_name['GetSignalGroupIDsReply'] = _GETSIGNALGROUPIDSREPLY
DESCRIPTOR.message_types_by_name['DataSource'] = _DATASOURCE
DESCRIPTOR.message_types_by_name['FileDescriptor'] = _FILEDESCRIPTOR
DESCRIPTOR.message_types_by_name['TimeSpec'] = _TIMESPEC
DESCRIPTOR.message_types_by_name['SignalSpec'] = _SIGNALSPEC
DESCRIPTOR.message_types_by_name['ChannelRecord'] = _CHANNELRECORD
DESCRIPTOR.message_types_by_name['XYCoord'] = _XYCOORD
DESCRIPTOR.message_types_by_name['XYZCoord'] = _XYZCOORD
DESCRIPTOR.message_types_by_name['Sensor'] = _SENSOR
DESCRIPTOR.message_types_by_name['SensorPortSpec'] = _SENSORPORTSPEC
DESCRIPTOR.message_types_by_name['SignalGroupUnits'] = _SIGNALGROUPUNITS
DESCRIPTOR.message_types_by_name['SignalGroup'] = _SIGNALGROUP
DESCRIPTOR.message_types_by_name['CreateSignalGroupRequest'] = _CREATESIGNALGROUPREQUEST
DESCRIPTOR.message_types_by_name['SubOpSort'] = _SUBOPSORT
DESCRIPTOR.message_types_by_name['UpdateSignalGroupRequest'] = _UPDATESIGNALGROUPREQUEST
DESCRIPTOR.message_types_by_name['LicenseStatus'] = _LICENSESTATUS
DESCRIPTOR.message_types_by_name['SetDSPGroupRequest'] = _SETDSPGROUPREQUEST
DESCRIPTOR.message_types_by_name['DSPParams'] = _DSPPARAMS
DESCRIPTOR.message_types_by_name['DSPGroup'] = _DSPGROUP
DESCRIPTOR.message_types_by_name['SetSensorRequest'] = _SETSENSORREQUEST
DESCRIPTOR.message_types_by_name['SensorPositionTcs'] = _SENSORPOSITIONTCS
DESCRIPTOR.message_types_by_name['SetSensorPositionTcsRequest'] = _SETSENSORPOSITIONTCSREQUEST
DESCRIPTOR.message_types_by_name['SitePositionTcs'] = _SITEPOSITIONTCS
DESCRIPTOR.message_types_by_name['SetSitePositionsTcsRequest'] = _SETSITEPOSITIONSTCSREQUEST
DESCRIPTOR.message_types_by_name['FeatureStartStopRequest'] = _FEATURESTARTSTOPREQUEST
DESCRIPTOR.message_types_by_name['PrivacyReply'] = _PRIVACYREPLY
DESCRIPTOR.message_types_by_name['SetPrivacyRequest'] = _SETPRIVACYREQUEST
DESCRIPTOR.message_types_by_name['DenseMatrix'] = _DENSEMATRIX
DESCRIPTOR.message_types_by_name['KpiMetricID'] = _KPIMETRICID
DESCRIPTOR.message_types_by_name['TimeRange'] = _TIMERANGE
DESCRIPTOR.message_types_by_name['BundleReq'] = _BUNDLEREQ
DESCRIPTOR.message_types_by_name['KpiMetricsReq'] = _KPIMETRICSREQ
DESCRIPTOR.message_types_by_name['KpiMetricsData'] = _KPIMETRICSDATA
DESCRIPTOR.message_types_by_name['KpiBundlePacketMetrics'] = _KPIBUNDLEPACKETMETRICS
DESCRIPTOR.message_types_by_name['KpiMetrics'] = _KPIMETRICS
DESCRIPTOR.message_types_by_name['KpiControlRequest'] = _KPICONTROLREQUEST
DESCRIPTOR.message_types_by_name['SetKpiUpdatePeriodRequest'] = _SETKPIUPDATEPERIODREQUEST
DESCRIPTOR.message_types_by_name['SetKpiThresholdRequest'] = _SETKPITHRESHOLDREQUEST
DESCRIPTOR.message_types_by_name['SetKpiEventDetectRequest'] = _SETKPIEVENTDETECTREQUEST
DESCRIPTOR.message_types_by_name['SetKpiEventShadowRequest'] = _SETKPIEVENTSHADOWREQUEST
DESCRIPTOR.message_types_by_name['SetKpiEventWindowRequest'] = _SETKPIEVENTWINDOWREQUEST
DESCRIPTOR.message_types_by_name['GetKpiStatusRequest'] = _GETKPISTATUSREQUEST
DESCRIPTOR.message_types_by_name['KpiStatusReply'] = _KPISTATUSREPLY
DESCRIPTOR.message_types_by_name['SigKpiParamRecord'] = _SIGKPIPARAMRECORD
DESCRIPTOR.message_types_by_name['AnnotateBundle'] = _ANNOTATEBUNDLE
DESCRIPTOR.message_types_by_name['ProjectMetadata'] = _PROJECTMETADATA
DESCRIPTOR.message_types_by_name['SensorExtendedMetadata'] = _SENSOREXTENDEDMETADATA
DESCRIPTOR.message_types_by_name['GonumMatrixList'] = _GONUMMATRIXLIST
DESCRIPTOR.message_types_by_name['RadixMatrixList'] = _RADIXMATRIXLIST
DESCRIPTOR.message_types_by_name['RadixMatrix'] = _RADIXMATRIX
DESCRIPTOR.message_types_by_name['RadixSignalsList'] = _RADIXSIGNALSLIST
DESCRIPTOR.message_types_by_name['RadixSignals'] = _RADIXSIGNALS
DESCRIPTOR.message_types_by_name['VectorString'] = _VECTORSTRING
DESCRIPTOR.message_types_by_name['VectorFloat64'] = _VECTORFLOAT64
DESCRIPTOR.message_types_by_name['VectorSliceFloat64'] = _VECTORSLICEFLOAT64
DESCRIPTOR.message_types_by_name['LogsysKpiStatusReply'] = _LOGSYSKPISTATUSREPLY
DESCRIPTOR.message_types_by_name['KpiCache'] = _KPICACHE
DESCRIPTOR.message_types_by_name['LogsysKpiTailReply'] = _LOGSYSKPITAILREPLY
DESCRIPTOR.message_types_by_name['KpiPortInfo'] = _KPIPORTINFO
DESCRIPTOR.message_types_by_name['KpiTailRows'] = _KPITAILROWS
DESCRIPTOR.message_types_by_name['WarehouseHealthcheckSpec'] = _WAREHOUSEHEALTHCHECKSPEC
DESCRIPTOR.message_types_by_name['OutfitterGetDeviceRequest'] = _OUTFITTERGETDEVICEREQUEST
DESCRIPTOR.message_types_by_name['SensorCompRequest'] = _SENSORCOMPREQUEST
DESCRIPTOR.message_types_by_name['RegisterSensorCompRequest'] = _REGISTERSENSORCOMPREQUEST
DESCRIPTOR.message_types_by_name['SaveSensorCompInstanceRequest'] = _SAVESENSORCOMPINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ProbeDesc'] = _PROBEDESC
DESCRIPTOR.message_types_by_name['HeadstageDesc'] = _HEADSTAGEDESC
DESCRIPTOR.message_types_by_name['GetSensorCompReply'] = _GETSENSORCOMPREPLY
DESCRIPTOR.message_types_by_name['ProbeSpec'] = _PROBESPEC
DESCRIPTOR.message_types_by_name['HeadstageSpec'] = _HEADSTAGESPEC
DESCRIPTOR.message_types_by_name['ProbeModel'] = _PROBEMODEL
DESCRIPTOR.message_types_by_name['ProbeMetaData'] = _PROBEMETADATA
DESCRIPTOR.message_types_by_name['HeadstageModel'] = _HEADSTAGEMODEL
DESCRIPTOR.message_types_by_name['HeadstageMetaData'] = _HEADSTAGEMETADATA
DESCRIPTOR.message_types_by_name['UserProfile'] = _USERPROFILE
DESCRIPTOR.message_types_by_name['GetCurrentProfileReply'] = _GETCURRENTPROFILEREPLY
DESCRIPTOR.message_types_by_name['GetAllProfilesReply'] = _GETALLPROFILESREPLY
DESCRIPTOR.message_types_by_name['SetCurrentProfileRequest'] = _SETCURRENTPROFILEREQUEST
DESCRIPTOR.message_types_by_name['ManageNodeOrgPayload'] = _MANAGENODEORGPAYLOAD
DESCRIPTOR.message_types_by_name['ManageNodeOrgRequest'] = _MANAGENODEORGREQUEST
DESCRIPTOR.message_types_by_name['ManageNodeOrgReply'] = _MANAGENODEORGREPLY
DESCRIPTOR.message_types_by_name['ManageNodeLabPayload'] = _MANAGENODELABPAYLOAD
DESCRIPTOR.message_types_by_name['ManageNodeLabRequest'] = _MANAGENODELABREQUEST
DESCRIPTOR.message_types_by_name['ManageNodeLabReply'] = _MANAGENODELABREPLY
DESCRIPTOR.message_types_by_name['ManageNodeUserPayload'] = _MANAGENODEUSERPAYLOAD
DESCRIPTOR.message_types_by_name['ManageNodeUserRequest'] = _MANAGENODEUSERREQUEST
DESCRIPTOR.message_types_by_name['ManageNodeUserReply'] = _MANAGENODEUSERREPLY
DESCRIPTOR.message_types_by_name['CatalogProbePayload'] = _CATALOGPROBEPAYLOAD
DESCRIPTOR.message_types_by_name['ProbeNodeRequest'] = _PROBENODEREQUEST
DESCRIPTOR.message_types_by_name['ProbeNodeReply'] = _PROBENODEREPLY
DESCRIPTOR.message_types_by_name['ProbePayload'] = _PROBEPAYLOAD
DESCRIPTOR.message_types_by_name['EdgePayload'] = _EDGEPAYLOAD
DESCRIPTOR.message_types_by_name['WorldEdgeRequest'] = _WORLDEDGEREQUEST
DESCRIPTOR.message_types_by_name['WorldEdgeReply'] = _WORLDEDGEREPLY
DESCRIPTOR.message_types_by_name['QueryWorldRequest'] = _QUERYWORLDREQUEST
DESCRIPTOR.message_types_by_name['QueryWorldRec'] = _QUERYWORLDREC
DESCRIPTOR.message_types_by_name['QueryWorldReply'] = _QUERYWORLDREPLY
DESCRIPTOR.message_types_by_name['HighLowPassTransformParams'] = _HIGHLOWPASSTRANSFORMPARAMS
DESCRIPTOR.message_types_by_name['BandTransformParams'] = _BANDTRANSFORMPARAMS
DESCRIPTOR.message_types_by_name['NotchTransformParams'] = _NOTCHTRANSFORMPARAMS
DESCRIPTOR.message_types_by_name['CARTransformParams'] = _CARTRANSFORMPARAMS
DESCRIPTOR.message_types_by_name['VirtualRefTransformParams'] = _VIRTUALREFTRANSFORMPARAMS
DESCRIPTOR.message_types_by_name['PairedRefTransformParams'] = _PAIREDREFTRANSFORMPARAMS
DESCRIPTOR.message_types_by_name['DataSourceSinkTransformParams'] = _DATASOURCESINKTRANSFORMPARAMS
DESCRIPTOR.message_types_by_name['SliceTimeTransformParams'] = _SLICETIMETRANSFORMPARAMS
DESCRIPTOR.message_types_by_name['SliceChannelsTransformParams'] = _SLICECHANNELSTRANSFORMPARAMS
DESCRIPTOR.message_types_by_name['DownsampleTransformParams'] = _DOWNSAMPLETRANSFORMPARAMS
DESCRIPTOR.message_types_by_name['Position'] = _POSITION
DESCRIPTOR.message_types_by_name['TransformNode'] = _TRANSFORMNODE
DESCRIPTOR.message_types_by_name['TransformEdge'] = _TRANSFORMEDGE
DESCRIPTOR.message_types_by_name['Protocol'] = _PROTOCOL
DESCRIPTOR.message_types_by_name['ProtocolRequest'] = _PROTOCOLREQUEST
DESCRIPTOR.message_types_by_name['RenameProtocolRequest'] = _RENAMEPROTOCOLREQUEST
DESCRIPTOR.message_types_by_name['GetAllProtocolsReply'] = _GETALLPROTOCOLSREPLY
DESCRIPTOR.message_types_by_name['ApplyProtocolProgress'] = _APPLYPROTOCOLPROGRESS
DESCRIPTOR.message_types_by_name['SpikeSorterSetParamRequest'] = _SPIKESORTERSETPARAMREQUEST
DESCRIPTOR.message_types_by_name['SpikeSorterSetParamsRequest'] = _SPIKESORTERSETPARAMSREQUEST
DESCRIPTOR.message_types_by_name['SpikeSorterParamCommandRecord'] = _SPIKESORTERPARAMCOMMANDRECORD
DESCRIPTOR.message_types_by_name['WrangleRequest'] = _WRANGLEREQUEST
DESCRIPTOR.message_types_by_name['WrangleSpec'] = _WRANGLESPEC
DESCRIPTOR.message_types_by_name['WrangleImport'] = _WRANGLEIMPORT
DESCRIPTOR.message_types_by_name['WrangleImportVexSpikesSim'] = _WRANGLEIMPORTVEXSPIKESSIM
DESCRIPTOR.message_types_by_name['WrangleFileDesc'] = _WRANGLEFILEDESC
DESCRIPTOR.message_types_by_name['WrangleMerge'] = _WRANGLEMERGE
DESCRIPTOR.message_types_by_name['WrangleMergeVexSpikesView'] = _WRANGLEMERGEVEXSPIKESVIEW
DESCRIPTOR.message_types_by_name['WrangleMergeVexSpikesViewSpec'] = _WRANGLEMERGEVEXSPIKESVIEWSPEC
DESCRIPTOR.message_types_by_name['DACStreamRequest'] = _DACSTREAMREQUEST
DESCRIPTOR.message_types_by_name['EventViewerConfig'] = _EVENTVIEWERCONFIG
DESCRIPTOR.message_types_by_name['EventViewerID'] = _EVENTVIEWERID
DESCRIPTOR.message_types_by_name['GetEventViewerEventRequest'] = _GETEVENTVIEWEREVENTREQUEST
DESCRIPTOR.message_types_by_name['EventViewerEventDesc'] = _EVENTVIEWEREVENTDESC
DESCRIPTOR.message_types_by_name['EventViewerEvent'] = _EVENTVIEWEREVENT
DESCRIPTOR.message_types_by_name['ListEventViewerEventsReply'] = _LISTEVENTVIEWEREVENTSREPLY
DESCRIPTOR.message_types_by_name['ListEventViewersReply'] = _LISTEVENTVIEWERSREPLY
DESCRIPTOR.message_types_by_name['StatusPollFieldsToUpdateRequest'] = _STATUSPOLLFIELDSTOUPDATEREQUEST
DESCRIPTOR.message_types_by_name['StatusPollFieldsToUpdate'] = _STATUSPOLLFIELDSTOUPDATE
DESCRIPTOR.enum_types_by_name['RadixFileTypes'] = _RADIXFILETYPES
DESCRIPTOR.enum_types_by_name['SignalType'] = _SIGNALTYPE
DESCRIPTOR.enum_types_by_name['ResampleRoutine'] = _RESAMPLEROUTINE
DESCRIPTOR.enum_types_by_name['Port'] = _PORT
DESCRIPTOR.enum_types_by_name['WorkspaceApp'] = _WORKSPACEAPP
DESCRIPTOR.enum_types_by_name['WorkspaceCommands'] = _WORKSPACECOMMANDS
DESCRIPTOR.enum_types_by_name['GetWorkspaceCommands'] = _GETWORKSPACECOMMANDS
DESCRIPTOR.enum_types_by_name['RadiensServerType'] = _RADIENSSERVERTYPE
DESCRIPTOR.enum_types_by_name['GrpcServiceType'] = _GRPCSERVICETYPE
DESCRIPTOR.enum_types_by_name['DevDatasetType'] = _DEVDATASETTYPE
DESCRIPTOR.enum_types_by_name['DataSourceSort'] = _DATASOURCESORT
DESCRIPTOR.enum_types_by_name['SignalGroupType'] = _SIGNALGROUPTYPE
DESCRIPTOR.enum_types_by_name['DSPType'] = _DSPTYPE
DESCRIPTOR.enum_types_by_name['FilterStage'] = _FILTERSTAGE
DESCRIPTOR.enum_types_by_name['FeatureLicense'] = _FEATURELICENSE
DESCRIPTOR.enum_types_by_name['KpiMetricsMode'] = _KPIMETRICSMODE
DESCRIPTOR.enum_types_by_name['KpiMetricsEnum'] = _KPIMETRICSENUM
DESCRIPTOR.enum_types_by_name['KpiMetricsStatsEnum'] = _KPIMETRICSSTATSENUM
DESCRIPTOR.enum_types_by_name['KpiBundlePacketsStatsEnum'] = _KPIBUNDLEPACKETSSTATSENUM
DESCRIPTOR.enum_types_by_name['KpiBundleName'] = _KPIBUNDLENAME
DESCRIPTOR.enum_types_by_name['TimeRangeSelMode'] = _TIMERANGESELMODE
DESCRIPTOR.enum_types_by_name['KpiThresholdName'] = _KPITHRESHOLDNAME
DESCRIPTOR.enum_types_by_name['KpiWindowdName'] = _KPIWINDOWDNAME
DESCRIPTOR.enum_types_by_name['OutfitterComponentType'] = _OUTFITTERCOMPONENTTYPE
DESCRIPTOR.enum_types_by_name['WorldNodeLabel'] = _WORLDNODELABEL
DESCRIPTOR.enum_types_by_name['WorldEdgeLabel'] = _WORLDEDGELABEL
DESCRIPTOR.enum_types_by_name['WorldEdgeDirection'] = _WORLDEDGEDIRECTION
DESCRIPTOR.enum_types_by_name['UserRoleType'] = _USERROLETYPE
DESCRIPTOR.enum_types_by_name['ManageNodeCmd'] = _MANAGENODECMD
DESCRIPTOR.enum_types_by_name['WorldQueryCmd'] = _WORLDQUERYCMD
DESCRIPTOR.enum_types_by_name['TransformNodeType'] = _TRANSFORMNODETYPE
DESCRIPTOR.enum_types_by_name['SpikeSorterParamCommand'] = _SPIKESORTERPARAMCOMMAND
DESCRIPTOR.enum_types_by_name['WrangleMode'] = _WRANGLEMODE
DESCRIPTOR.enum_types_by_name['StatusPollFields'] = _STATUSPOLLFIELDS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RadixEnvironment = _reflection.GeneratedProtocolMessageType('RadixEnvironment', (_message.Message,), {
  'DESCRIPTOR' : _RADIXENVIRONMENT,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.RadixEnvironment)
  })
_sym_db.RegisterMessage(RadixEnvironment)

StandardRequest = _reflection.GeneratedProtocolMessageType('StandardRequest', (_message.Message,), {
  'DESCRIPTOR' : _STANDARDREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.StandardRequest)
  })
_sym_db.RegisterMessage(StandardRequest)

StandardReply = _reflection.GeneratedProtocolMessageType('StandardReply', (_message.Message,), {
  'DESCRIPTOR' : _STANDARDREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.StandardReply)
  })
_sym_db.RegisterMessage(StandardReply)

DACOffRequest = _reflection.GeneratedProtocolMessageType('DACOffRequest', (_message.Message,), {
  'DESCRIPTOR' : _DACOFFREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.DACOffRequest)
  })
_sym_db.RegisterMessage(DACOffRequest)

WorkspaceDescriptor = _reflection.GeneratedProtocolMessageType('WorkspaceDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEDESCRIPTOR,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WorkspaceDescriptor)
  })
_sym_db.RegisterMessage(WorkspaceDescriptor)

WorkspaceControlRequest = _reflection.GeneratedProtocolMessageType('WorkspaceControlRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACECONTROLREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WorkspaceControlRequest)
  })
_sym_db.RegisterMessage(WorkspaceControlRequest)

GetWorkspaceRequest = _reflection.GeneratedProtocolMessageType('GetWorkspaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKSPACEREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetWorkspaceRequest)
  })
_sym_db.RegisterMessage(GetWorkspaceRequest)

GetWorkspaceReply = _reflection.GeneratedProtocolMessageType('GetWorkspaceReply', (_message.Message,), {

  'WorkspaceDescEntry' : _reflection.GeneratedProtocolMessageType('WorkspaceDescEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETWORKSPACEREPLY_WORKSPACEDESCENTRY,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.GetWorkspaceReply.WorkspaceDescEntry)
    })
  ,
  'DESCRIPTOR' : _GETWORKSPACEREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetWorkspaceReply)
  })
_sym_db.RegisterMessage(GetWorkspaceReply)
_sym_db.RegisterMessage(GetWorkspaceReply.WorkspaceDescEntry)

GetRadiensServersRequest = _reflection.GeneratedProtocolMessageType('GetRadiensServersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRADIENSSERVERSREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetRadiensServersRequest)
  })
_sym_db.RegisterMessage(GetRadiensServersRequest)

ServerSpec = _reflection.GeneratedProtocolMessageType('ServerSpec', (_message.Message,), {

  'GrpcService' : _reflection.GeneratedProtocolMessageType('GrpcService', (_message.Message,), {
    'DESCRIPTOR' : _SERVERSPEC_GRPCSERVICE,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.ServerSpec.GrpcService)
    })
  ,

  'SpawnedProcess' : _reflection.GeneratedProtocolMessageType('SpawnedProcess', (_message.Message,), {
    'DESCRIPTOR' : _SERVERSPEC_SPAWNEDPROCESS,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.ServerSpec.SpawnedProcess)
    })
  ,

  'ServiceEntry' : _reflection.GeneratedProtocolMessageType('ServiceEntry', (_message.Message,), {
    'DESCRIPTOR' : _SERVERSPEC_SERVICEENTRY,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.ServerSpec.ServiceEntry)
    })
  ,
  'DESCRIPTOR' : _SERVERSPEC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ServerSpec)
  })
_sym_db.RegisterMessage(ServerSpec)
_sym_db.RegisterMessage(ServerSpec.GrpcService)
_sym_db.RegisterMessage(ServerSpec.SpawnedProcess)
_sym_db.RegisterMessage(ServerSpec.ServiceEntry)

RadiensServersReply = _reflection.GeneratedProtocolMessageType('RadiensServersReply', (_message.Message,), {
  'DESCRIPTOR' : _RADIENSSERVERSREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.RadiensServersReply)
  })
_sym_db.RegisterMessage(RadiensServersReply)

SignalGroupIDRequest = _reflection.GeneratedProtocolMessageType('SignalGroupIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALGROUPIDREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SignalGroupIDRequest)
  })
_sym_db.RegisterMessage(SignalGroupIDRequest)

SignalMap = _reflection.GeneratedProtocolMessageType('SignalMap', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALMAP,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SignalMap)
  })
_sym_db.RegisterMessage(SignalMap)

GPIOChannelCount = _reflection.GeneratedProtocolMessageType('GPIOChannelCount', (_message.Message,), {
  'DESCRIPTOR' : _GPIOCHANNELCOUNT,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GPIOChannelCount)
  })
_sym_db.RegisterMessage(GPIOChannelCount)

PortChannelCount = _reflection.GeneratedProtocolMessageType('PortChannelCount', (_message.Message,), {
  'DESCRIPTOR' : _PORTCHANNELCOUNT,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.PortChannelCount)
  })
_sym_db.RegisterMessage(PortChannelCount)

SetPortRequest = _reflection.GeneratedProtocolMessageType('SetPortRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPORTREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetPortRequest)
  })
_sym_db.RegisterMessage(SetPortRequest)

HDSnapshotRequest = _reflection.GeneratedProtocolMessageType('HDSnapshotRequest', (_message.Message,), {

  'SelectedSignals' : _reflection.GeneratedProtocolMessageType('SelectedSignals', (_message.Message,), {
    'DESCRIPTOR' : _HDSNAPSHOTREQUEST_SELECTEDSIGNALS,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.HDSnapshotRequest.SelectedSignals)
    })
  ,
  'DESCRIPTOR' : _HDSNAPSHOTREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.HDSnapshotRequest)
  })
_sym_db.RegisterMessage(HDSnapshotRequest)
_sym_db.RegisterMessage(HDSnapshotRequest.SelectedSignals)

HDSnapshotMeta = _reflection.GeneratedProtocolMessageType('HDSnapshotMeta', (_message.Message,), {
  'DESCRIPTOR' : _HDSNAPSHOTMETA,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.HDSnapshotMeta)
  })
_sym_db.RegisterMessage(HDSnapshotMeta)

HDSnapshot = _reflection.GeneratedProtocolMessageType('HDSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _HDSNAPSHOT,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.HDSnapshot)
  })
_sym_db.RegisterMessage(HDSnapshot)

GetSignalsRequest = _reflection.GeneratedProtocolMessageType('GetSignalsRequest', (_message.Message,), {

  'GetSigsParams' : _reflection.GeneratedProtocolMessageType('GetSigsParams', (_message.Message,), {
    'DESCRIPTOR' : _GETSIGNALSREQUEST_GETSIGSPARAMS,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.GetSignalsRequest.GetSigsParams)
    })
  ,
  'DESCRIPTOR' : _GETSIGNALSREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetSignalsRequest)
  })
_sym_db.RegisterMessage(GetSignalsRequest)
_sym_db.RegisterMessage(GetSignalsRequest.GetSigsParams)

RawSignals = _reflection.GeneratedProtocolMessageType('RawSignals', (_message.Message,), {
  'DESCRIPTOR' : _RAWSIGNALS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.RawSignals)
  })
_sym_db.RegisterMessage(RawSignals)

ListSensorSpecsReply = _reflection.GeneratedProtocolMessageType('ListSensorSpecsReply', (_message.Message,), {

  'SpecWithChannelCount' : _reflection.GeneratedProtocolMessageType('SpecWithChannelCount', (_message.Message,), {
    'DESCRIPTOR' : _LISTSENSORSPECSREPLY_SPECWITHCHANNELCOUNT,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.ListSensorSpecsReply.SpecWithChannelCount)
    })
  ,
  'DESCRIPTOR' : _LISTSENSORSPECSREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ListSensorSpecsReply)
  })
_sym_db.RegisterMessage(ListSensorSpecsReply)
_sym_db.RegisterMessage(ListSensorSpecsReply.SpecWithChannelCount)

ListDataSourcesRequest = _reflection.GeneratedProtocolMessageType('ListDataSourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ListDataSourcesRequest)
  })
_sym_db.RegisterMessage(ListDataSourcesRequest)

GetSignalGroupIDsReply = _reflection.GeneratedProtocolMessageType('GetSignalGroupIDsReply', (_message.Message,), {
  'DESCRIPTOR' : _GETSIGNALGROUPIDSREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetSignalGroupIDsReply)
  })
_sym_db.RegisterMessage(GetSignalGroupIDsReply)

DataSource = _reflection.GeneratedProtocolMessageType('DataSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCE,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSource)
  })
_sym_db.RegisterMessage(DataSource)

FileDescriptor = _reflection.GeneratedProtocolMessageType('FileDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _FILEDESCRIPTOR,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.FileDescriptor)
  })
_sym_db.RegisterMessage(FileDescriptor)

TimeSpec = _reflection.GeneratedProtocolMessageType('TimeSpec', (_message.Message,), {

  'TimeRangeL' : _reflection.GeneratedProtocolMessageType('TimeRangeL', (_message.Message,), {
    'DESCRIPTOR' : _TIMESPEC_TIMERANGEL,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.TimeSpec.TimeRangeL)
    })
  ,

  'TimestampRangeL' : _reflection.GeneratedProtocolMessageType('TimestampRangeL', (_message.Message,), {
    'DESCRIPTOR' : _TIMESPEC_TIMESTAMPRANGEL,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.TimeSpec.TimestampRangeL)
    })
  ,
  'DESCRIPTOR' : _TIMESPEC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.TimeSpec)
  })
_sym_db.RegisterMessage(TimeSpec)
_sym_db.RegisterMessage(TimeSpec.TimeRangeL)
_sym_db.RegisterMessage(TimeSpec.TimestampRangeL)

SignalSpec = _reflection.GeneratedProtocolMessageType('SignalSpec', (_message.Message,), {

  'SiteNumL' : _reflection.GeneratedProtocolMessageType('SiteNumL', (_message.Message,), {
    'DESCRIPTOR' : _SIGNALSPEC_SITENUML,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.SignalSpec.SiteNumL)
    })
  ,

  'NtvChanIdxL' : _reflection.GeneratedProtocolMessageType('NtvChanIdxL', (_message.Message,), {
    'DESCRIPTOR' : _SIGNALSPEC_NTVCHANIDXL,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.SignalSpec.NtvChanIdxL)
    })
  ,
  'DESCRIPTOR' : _SIGNALSPEC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SignalSpec)
  })
_sym_db.RegisterMessage(SignalSpec)
_sym_db.RegisterMessage(SignalSpec.SiteNumL)
_sym_db.RegisterMessage(SignalSpec.NtvChanIdxL)

ChannelRecord = _reflection.GeneratedProtocolMessageType('ChannelRecord', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELRECORD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ChannelRecord)
  })
_sym_db.RegisterMessage(ChannelRecord)

XYCoord = _reflection.GeneratedProtocolMessageType('XYCoord', (_message.Message,), {
  'DESCRIPTOR' : _XYCOORD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.XYCoord)
  })
_sym_db.RegisterMessage(XYCoord)

XYZCoord = _reflection.GeneratedProtocolMessageType('XYZCoord', (_message.Message,), {
  'DESCRIPTOR' : _XYZCOORD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.XYZCoord)
  })
_sym_db.RegisterMessage(XYZCoord)

Sensor = _reflection.GeneratedProtocolMessageType('Sensor', (_message.Message,), {

  'WireFrame' : _reflection.GeneratedProtocolMessageType('WireFrame', (_message.Message,), {
    'DESCRIPTOR' : _SENSOR_WIREFRAME,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.Sensor.WireFrame)
    })
  ,
  'DESCRIPTOR' : _SENSOR,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.Sensor)
  })
_sym_db.RegisterMessage(Sensor)
_sym_db.RegisterMessage(Sensor.WireFrame)

SensorPortSpec = _reflection.GeneratedProtocolMessageType('SensorPortSpec', (_message.Message,), {
  'DESCRIPTOR' : _SENSORPORTSPEC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SensorPortSpec)
  })
_sym_db.RegisterMessage(SensorPortSpec)

SignalGroupUnits = _reflection.GeneratedProtocolMessageType('SignalGroupUnits', (_message.Message,), {

  'UnitsEntry' : _reflection.GeneratedProtocolMessageType('UnitsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SIGNALGROUPUNITS_UNITSENTRY,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.SignalGroupUnits.UnitsEntry)
    })
  ,
  'DESCRIPTOR' : _SIGNALGROUPUNITS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SignalGroupUnits)
  })
_sym_db.RegisterMessage(SignalGroupUnits)
_sym_db.RegisterMessage(SignalGroupUnits.UnitsEntry)

SignalGroup = _reflection.GeneratedProtocolMessageType('SignalGroup', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALGROUP,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SignalGroup)
  })
_sym_db.RegisterMessage(SignalGroup)

CreateSignalGroupRequest = _reflection.GeneratedProtocolMessageType('CreateSignalGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESIGNALGROUPREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.CreateSignalGroupRequest)
  })
_sym_db.RegisterMessage(CreateSignalGroupRequest)

SubOpSort = _reflection.GeneratedProtocolMessageType('SubOpSort', (_message.Message,), {
  'DESCRIPTOR' : _SUBOPSORT,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SubOpSort)
  })
_sym_db.RegisterMessage(SubOpSort)

UpdateSignalGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateSignalGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESIGNALGROUPREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.UpdateSignalGroupRequest)
  })
_sym_db.RegisterMessage(UpdateSignalGroupRequest)

LicenseStatus = _reflection.GeneratedProtocolMessageType('LicenseStatus', (_message.Message,), {
  'DESCRIPTOR' : _LICENSESTATUS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.LicenseStatus)
  })
_sym_db.RegisterMessage(LicenseStatus)

SetDSPGroupRequest = _reflection.GeneratedProtocolMessageType('SetDSPGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDSPGROUPREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetDSPGroupRequest)
  })
_sym_db.RegisterMessage(SetDSPGroupRequest)

DSPParams = _reflection.GeneratedProtocolMessageType('DSPParams', (_message.Message,), {

  'FreqSpecBand' : _reflection.GeneratedProtocolMessageType('FreqSpecBand', (_message.Message,), {
    'DESCRIPTOR' : _DSPPARAMS_FREQSPECBAND,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.DSPParams.FreqSpecBand)
    })
  ,
  'DESCRIPTOR' : _DSPPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.DSPParams)
  })
_sym_db.RegisterMessage(DSPParams)
_sym_db.RegisterMessage(DSPParams.FreqSpecBand)

DSPGroup = _reflection.GeneratedProtocolMessageType('DSPGroup', (_message.Message,), {
  'DESCRIPTOR' : _DSPGROUP,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.DSPGroup)
  })
_sym_db.RegisterMessage(DSPGroup)

SetSensorRequest = _reflection.GeneratedProtocolMessageType('SetSensorRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSENSORREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetSensorRequest)
  })
_sym_db.RegisterMessage(SetSensorRequest)

SensorPositionTcs = _reflection.GeneratedProtocolMessageType('SensorPositionTcs', (_message.Message,), {
  'DESCRIPTOR' : _SENSORPOSITIONTCS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SensorPositionTcs)
  })
_sym_db.RegisterMessage(SensorPositionTcs)

SetSensorPositionTcsRequest = _reflection.GeneratedProtocolMessageType('SetSensorPositionTcsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSENSORPOSITIONTCSREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetSensorPositionTcsRequest)
  })
_sym_db.RegisterMessage(SetSensorPositionTcsRequest)

SitePositionTcs = _reflection.GeneratedProtocolMessageType('SitePositionTcs', (_message.Message,), {
  'DESCRIPTOR' : _SITEPOSITIONTCS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SitePositionTcs)
  })
_sym_db.RegisterMessage(SitePositionTcs)

SetSitePositionsTcsRequest = _reflection.GeneratedProtocolMessageType('SetSitePositionsTcsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSITEPOSITIONSTCSREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetSitePositionsTcsRequest)
  })
_sym_db.RegisterMessage(SetSitePositionsTcsRequest)

FeatureStartStopRequest = _reflection.GeneratedProtocolMessageType('FeatureStartStopRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESTARTSTOPREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.FeatureStartStopRequest)
  })
_sym_db.RegisterMessage(FeatureStartStopRequest)

PrivacyReply = _reflection.GeneratedProtocolMessageType('PrivacyReply', (_message.Message,), {
  'DESCRIPTOR' : _PRIVACYREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.PrivacyReply)
  })
_sym_db.RegisterMessage(PrivacyReply)

SetPrivacyRequest = _reflection.GeneratedProtocolMessageType('SetPrivacyRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPRIVACYREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetPrivacyRequest)
  })
_sym_db.RegisterMessage(SetPrivacyRequest)

DenseMatrix = _reflection.GeneratedProtocolMessageType('DenseMatrix', (_message.Message,), {
  'DESCRIPTOR' : _DENSEMATRIX,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.DenseMatrix)
  })
_sym_db.RegisterMessage(DenseMatrix)

KpiMetricID = _reflection.GeneratedProtocolMessageType('KpiMetricID', (_message.Message,), {
  'DESCRIPTOR' : _KPIMETRICID,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.KpiMetricID)
  })
_sym_db.RegisterMessage(KpiMetricID)

TimeRange = _reflection.GeneratedProtocolMessageType('TimeRange', (_message.Message,), {
  'DESCRIPTOR' : _TIMERANGE,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.TimeRange)
  })
_sym_db.RegisterMessage(TimeRange)

BundleReq = _reflection.GeneratedProtocolMessageType('BundleReq', (_message.Message,), {
  'DESCRIPTOR' : _BUNDLEREQ,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.BundleReq)
  })
_sym_db.RegisterMessage(BundleReq)

KpiMetricsReq = _reflection.GeneratedProtocolMessageType('KpiMetricsReq', (_message.Message,), {
  'DESCRIPTOR' : _KPIMETRICSREQ,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.KpiMetricsReq)
  })
_sym_db.RegisterMessage(KpiMetricsReq)

KpiMetricsData = _reflection.GeneratedProtocolMessageType('KpiMetricsData', (_message.Message,), {

  'MetricStats' : _reflection.GeneratedProtocolMessageType('MetricStats', (_message.Message,), {
    'DESCRIPTOR' : _KPIMETRICSDATA_METRICSTATS,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.KpiMetricsData.MetricStats)
    })
  ,
  'DESCRIPTOR' : _KPIMETRICSDATA,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.KpiMetricsData)
  })
_sym_db.RegisterMessage(KpiMetricsData)
_sym_db.RegisterMessage(KpiMetricsData.MetricStats)

KpiBundlePacketMetrics = _reflection.GeneratedProtocolMessageType('KpiBundlePacketMetrics', (_message.Message,), {
  'DESCRIPTOR' : _KPIBUNDLEPACKETMETRICS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.KpiBundlePacketMetrics)
  })
_sym_db.RegisterMessage(KpiBundlePacketMetrics)

KpiMetrics = _reflection.GeneratedProtocolMessageType('KpiMetrics', (_message.Message,), {
  'DESCRIPTOR' : _KPIMETRICS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.KpiMetrics)
  })
_sym_db.RegisterMessage(KpiMetrics)

KpiControlRequest = _reflection.GeneratedProtocolMessageType('KpiControlRequest', (_message.Message,), {
  'DESCRIPTOR' : _KPICONTROLREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.KpiControlRequest)
  })
_sym_db.RegisterMessage(KpiControlRequest)

SetKpiUpdatePeriodRequest = _reflection.GeneratedProtocolMessageType('SetKpiUpdatePeriodRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETKPIUPDATEPERIODREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetKpiUpdatePeriodRequest)
  })
_sym_db.RegisterMessage(SetKpiUpdatePeriodRequest)

SetKpiThresholdRequest = _reflection.GeneratedProtocolMessageType('SetKpiThresholdRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETKPITHRESHOLDREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetKpiThresholdRequest)
  })
_sym_db.RegisterMessage(SetKpiThresholdRequest)

SetKpiEventDetectRequest = _reflection.GeneratedProtocolMessageType('SetKpiEventDetectRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETKPIEVENTDETECTREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetKpiEventDetectRequest)
  })
_sym_db.RegisterMessage(SetKpiEventDetectRequest)

SetKpiEventShadowRequest = _reflection.GeneratedProtocolMessageType('SetKpiEventShadowRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETKPIEVENTSHADOWREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetKpiEventShadowRequest)
  })
_sym_db.RegisterMessage(SetKpiEventShadowRequest)

SetKpiEventWindowRequest = _reflection.GeneratedProtocolMessageType('SetKpiEventWindowRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETKPIEVENTWINDOWREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetKpiEventWindowRequest)
  })
_sym_db.RegisterMessage(SetKpiEventWindowRequest)

GetKpiStatusRequest = _reflection.GeneratedProtocolMessageType('GetKpiStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKPISTATUSREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetKpiStatusRequest)
  })
_sym_db.RegisterMessage(GetKpiStatusRequest)

KpiStatusReply = _reflection.GeneratedProtocolMessageType('KpiStatusReply', (_message.Message,), {
  'DESCRIPTOR' : _KPISTATUSREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.KpiStatusReply)
  })
_sym_db.RegisterMessage(KpiStatusReply)

SigKpiParamRecord = _reflection.GeneratedProtocolMessageType('SigKpiParamRecord', (_message.Message,), {
  'DESCRIPTOR' : _SIGKPIPARAMRECORD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SigKpiParamRecord)
  })
_sym_db.RegisterMessage(SigKpiParamRecord)

AnnotateBundle = _reflection.GeneratedProtocolMessageType('AnnotateBundle', (_message.Message,), {
  'DESCRIPTOR' : _ANNOTATEBUNDLE,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.AnnotateBundle)
  })
_sym_db.RegisterMessage(AnnotateBundle)

ProjectMetadata = _reflection.GeneratedProtocolMessageType('ProjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTMETADATA,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ProjectMetadata)
  })
_sym_db.RegisterMessage(ProjectMetadata)

SensorExtendedMetadata = _reflection.GeneratedProtocolMessageType('SensorExtendedMetadata', (_message.Message,), {
  'DESCRIPTOR' : _SENSOREXTENDEDMETADATA,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SensorExtendedMetadata)
  })
_sym_db.RegisterMessage(SensorExtendedMetadata)

GonumMatrixList = _reflection.GeneratedProtocolMessageType('GonumMatrixList', (_message.Message,), {
  'DESCRIPTOR' : _GONUMMATRIXLIST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GonumMatrixList)
  })
_sym_db.RegisterMessage(GonumMatrixList)

RadixMatrixList = _reflection.GeneratedProtocolMessageType('RadixMatrixList', (_message.Message,), {
  'DESCRIPTOR' : _RADIXMATRIXLIST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.RadixMatrixList)
  })
_sym_db.RegisterMessage(RadixMatrixList)

RadixMatrix = _reflection.GeneratedProtocolMessageType('RadixMatrix', (_message.Message,), {
  'DESCRIPTOR' : _RADIXMATRIX,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.RadixMatrix)
  })
_sym_db.RegisterMessage(RadixMatrix)

RadixSignalsList = _reflection.GeneratedProtocolMessageType('RadixSignalsList', (_message.Message,), {
  'DESCRIPTOR' : _RADIXSIGNALSLIST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.RadixSignalsList)
  })
_sym_db.RegisterMessage(RadixSignalsList)

RadixSignals = _reflection.GeneratedProtocolMessageType('RadixSignals', (_message.Message,), {
  'DESCRIPTOR' : _RADIXSIGNALS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.RadixSignals)
  })
_sym_db.RegisterMessage(RadixSignals)

VectorString = _reflection.GeneratedProtocolMessageType('VectorString', (_message.Message,), {
  'DESCRIPTOR' : _VECTORSTRING,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.VectorString)
  })
_sym_db.RegisterMessage(VectorString)

VectorFloat64 = _reflection.GeneratedProtocolMessageType('VectorFloat64', (_message.Message,), {
  'DESCRIPTOR' : _VECTORFLOAT64,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.VectorFloat64)
  })
_sym_db.RegisterMessage(VectorFloat64)

VectorSliceFloat64 = _reflection.GeneratedProtocolMessageType('VectorSliceFloat64', (_message.Message,), {
  'DESCRIPTOR' : _VECTORSLICEFLOAT64,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.VectorSliceFloat64)
  })
_sym_db.RegisterMessage(VectorSliceFloat64)

LogsysKpiStatusReply = _reflection.GeneratedProtocolMessageType('LogsysKpiStatusReply', (_message.Message,), {
  'DESCRIPTOR' : _LOGSYSKPISTATUSREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.LogsysKpiStatusReply)
  })
_sym_db.RegisterMessage(LogsysKpiStatusReply)

KpiCache = _reflection.GeneratedProtocolMessageType('KpiCache', (_message.Message,), {
  'DESCRIPTOR' : _KPICACHE,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.KpiCache)
  })
_sym_db.RegisterMessage(KpiCache)

LogsysKpiTailReply = _reflection.GeneratedProtocolMessageType('LogsysKpiTailReply', (_message.Message,), {
  'DESCRIPTOR' : _LOGSYSKPITAILREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.LogsysKpiTailReply)
  })
_sym_db.RegisterMessage(LogsysKpiTailReply)

KpiPortInfo = _reflection.GeneratedProtocolMessageType('KpiPortInfo', (_message.Message,), {
  'DESCRIPTOR' : _KPIPORTINFO,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.KpiPortInfo)
  })
_sym_db.RegisterMessage(KpiPortInfo)

KpiTailRows = _reflection.GeneratedProtocolMessageType('KpiTailRows', (_message.Message,), {
  'DESCRIPTOR' : _KPITAILROWS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.KpiTailRows)
  })
_sym_db.RegisterMessage(KpiTailRows)

WarehouseHealthcheckSpec = _reflection.GeneratedProtocolMessageType('WarehouseHealthcheckSpec', (_message.Message,), {
  'DESCRIPTOR' : _WAREHOUSEHEALTHCHECKSPEC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WarehouseHealthcheckSpec)
  })
_sym_db.RegisterMessage(WarehouseHealthcheckSpec)

OutfitterGetDeviceRequest = _reflection.GeneratedProtocolMessageType('OutfitterGetDeviceRequest', (_message.Message,), {
  'DESCRIPTOR' : _OUTFITTERGETDEVICEREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.OutfitterGetDeviceRequest)
  })
_sym_db.RegisterMessage(OutfitterGetDeviceRequest)

SensorCompRequest = _reflection.GeneratedProtocolMessageType('SensorCompRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENSORCOMPREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SensorCompRequest)
  })
_sym_db.RegisterMessage(SensorCompRequest)

RegisterSensorCompRequest = _reflection.GeneratedProtocolMessageType('RegisterSensorCompRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERSENSORCOMPREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.RegisterSensorCompRequest)
  })
_sym_db.RegisterMessage(RegisterSensorCompRequest)

SaveSensorCompInstanceRequest = _reflection.GeneratedProtocolMessageType('SaveSensorCompInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVESENSORCOMPINSTANCEREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SaveSensorCompInstanceRequest)
  })
_sym_db.RegisterMessage(SaveSensorCompInstanceRequest)

ProbeDesc = _reflection.GeneratedProtocolMessageType('ProbeDesc', (_message.Message,), {
  'DESCRIPTOR' : _PROBEDESC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ProbeDesc)
  })
_sym_db.RegisterMessage(ProbeDesc)

HeadstageDesc = _reflection.GeneratedProtocolMessageType('HeadstageDesc', (_message.Message,), {
  'DESCRIPTOR' : _HEADSTAGEDESC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.HeadstageDesc)
  })
_sym_db.RegisterMessage(HeadstageDesc)

GetSensorCompReply = _reflection.GeneratedProtocolMessageType('GetSensorCompReply', (_message.Message,), {
  'DESCRIPTOR' : _GETSENSORCOMPREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetSensorCompReply)
  })
_sym_db.RegisterMessage(GetSensorCompReply)

ProbeSpec = _reflection.GeneratedProtocolMessageType('ProbeSpec', (_message.Message,), {
  'DESCRIPTOR' : _PROBESPEC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ProbeSpec)
  })
_sym_db.RegisterMessage(ProbeSpec)

HeadstageSpec = _reflection.GeneratedProtocolMessageType('HeadstageSpec', (_message.Message,), {
  'DESCRIPTOR' : _HEADSTAGESPEC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.HeadstageSpec)
  })
_sym_db.RegisterMessage(HeadstageSpec)

ProbeModel = _reflection.GeneratedProtocolMessageType('ProbeModel', (_message.Message,), {

  'ProbeSiteDesc' : _reflection.GeneratedProtocolMessageType('ProbeSiteDesc', (_message.Message,), {
    'DESCRIPTOR' : _PROBEMODEL_PROBESITEDESC,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.ProbeModel.ProbeSiteDesc)
    })
  ,

  'ProbeWireFrame' : _reflection.GeneratedProtocolMessageType('ProbeWireFrame', (_message.Message,), {
    'DESCRIPTOR' : _PROBEMODEL_PROBEWIREFRAME,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.ProbeModel.ProbeWireFrame)
    })
  ,

  'ProbePtXY' : _reflection.GeneratedProtocolMessageType('ProbePtXY', (_message.Message,), {
    'DESCRIPTOR' : _PROBEMODEL_PROBEPTXY,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.ProbeModel.ProbePtXY)
    })
  ,
  'DESCRIPTOR' : _PROBEMODEL,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ProbeModel)
  })
_sym_db.RegisterMessage(ProbeModel)
_sym_db.RegisterMessage(ProbeModel.ProbeSiteDesc)
_sym_db.RegisterMessage(ProbeModel.ProbeWireFrame)
_sym_db.RegisterMessage(ProbeModel.ProbePtXY)

ProbeMetaData = _reflection.GeneratedProtocolMessageType('ProbeMetaData', (_message.Message,), {
  'DESCRIPTOR' : _PROBEMETADATA,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ProbeMetaData)
  })
_sym_db.RegisterMessage(ProbeMetaData)

HeadstageModel = _reflection.GeneratedProtocolMessageType('HeadstageModel', (_message.Message,), {

  'HeadstageRow' : _reflection.GeneratedProtocolMessageType('HeadstageRow', (_message.Message,), {
    'DESCRIPTOR' : _HEADSTAGEMODEL_HEADSTAGEROW,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.HeadstageModel.HeadstageRow)
    })
  ,
  'DESCRIPTOR' : _HEADSTAGEMODEL,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.HeadstageModel)
  })
_sym_db.RegisterMessage(HeadstageModel)
_sym_db.RegisterMessage(HeadstageModel.HeadstageRow)

HeadstageMetaData = _reflection.GeneratedProtocolMessageType('HeadstageMetaData', (_message.Message,), {
  'DESCRIPTOR' : _HEADSTAGEMETADATA,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.HeadstageMetaData)
  })
_sym_db.RegisterMessage(HeadstageMetaData)

UserProfile = _reflection.GeneratedProtocolMessageType('UserProfile', (_message.Message,), {
  'DESCRIPTOR' : _USERPROFILE,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.UserProfile)
  })
_sym_db.RegisterMessage(UserProfile)

GetCurrentProfileReply = _reflection.GeneratedProtocolMessageType('GetCurrentProfileReply', (_message.Message,), {
  'DESCRIPTOR' : _GETCURRENTPROFILEREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetCurrentProfileReply)
  })
_sym_db.RegisterMessage(GetCurrentProfileReply)

GetAllProfilesReply = _reflection.GeneratedProtocolMessageType('GetAllProfilesReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPROFILESREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetAllProfilesReply)
  })
_sym_db.RegisterMessage(GetAllProfilesReply)

SetCurrentProfileRequest = _reflection.GeneratedProtocolMessageType('SetCurrentProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCURRENTPROFILEREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SetCurrentProfileRequest)
  })
_sym_db.RegisterMessage(SetCurrentProfileRequest)

ManageNodeOrgPayload = _reflection.GeneratedProtocolMessageType('ManageNodeOrgPayload', (_message.Message,), {
  'DESCRIPTOR' : _MANAGENODEORGPAYLOAD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ManageNodeOrgPayload)
  })
_sym_db.RegisterMessage(ManageNodeOrgPayload)

ManageNodeOrgRequest = _reflection.GeneratedProtocolMessageType('ManageNodeOrgRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGENODEORGREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ManageNodeOrgRequest)
  })
_sym_db.RegisterMessage(ManageNodeOrgRequest)

ManageNodeOrgReply = _reflection.GeneratedProtocolMessageType('ManageNodeOrgReply', (_message.Message,), {
  'DESCRIPTOR' : _MANAGENODEORGREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ManageNodeOrgReply)
  })
_sym_db.RegisterMessage(ManageNodeOrgReply)

ManageNodeLabPayload = _reflection.GeneratedProtocolMessageType('ManageNodeLabPayload', (_message.Message,), {
  'DESCRIPTOR' : _MANAGENODELABPAYLOAD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ManageNodeLabPayload)
  })
_sym_db.RegisterMessage(ManageNodeLabPayload)

ManageNodeLabRequest = _reflection.GeneratedProtocolMessageType('ManageNodeLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGENODELABREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ManageNodeLabRequest)
  })
_sym_db.RegisterMessage(ManageNodeLabRequest)

ManageNodeLabReply = _reflection.GeneratedProtocolMessageType('ManageNodeLabReply', (_message.Message,), {
  'DESCRIPTOR' : _MANAGENODELABREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ManageNodeLabReply)
  })
_sym_db.RegisterMessage(ManageNodeLabReply)

ManageNodeUserPayload = _reflection.GeneratedProtocolMessageType('ManageNodeUserPayload', (_message.Message,), {
  'DESCRIPTOR' : _MANAGENODEUSERPAYLOAD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ManageNodeUserPayload)
  })
_sym_db.RegisterMessage(ManageNodeUserPayload)

ManageNodeUserRequest = _reflection.GeneratedProtocolMessageType('ManageNodeUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _MANAGENODEUSERREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ManageNodeUserRequest)
  })
_sym_db.RegisterMessage(ManageNodeUserRequest)

ManageNodeUserReply = _reflection.GeneratedProtocolMessageType('ManageNodeUserReply', (_message.Message,), {
  'DESCRIPTOR' : _MANAGENODEUSERREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ManageNodeUserReply)
  })
_sym_db.RegisterMessage(ManageNodeUserReply)

CatalogProbePayload = _reflection.GeneratedProtocolMessageType('CatalogProbePayload', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGPROBEPAYLOAD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.CatalogProbePayload)
  })
_sym_db.RegisterMessage(CatalogProbePayload)

ProbeNodeRequest = _reflection.GeneratedProtocolMessageType('ProbeNodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROBENODEREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ProbeNodeRequest)
  })
_sym_db.RegisterMessage(ProbeNodeRequest)

ProbeNodeReply = _reflection.GeneratedProtocolMessageType('ProbeNodeReply', (_message.Message,), {
  'DESCRIPTOR' : _PROBENODEREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ProbeNodeReply)
  })
_sym_db.RegisterMessage(ProbeNodeReply)

ProbePayload = _reflection.GeneratedProtocolMessageType('ProbePayload', (_message.Message,), {
  'DESCRIPTOR' : _PROBEPAYLOAD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ProbePayload)
  })
_sym_db.RegisterMessage(ProbePayload)

EdgePayload = _reflection.GeneratedProtocolMessageType('EdgePayload', (_message.Message,), {

  'GenericNode' : _reflection.GeneratedProtocolMessageType('GenericNode', (_message.Message,), {
    'DESCRIPTOR' : _EDGEPAYLOAD_GENERICNODE,
    '__module__' : 'common_pb2'
    # @@protoc_insertion_point(class_scope:allego.EdgePayload.GenericNode)
    })
  ,
  'DESCRIPTOR' : _EDGEPAYLOAD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.EdgePayload)
  })
_sym_db.RegisterMessage(EdgePayload)
_sym_db.RegisterMessage(EdgePayload.GenericNode)

WorldEdgeRequest = _reflection.GeneratedProtocolMessageType('WorldEdgeRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORLDEDGEREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WorldEdgeRequest)
  })
_sym_db.RegisterMessage(WorldEdgeRequest)

WorldEdgeReply = _reflection.GeneratedProtocolMessageType('WorldEdgeReply', (_message.Message,), {
  'DESCRIPTOR' : _WORLDEDGEREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WorldEdgeReply)
  })
_sym_db.RegisterMessage(WorldEdgeReply)

QueryWorldRequest = _reflection.GeneratedProtocolMessageType('QueryWorldRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYWORLDREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.QueryWorldRequest)
  })
_sym_db.RegisterMessage(QueryWorldRequest)

QueryWorldRec = _reflection.GeneratedProtocolMessageType('QueryWorldRec', (_message.Message,), {
  'DESCRIPTOR' : _QUERYWORLDREC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.QueryWorldRec)
  })
_sym_db.RegisterMessage(QueryWorldRec)

QueryWorldReply = _reflection.GeneratedProtocolMessageType('QueryWorldReply', (_message.Message,), {
  'DESCRIPTOR' : _QUERYWORLDREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.QueryWorldReply)
  })
_sym_db.RegisterMessage(QueryWorldReply)

HighLowPassTransformParams = _reflection.GeneratedProtocolMessageType('HighLowPassTransformParams', (_message.Message,), {
  'DESCRIPTOR' : _HIGHLOWPASSTRANSFORMPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.HighLowPassTransformParams)
  })
_sym_db.RegisterMessage(HighLowPassTransformParams)

BandTransformParams = _reflection.GeneratedProtocolMessageType('BandTransformParams', (_message.Message,), {
  'DESCRIPTOR' : _BANDTRANSFORMPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.BandTransformParams)
  })
_sym_db.RegisterMessage(BandTransformParams)

NotchTransformParams = _reflection.GeneratedProtocolMessageType('NotchTransformParams', (_message.Message,), {
  'DESCRIPTOR' : _NOTCHTRANSFORMPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.NotchTransformParams)
  })
_sym_db.RegisterMessage(NotchTransformParams)

CARTransformParams = _reflection.GeneratedProtocolMessageType('CARTransformParams', (_message.Message,), {
  'DESCRIPTOR' : _CARTRANSFORMPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.CARTransformParams)
  })
_sym_db.RegisterMessage(CARTransformParams)

VirtualRefTransformParams = _reflection.GeneratedProtocolMessageType('VirtualRefTransformParams', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALREFTRANSFORMPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.VirtualRefTransformParams)
  })
_sym_db.RegisterMessage(VirtualRefTransformParams)

PairedRefTransformParams = _reflection.GeneratedProtocolMessageType('PairedRefTransformParams', (_message.Message,), {
  'DESCRIPTOR' : _PAIREDREFTRANSFORMPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.PairedRefTransformParams)
  })
_sym_db.RegisterMessage(PairedRefTransformParams)

DataSourceSinkTransformParams = _reflection.GeneratedProtocolMessageType('DataSourceSinkTransformParams', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESINKTRANSFORMPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceSinkTransformParams)
  })
_sym_db.RegisterMessage(DataSourceSinkTransformParams)

SliceTimeTransformParams = _reflection.GeneratedProtocolMessageType('SliceTimeTransformParams', (_message.Message,), {
  'DESCRIPTOR' : _SLICETIMETRANSFORMPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SliceTimeTransformParams)
  })
_sym_db.RegisterMessage(SliceTimeTransformParams)

SliceChannelsTransformParams = _reflection.GeneratedProtocolMessageType('SliceChannelsTransformParams', (_message.Message,), {
  'DESCRIPTOR' : _SLICECHANNELSTRANSFORMPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SliceChannelsTransformParams)
  })
_sym_db.RegisterMessage(SliceChannelsTransformParams)

DownsampleTransformParams = _reflection.GeneratedProtocolMessageType('DownsampleTransformParams', (_message.Message,), {
  'DESCRIPTOR' : _DOWNSAMPLETRANSFORMPARAMS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.DownsampleTransformParams)
  })
_sym_db.RegisterMessage(DownsampleTransformParams)

Position = _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), {
  'DESCRIPTOR' : _POSITION,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.Position)
  })
_sym_db.RegisterMessage(Position)

TransformNode = _reflection.GeneratedProtocolMessageType('TransformNode', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMNODE,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.TransformNode)
  })
_sym_db.RegisterMessage(TransformNode)

TransformEdge = _reflection.GeneratedProtocolMessageType('TransformEdge', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMEDGE,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.TransformEdge)
  })
_sym_db.RegisterMessage(TransformEdge)

Protocol = _reflection.GeneratedProtocolMessageType('Protocol', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOL,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.Protocol)
  })
_sym_db.RegisterMessage(Protocol)

ProtocolRequest = _reflection.GeneratedProtocolMessageType('ProtocolRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ProtocolRequest)
  })
_sym_db.RegisterMessage(ProtocolRequest)

RenameProtocolRequest = _reflection.GeneratedProtocolMessageType('RenameProtocolRequest', (_message.Message,), {
  'DESCRIPTOR' : _RENAMEPROTOCOLREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.RenameProtocolRequest)
  })
_sym_db.RegisterMessage(RenameProtocolRequest)

GetAllProtocolsReply = _reflection.GeneratedProtocolMessageType('GetAllProtocolsReply', (_message.Message,), {
  'DESCRIPTOR' : _GETALLPROTOCOLSREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetAllProtocolsReply)
  })
_sym_db.RegisterMessage(GetAllProtocolsReply)

ApplyProtocolProgress = _reflection.GeneratedProtocolMessageType('ApplyProtocolProgress', (_message.Message,), {
  'DESCRIPTOR' : _APPLYPROTOCOLPROGRESS,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ApplyProtocolProgress)
  })
_sym_db.RegisterMessage(ApplyProtocolProgress)

SpikeSorterSetParamRequest = _reflection.GeneratedProtocolMessageType('SpikeSorterSetParamRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERSETPARAMREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterSetParamRequest)
  })
_sym_db.RegisterMessage(SpikeSorterSetParamRequest)

SpikeSorterSetParamsRequest = _reflection.GeneratedProtocolMessageType('SpikeSorterSetParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERSETPARAMSREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterSetParamsRequest)
  })
_sym_db.RegisterMessage(SpikeSorterSetParamsRequest)

SpikeSorterParamCommandRecord = _reflection.GeneratedProtocolMessageType('SpikeSorterParamCommandRecord', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESORTERPARAMCOMMANDRECORD,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeSorterParamCommandRecord)
  })
_sym_db.RegisterMessage(SpikeSorterParamCommandRecord)

WrangleRequest = _reflection.GeneratedProtocolMessageType('WrangleRequest', (_message.Message,), {
  'DESCRIPTOR' : _WRANGLEREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WrangleRequest)
  })
_sym_db.RegisterMessage(WrangleRequest)

WrangleSpec = _reflection.GeneratedProtocolMessageType('WrangleSpec', (_message.Message,), {
  'DESCRIPTOR' : _WRANGLESPEC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WrangleSpec)
  })
_sym_db.RegisterMessage(WrangleSpec)

WrangleImport = _reflection.GeneratedProtocolMessageType('WrangleImport', (_message.Message,), {
  'DESCRIPTOR' : _WRANGLEIMPORT,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WrangleImport)
  })
_sym_db.RegisterMessage(WrangleImport)

WrangleImportVexSpikesSim = _reflection.GeneratedProtocolMessageType('WrangleImportVexSpikesSim', (_message.Message,), {
  'DESCRIPTOR' : _WRANGLEIMPORTVEXSPIKESSIM,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WrangleImportVexSpikesSim)
  })
_sym_db.RegisterMessage(WrangleImportVexSpikesSim)

WrangleFileDesc = _reflection.GeneratedProtocolMessageType('WrangleFileDesc', (_message.Message,), {
  'DESCRIPTOR' : _WRANGLEFILEDESC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WrangleFileDesc)
  })
_sym_db.RegisterMessage(WrangleFileDesc)

WrangleMerge = _reflection.GeneratedProtocolMessageType('WrangleMerge', (_message.Message,), {
  'DESCRIPTOR' : _WRANGLEMERGE,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WrangleMerge)
  })
_sym_db.RegisterMessage(WrangleMerge)

WrangleMergeVexSpikesView = _reflection.GeneratedProtocolMessageType('WrangleMergeVexSpikesView', (_message.Message,), {
  'DESCRIPTOR' : _WRANGLEMERGEVEXSPIKESVIEW,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WrangleMergeVexSpikesView)
  })
_sym_db.RegisterMessage(WrangleMergeVexSpikesView)

WrangleMergeVexSpikesViewSpec = _reflection.GeneratedProtocolMessageType('WrangleMergeVexSpikesViewSpec', (_message.Message,), {
  'DESCRIPTOR' : _WRANGLEMERGEVEXSPIKESVIEWSPEC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.WrangleMergeVexSpikesViewSpec)
  })
_sym_db.RegisterMessage(WrangleMergeVexSpikesViewSpec)

DACStreamRequest = _reflection.GeneratedProtocolMessageType('DACStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _DACSTREAMREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.DACStreamRequest)
  })
_sym_db.RegisterMessage(DACStreamRequest)

EventViewerConfig = _reflection.GeneratedProtocolMessageType('EventViewerConfig', (_message.Message,), {
  'DESCRIPTOR' : _EVENTVIEWERCONFIG,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.EventViewerConfig)
  })
_sym_db.RegisterMessage(EventViewerConfig)

EventViewerID = _reflection.GeneratedProtocolMessageType('EventViewerID', (_message.Message,), {
  'DESCRIPTOR' : _EVENTVIEWERID,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.EventViewerID)
  })
_sym_db.RegisterMessage(EventViewerID)

GetEventViewerEventRequest = _reflection.GeneratedProtocolMessageType('GetEventViewerEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTVIEWEREVENTREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.GetEventViewerEventRequest)
  })
_sym_db.RegisterMessage(GetEventViewerEventRequest)

EventViewerEventDesc = _reflection.GeneratedProtocolMessageType('EventViewerEventDesc', (_message.Message,), {
  'DESCRIPTOR' : _EVENTVIEWEREVENTDESC,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.EventViewerEventDesc)
  })
_sym_db.RegisterMessage(EventViewerEventDesc)

EventViewerEvent = _reflection.GeneratedProtocolMessageType('EventViewerEvent', (_message.Message,), {
  'DESCRIPTOR' : _EVENTVIEWEREVENT,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.EventViewerEvent)
  })
_sym_db.RegisterMessage(EventViewerEvent)

ListEventViewerEventsReply = _reflection.GeneratedProtocolMessageType('ListEventViewerEventsReply', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTVIEWEREVENTSREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ListEventViewerEventsReply)
  })
_sym_db.RegisterMessage(ListEventViewerEventsReply)

ListEventViewersReply = _reflection.GeneratedProtocolMessageType('ListEventViewersReply', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTVIEWERSREPLY,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.ListEventViewersReply)
  })
_sym_db.RegisterMessage(ListEventViewersReply)

StatusPollFieldsToUpdateRequest = _reflection.GeneratedProtocolMessageType('StatusPollFieldsToUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATUSPOLLFIELDSTOUPDATEREQUEST,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.StatusPollFieldsToUpdateRequest)
  })
_sym_db.RegisterMessage(StatusPollFieldsToUpdateRequest)

StatusPollFieldsToUpdate = _reflection.GeneratedProtocolMessageType('StatusPollFieldsToUpdate', (_message.Message,), {
  'DESCRIPTOR' : _STATUSPOLLFIELDSTOUPDATE,
  '__module__' : 'common_pb2'
  # @@protoc_insertion_point(class_scope:allego.StatusPollFieldsToUpdate)
  })
_sym_db.RegisterMessage(StatusPollFieldsToUpdate)


DESCRIPTOR._options = None
_GETWORKSPACEREPLY_WORKSPACEDESCENTRY._options = None
_SERVERSPEC_SERVICEENTRY._options = None
_SIGNALGROUPUNITS_UNITSENTRY._options = None
_UPDATESIGNALGROUPREQUEST.fields_by_name['ntvChanIdx']._options = None
_SETKPITHRESHOLDREQUEST.fields_by_name['ntvChanIdx']._options = None
_SETKPIEVENTDETECTREQUEST.fields_by_name['ntvChanIdx']._options = None
_SETKPIEVENTSHADOWREQUEST.fields_by_name['ntvChanIdx']._options = None
_SETKPIEVENTWINDOWREQUEST.fields_by_name['ntvChanIdx']._options = None
# @@protoc_insertion_point(module_scope)
